Class: Google::Cloud::Dataplex::V1::CreateDataProductRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataplex/v1/data_products.rb

Overview

Request message for creating a data product.

Instance Attribute Summary collapse

Instance Attribute Details

#data_product::Google::Cloud::Dataplex::V1::DataProduct

Returns Required. The data product to create.

Returns:



292
293
294
295
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 292

class CreateDataProductRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#data_product_id::String

Returns Optional. The ID of the data product to create.

The ID must conform to RFC-1034 and contain only lower-case letters (a-z), numbers (0-9), or hyphens, with the first character a letter, the last a letter or a number, and a 63 character maximum. Characters outside of ASCII are not permitted. Valid format regex: ^[a-z]([a-z0-9-]{0,61}[a-z0-9])?$ If not provided, a system generated ID will be used.

Returns:

  • (::String)

    Optional. The ID of the data product to create.

    The ID must conform to RFC-1034 and contain only lower-case letters (a-z), numbers (0-9), or hyphens, with the first character a letter, the last a letter or a number, and a 63 character maximum. Characters outside of ASCII are not permitted. Valid format regex: ^[a-z]([a-z0-9-]{0,61}[a-z0-9])?$ If not provided, a system generated ID will be used.



292
293
294
295
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 292

class CreateDataProductRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent resource where this data product will be created. Format: projects/{project_id_or_number}/locations/{location_id}.

Returns:

  • (::String)

    Required. The parent resource where this data product will be created. Format: projects/{project_id_or_number}/locations/{location_id}



292
293
294
295
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 292

class CreateDataProductRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#validate_only::Boolean

Returns Optional. Validates the request without actually creating the data product. Default: false.

Returns:

  • (::Boolean)

    Optional. Validates the request without actually creating the data product. Default: false.



292
293
294
295
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 292

class CreateDataProductRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end