Class: Google::Cloud::Dataplex::V1::CreateMetadataFeedRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataplex/v1/catalog.rb

Overview

Request message for CreateMetadataFeed.

Instance Attribute Summary collapse

Instance Attribute Details

#metadata_feed::Google::Cloud::Dataplex::V1::MetadataFeed

Returns Required. The metadata job resource.

Returns:



2182
2183
2184
2185
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 2182

class CreateMetadataFeedRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#metadata_feed_id::String

Returns Optional. The metadata job ID. If not provided, a unique ID is generated with the prefix metadata-job-.

Returns:

  • (::String)

    Optional. The metadata job ID. If not provided, a unique ID is generated with the prefix metadata-job-.



2182
2183
2184
2185
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 2182

class CreateMetadataFeedRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The resource name of the parent location, in the format projects/{project_id_or_number}/locations/{location_id}.

Returns:

  • (::String)

    Required. The resource name of the parent location, in the format projects/{project_id_or_number}/locations/{location_id}



2182
2183
2184
2185
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 2182

class CreateMetadataFeedRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#validate_only::Boolean

Returns Optional. The service validates the request without performing any mutations. The default is false.

Returns:

  • (::Boolean)

    Optional. The service validates the request without performing any mutations. The default is false.



2182
2183
2184
2185
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 2182

class CreateMetadataFeedRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end