Class: Google::Cloud::Dataplex::V1::DataAsset

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataplex/v1/data_products.rb

Overview

Represents a data asset resource that can be packaged and shared via a data product.

Defined Under Namespace

Classes: AccessGroupConfig, AccessGroupConfigsEntry, LabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#access_group_configs::Google::Protobuf::Map{::String => ::Google::Cloud::Dataplex::V1::DataAsset::AccessGroupConfig}

Returns Optional. Access groups configurations for this data asset.

The key is DataProduct.AccessGroup.id and the value is AccessGroupConfig.

Example:

 {
   "analyst": {
     "iamRoles": ["roles/bigquery.dataViewer"]
   }
 }

Currently, at most one IAM role is allowed per access group. For providing multiple predefined IAM roles, wrap them in a custom IAM role as per https://cloud.google.com/iam/docs/creating-custom-roles.

Returns:



235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 235

class DataAsset
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for access group inherited from the parent data product.
  # @!attribute [rw] iam_roles
  #   @return [::Array<::String>]
  #     Optional. IAM roles granted on the resource to this access group. Role
  #     name follows https://cloud.google.com/iam/docs/reference/rest/v1/roles.
  #
  #     Example: `[ "roles/bigquery.dataViewer" ]`
  class AccessGroupConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dataplex::V1::DataAsset::AccessGroupConfig]
  class AccessGroupConfigsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time at which the data asset was created.

Returns:



235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 235

class DataAsset
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for access group inherited from the parent data product.
  # @!attribute [rw] iam_roles
  #   @return [::Array<::String>]
  #     Optional. IAM roles granted on the resource to this access group. Role
  #     name follows https://cloud.google.com/iam/docs/reference/rest/v1/roles.
  #
  #     Example: `[ "roles/bigquery.dataViewer" ]`
  class AccessGroupConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dataplex::V1::DataAsset::AccessGroupConfig]
  class AccessGroupConfigsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#etag::String

Returns Optional. This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.

Returns:

  • (::String)

    Optional. This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.



235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 235

class DataAsset
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for access group inherited from the parent data product.
  # @!attribute [rw] iam_roles
  #   @return [::Array<::String>]
  #     Optional. IAM roles granted on the resource to this access group. Role
  #     name follows https://cloud.google.com/iam/docs/reference/rest/v1/roles.
  #
  #     Example: `[ "roles/bigquery.dataViewer" ]`
  class AccessGroupConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dataplex::V1::DataAsset::AccessGroupConfig]
  class AccessGroupConfigsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#labels::Google::Protobuf::Map{::String => ::String}

Returns Optional. User-defined labels for the data asset.

Example:

 {
   "environment": "production",
   "billing": "marketing-department"
 }
 ```.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional. User-defined labels for the data asset.

    Example:

     {
       "environment": "production",
       "billing": "marketing-department"
     }
    


235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 235

class DataAsset
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for access group inherited from the parent data product.
  # @!attribute [rw] iam_roles
  #   @return [::Array<::String>]
  #     Optional. IAM roles granted on the resource to this access group. Role
  #     name follows https://cloud.google.com/iam/docs/reference/rest/v1/roles.
  #
  #     Example: `[ "roles/bigquery.dataViewer" ]`
  class AccessGroupConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dataplex::V1::DataAsset::AccessGroupConfig]
  class AccessGroupConfigsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#name::String

Returns Identifier. Resource name of the data asset. Format: projects/{project_id_or_number}/locations/{location_id}/dataProducts/{data_product_id}/dataAssets/{data_asset_id}.

Returns:

  • (::String)

    Identifier. Resource name of the data asset. Format: projects/{project_id_or_number}/locations/{location_id}/dataProducts/{data_product_id}/dataAssets/{data_asset_id}



235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 235

class DataAsset
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for access group inherited from the parent data product.
  # @!attribute [rw] iam_roles
  #   @return [::Array<::String>]
  #     Optional. IAM roles granted on the resource to this access group. Role
  #     name follows https://cloud.google.com/iam/docs/reference/rest/v1/roles.
  #
  #     Example: `[ "roles/bigquery.dataViewer" ]`
  class AccessGroupConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dataplex::V1::DataAsset::AccessGroupConfig]
  class AccessGroupConfigsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#resource::String

Returns Required. Immutable. Full resource name of the cloud resource represented by the data asset. This must follow https://cloud.google.com/iam/docs/full-resource-names. Example: //bigquery.googleapis.com/projects/my_project_123/datasets/dataset_456/tables/table_789 Only BigQuery tables and datasets are currently supported. Data asset creator must have getIamPolicy and setIamPolicy permissions on the resource. Data asset creator must also have resource specific get permission, for instance, bigquery.tables.get for BigQuery tables.

Returns:

  • (::String)

    Required. Immutable. Full resource name of the cloud resource represented by the data asset. This must follow https://cloud.google.com/iam/docs/full-resource-names. Example: //bigquery.googleapis.com/projects/my_project_123/datasets/dataset_456/tables/table_789 Only BigQuery tables and datasets are currently supported. Data asset creator must have getIamPolicy and setIamPolicy permissions on the resource. Data asset creator must also have resource specific get permission, for instance, bigquery.tables.get for BigQuery tables.



235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 235

class DataAsset
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for access group inherited from the parent data product.
  # @!attribute [rw] iam_roles
  #   @return [::Array<::String>]
  #     Optional. IAM roles granted on the resource to this access group. Role
  #     name follows https://cloud.google.com/iam/docs/reference/rest/v1/roles.
  #
  #     Example: `[ "roles/bigquery.dataViewer" ]`
  class AccessGroupConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dataplex::V1::DataAsset::AccessGroupConfig]
  class AccessGroupConfigsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#uid::String (readonly)

Returns Output only. System generated globally unique ID for the data asset. This ID will be different if the data asset is deleted and re-created with the same name.

Returns:

  • (::String)

    Output only. System generated globally unique ID for the data asset. This ID will be different if the data asset is deleted and re-created with the same name.



235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 235

class DataAsset
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for access group inherited from the parent data product.
  # @!attribute [rw] iam_roles
  #   @return [::Array<::String>]
  #     Optional. IAM roles granted on the resource to this access group. Role
  #     name follows https://cloud.google.com/iam/docs/reference/rest/v1/roles.
  #
  #     Example: `[ "roles/bigquery.dataViewer" ]`
  class AccessGroupConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dataplex::V1::DataAsset::AccessGroupConfig]
  class AccessGroupConfigsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time at which the data asset was last updated.

Returns:



235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 235

class DataAsset
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for access group inherited from the parent data product.
  # @!attribute [rw] iam_roles
  #   @return [::Array<::String>]
  #     Optional. IAM roles granted on the resource to this access group. Role
  #     name follows https://cloud.google.com/iam/docs/reference/rest/v1/roles.
  #
  #     Example: `[ "roles/bigquery.dataViewer" ]`
  class AccessGroupConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dataplex::V1::DataAsset::AccessGroupConfig]
  class AccessGroupConfigsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end