Class: Google::Cloud::Dataplex::V1::DataDiscoveryResult

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataplex/v1/data_discovery.rb

Overview

The output of a data discovery scan.

Defined Under Namespace

Classes: BigQueryPublishing, ScanStatistics

Instance Attribute Summary collapse

Instance Attribute Details

#bigquery_publishing::Google::Cloud::Dataplex::V1::DataDiscoveryResult::BigQueryPublishing (readonly)

Returns Output only. Configuration for metadata publishing.

Returns:



183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'proto_docs/google/cloud/dataplex/v1/data_discovery.rb', line 183

class DataDiscoveryResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes BigQuery publishing configurations.
  # @!attribute [r] dataset
  #   @return [::String]
  #     Output only. The BigQuery dataset the discovered tables are published to.
  # @!attribute [r] location
  #   @return [::String]
  #     Output only. The location of the BigQuery publishing dataset.
  class BigQueryPublishing
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Describes result statistics of a data scan discovery job.
  # @!attribute [rw] scanned_file_count
  #   @return [::Integer]
  #     The number of files scanned.
  # @!attribute [rw] data_processed_bytes
  #   @return [::Integer]
  #     The data processed in bytes.
  # @!attribute [rw] files_excluded
  #   @return [::Integer]
  #     The number of files excluded.
  # @!attribute [rw] tables_created
  #   @return [::Integer]
  #     The number of tables created.
  # @!attribute [rw] tables_deleted
  #   @return [::Integer]
  #     The number of tables deleted.
  # @!attribute [rw] tables_updated
  #   @return [::Integer]
  #     The number of tables updated.
  # @!attribute [rw] filesets_created
  #   @return [::Integer]
  #     The number of filesets created.
  # @!attribute [rw] filesets_deleted
  #   @return [::Integer]
  #     The number of filesets deleted.
  # @!attribute [rw] filesets_updated
  #   @return [::Integer]
  #     The number of filesets updated.
  class ScanStatistics
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#scan_statistics::Google::Cloud::Dataplex::V1::DataDiscoveryResult::ScanStatistics (readonly)

Returns Output only. Describes result statistics of a data scan discovery job.

Returns:



183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'proto_docs/google/cloud/dataplex/v1/data_discovery.rb', line 183

class DataDiscoveryResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes BigQuery publishing configurations.
  # @!attribute [r] dataset
  #   @return [::String]
  #     Output only. The BigQuery dataset the discovered tables are published to.
  # @!attribute [r] location
  #   @return [::String]
  #     Output only. The location of the BigQuery publishing dataset.
  class BigQueryPublishing
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Describes result statistics of a data scan discovery job.
  # @!attribute [rw] scanned_file_count
  #   @return [::Integer]
  #     The number of files scanned.
  # @!attribute [rw] data_processed_bytes
  #   @return [::Integer]
  #     The data processed in bytes.
  # @!attribute [rw] files_excluded
  #   @return [::Integer]
  #     The number of files excluded.
  # @!attribute [rw] tables_created
  #   @return [::Integer]
  #     The number of tables created.
  # @!attribute [rw] tables_deleted
  #   @return [::Integer]
  #     The number of tables deleted.
  # @!attribute [rw] tables_updated
  #   @return [::Integer]
  #     The number of tables updated.
  # @!attribute [rw] filesets_created
  #   @return [::Integer]
  #     The number of filesets created.
  # @!attribute [rw] filesets_deleted
  #   @return [::Integer]
  #     The number of filesets deleted.
  # @!attribute [rw] filesets_updated
  #   @return [::Integer]
  #     The number of filesets updated.
  class ScanStatistics
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end