Class: Google::Cloud::Dataplex::V1::DataDocumentationResult::SchemaRelationship

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataplex/v1/data_documentation.rb

Overview

Details of the relationship between the schema of two resources.

Defined Under Namespace

Modules: Source, Type Classes: SchemaPaths

Instance Attribute Summary collapse

Instance Attribute Details

#left_schema_paths::Google::Cloud::Dataplex::V1::DataDocumentationResult::SchemaRelationship::SchemaPaths (readonly)

Returns Output only. An ordered list of fields for the join from the first table. The size of this list must be the same as right_schema_paths. Each field at index i in this list must correspond to a field at the same index in the right_schema_paths list.

Returns:



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'proto_docs/google/cloud/dataplex/v1/data_documentation.rb', line 127

class SchemaRelationship
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents an ordered set of paths within a table's schema.
  # @!attribute [r] table_fqn
  #   @return [::String]
  #     Output only. The service-qualified full resource name of the table
  #     Ex:
  #     //bigquery.googleapis.com/projects/PROJECT_ID/datasets/DATASET_ID/tables/TABLE_ID
  # @!attribute [r] paths
  #   @return [::Array<::String>]
  #     Output only. An ordered set of Paths to fields within the schema of the
  #     table. For fields nested within a top level field of type record, use
  #     '.' to separate field names. Examples: Top level field - `top_level`
  #     Nested field - `top_level.child.sub_field`
  class SchemaPaths
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Source which generated the schema relation edge.
  module Source
    # The source of the schema relationship is unspecified.
    SOURCE_UNSPECIFIED = 0

    # The source of the schema relationship is agent.
    AGENT = 4

    # The source of the schema relationship is query history from the source
    # system.
    QUERY_HISTORY = 5

    # The source of the schema relationship is table constraints added in
    # the source system.
    TABLE_CONSTRAINTS = 6
  end

  # The type of relationship.
  module Type
    # The type of the schema relationship is unspecified.
    TYPE_UNSPECIFIED = 0

    # Indicates a join relationship between the schema fields.
    SCHEMA_JOIN = 1
  end
end

#right_schema_paths::Google::Cloud::Dataplex::V1::DataDocumentationResult::SchemaRelationship::SchemaPaths (readonly)

Returns Output only. An ordered list of fields for the join from the second table. The size of this list must be the same as left_schema_paths. Each field at index i in this list must correspond to a field at the same index in the left_schema_paths list.

Returns:



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'proto_docs/google/cloud/dataplex/v1/data_documentation.rb', line 127

class SchemaRelationship
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents an ordered set of paths within a table's schema.
  # @!attribute [r] table_fqn
  #   @return [::String]
  #     Output only. The service-qualified full resource name of the table
  #     Ex:
  #     //bigquery.googleapis.com/projects/PROJECT_ID/datasets/DATASET_ID/tables/TABLE_ID
  # @!attribute [r] paths
  #   @return [::Array<::String>]
  #     Output only. An ordered set of Paths to fields within the schema of the
  #     table. For fields nested within a top level field of type record, use
  #     '.' to separate field names. Examples: Top level field - `top_level`
  #     Nested field - `top_level.child.sub_field`
  class SchemaPaths
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Source which generated the schema relation edge.
  module Source
    # The source of the schema relationship is unspecified.
    SOURCE_UNSPECIFIED = 0

    # The source of the schema relationship is agent.
    AGENT = 4

    # The source of the schema relationship is query history from the source
    # system.
    QUERY_HISTORY = 5

    # The source of the schema relationship is table constraints added in
    # the source system.
    TABLE_CONSTRAINTS = 6
  end

  # The type of relationship.
  module Type
    # The type of the schema relationship is unspecified.
    TYPE_UNSPECIFIED = 0

    # Indicates a join relationship between the schema fields.
    SCHEMA_JOIN = 1
  end
end

#sources::Array<::Google::Cloud::Dataplex::V1::DataDocumentationResult::SchemaRelationship::Source> (readonly)

Returns Output only. Sources which generated the schema relation edge.

Returns:



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'proto_docs/google/cloud/dataplex/v1/data_documentation.rb', line 127

class SchemaRelationship
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents an ordered set of paths within a table's schema.
  # @!attribute [r] table_fqn
  #   @return [::String]
  #     Output only. The service-qualified full resource name of the table
  #     Ex:
  #     //bigquery.googleapis.com/projects/PROJECT_ID/datasets/DATASET_ID/tables/TABLE_ID
  # @!attribute [r] paths
  #   @return [::Array<::String>]
  #     Output only. An ordered set of Paths to fields within the schema of the
  #     table. For fields nested within a top level field of type record, use
  #     '.' to separate field names. Examples: Top level field - `top_level`
  #     Nested field - `top_level.child.sub_field`
  class SchemaPaths
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Source which generated the schema relation edge.
  module Source
    # The source of the schema relationship is unspecified.
    SOURCE_UNSPECIFIED = 0

    # The source of the schema relationship is agent.
    AGENT = 4

    # The source of the schema relationship is query history from the source
    # system.
    QUERY_HISTORY = 5

    # The source of the schema relationship is table constraints added in
    # the source system.
    TABLE_CONSTRAINTS = 6
  end

  # The type of relationship.
  module Type
    # The type of the schema relationship is unspecified.
    TYPE_UNSPECIFIED = 0

    # Indicates a join relationship between the schema fields.
    SCHEMA_JOIN = 1
  end
end

#type::Google::Cloud::Dataplex::V1::DataDocumentationResult::SchemaRelationship::Type (readonly)

Returns Output only. The type of relationship between the schema paths.

Returns:



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'proto_docs/google/cloud/dataplex/v1/data_documentation.rb', line 127

class SchemaRelationship
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents an ordered set of paths within a table's schema.
  # @!attribute [r] table_fqn
  #   @return [::String]
  #     Output only. The service-qualified full resource name of the table
  #     Ex:
  #     //bigquery.googleapis.com/projects/PROJECT_ID/datasets/DATASET_ID/tables/TABLE_ID
  # @!attribute [r] paths
  #   @return [::Array<::String>]
  #     Output only. An ordered set of Paths to fields within the schema of the
  #     table. For fields nested within a top level field of type record, use
  #     '.' to separate field names. Examples: Top level field - `top_level`
  #     Nested field - `top_level.child.sub_field`
  class SchemaPaths
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Source which generated the schema relation edge.
  module Source
    # The source of the schema relationship is unspecified.
    SOURCE_UNSPECIFIED = 0

    # The source of the schema relationship is agent.
    AGENT = 4

    # The source of the schema relationship is query history from the source
    # system.
    QUERY_HISTORY = 5

    # The source of the schema relationship is table constraints added in
    # the source system.
    TABLE_CONSTRAINTS = 6
  end

  # The type of relationship.
  module Type
    # The type of the schema relationship is unspecified.
    TYPE_UNSPECIFIED = 0

    # Indicates a join relationship between the schema fields.
    SCHEMA_JOIN = 1
  end
end