Class: Google::Cloud::Dataplex::V1::DataDocumentationResult::SchemaRelationship::SchemaPaths

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataplex/v1/data_documentation.rb

Overview

Represents an ordered set of paths within a table's schema.

Instance Attribute Summary collapse

Instance Attribute Details

#paths::Array<::String> (readonly)

Returns Output only. An ordered set of Paths to fields within the schema of the table. For fields nested within a top level field of type record, use '.' to separate field names. Examples: Top level field - top_level Nested field - top_level.child.sub_field.

Returns:

  • (::Array<::String>)

    Output only. An ordered set of Paths to fields within the schema of the table. For fields nested within a top level field of type record, use '.' to separate field names. Examples: Top level field - top_level Nested field - top_level.child.sub_field



143
144
145
146
# File 'proto_docs/google/cloud/dataplex/v1/data_documentation.rb', line 143

class SchemaPaths
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#table_fqn::String (readonly)

Returns Output only. The service-qualified full resource name of the table Ex: //bigquery.googleapis.com/projects/PROJECT_ID/datasets/DATASET_ID/tables/TABLE_ID.

Returns:

  • (::String)

    Output only. The service-qualified full resource name of the table Ex: //bigquery.googleapis.com/projects/PROJECT_ID/datasets/DATASET_ID/tables/TABLE_ID



143
144
145
146
# File 'proto_docs/google/cloud/dataplex/v1/data_documentation.rb', line 143

class SchemaPaths
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end