Module: Google::Cloud::Dataplex::V1::DataDocumentationResult::SchemaRelationship::Source

Defined in:
proto_docs/google/cloud/dataplex/v1/data_documentation.rb

Overview

Source which generated the schema relation edge.

Constant Summary collapse

SOURCE_UNSPECIFIED =

The source of the schema relationship is unspecified.

0
AGENT =

The source of the schema relationship is agent.

4
QUERY_HISTORY =

The source of the schema relationship is query history from the source system.

5
TABLE_CONSTRAINTS =

The source of the schema relationship is table constraints added in the source system.

6