Class: Google::Cloud::Dataplex::V1::DataProduct

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataplex/v1/data_products.rb

Overview

A data product is a curated collection of data assets, packaged to address specific use cases. It's a way to manage and share data in a more organized, product-like manner.

Defined Under Namespace

Classes: AccessApprovalConfig, AccessGroup, AccessGroupsEntry, LabelsEntry, Principal

Instance Attribute Summary collapse

Instance Attribute Details

#access_approval_config::Google::Cloud::Dataplex::V1::DataProduct::AccessApprovalConfig

Returns Optional. Configuration for access approval for the data product.

Returns:



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 101

class DataProduct
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the principal entity associated with an access group, as per
  # https://cloud.google.com/iam/docs/principals-overview.
  # @!attribute [rw] google_group
  #   @return [::String]
  #     Optional. Email of the Google Group, as per
  #     https://cloud.google.com/iam/docs/principals-overview#google-group.
  # @!attribute [rw] service_account
  #   @return [::String]
  #     Optional. Specifies the email of the producer service account, as per
  #     https://cloud.google.com/iam/docs/principals-overview#service-account.
  class Principal
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Custom user defined access groups at the data product level. These are used
  # for granting different levels of access (IAM roles) on the individual data
  # product's data assets.
  # @!attribute [rw] id
  #   @return [::String]
  #     Required. Unique identifier of the access group within the data product.
  #     User defined. Eg. "analyst", "developer", etc.
  # @!attribute [rw] display_name
  #   @return [::String]
  #     Required. User friendly display name of the access group.
  #     Eg. "Analyst", "Developer", etc.
  # @!attribute [rw] description
  #   @return [::String]
  #     Optional. Description of the access group.
  # @!attribute [rw] principal
  #   @return [::Google::Cloud::Dataplex::V1::DataProduct::Principal]
  #     Required. The principal entity associated with this access group.
  class AccessGroup
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration for access approval for the data product.
  # @!attribute [rw] approver_emails
  #   @return [::Array<::String>]
  #     Optional. Specifies the email addresses of users who are potential
  #     approvers and are notified when an access request is made for the data
  #     product. The maximum number of emails allowed is 10.
  class AccessApprovalConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dataplex::V1::DataProduct::AccessGroup]
  class AccessGroupsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#access_groups::Google::Protobuf::Map{::String => ::Google::Cloud::Dataplex::V1::DataProduct::AccessGroup}

Returns Optional. Data product access groups by access group id as key. If data product is used only for packaging data assets, then access groups may be empty. However, if a data product is used for sharing data assets, then at least one access group must be specified.

Example:

 {
   "analyst": {
     "id": "analyst",
     "displayName": "Analyst",
     "description": "Access group for analysts",
     "principal": {
       "googleGroup": "analysts@example.com"
     }
   }
 }
 ```.

Returns:

  • (::Google::Protobuf::Map{::String => ::Google::Cloud::Dataplex::V1::DataProduct::AccessGroup})

    Optional. Data product access groups by access group id as key. If data product is used only for packaging data assets, then access groups may be empty. However, if a data product is used for sharing data assets, then at least one access group must be specified.

    Example:

     {
       "analyst": {
         "id": "analyst",
         "displayName": "Analyst",
         "description": "Access group for analysts",
         "principal": {
           "googleGroup": "analysts@example.com"
         }
       }
     }
    


101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 101

class DataProduct
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the principal entity associated with an access group, as per
  # https://cloud.google.com/iam/docs/principals-overview.
  # @!attribute [rw] google_group
  #   @return [::String]
  #     Optional. Email of the Google Group, as per
  #     https://cloud.google.com/iam/docs/principals-overview#google-group.
  # @!attribute [rw] service_account
  #   @return [::String]
  #     Optional. Specifies the email of the producer service account, as per
  #     https://cloud.google.com/iam/docs/principals-overview#service-account.
  class Principal
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Custom user defined access groups at the data product level. These are used
  # for granting different levels of access (IAM roles) on the individual data
  # product's data assets.
  # @!attribute [rw] id
  #   @return [::String]
  #     Required. Unique identifier of the access group within the data product.
  #     User defined. Eg. "analyst", "developer", etc.
  # @!attribute [rw] display_name
  #   @return [::String]
  #     Required. User friendly display name of the access group.
  #     Eg. "Analyst", "Developer", etc.
  # @!attribute [rw] description
  #   @return [::String]
  #     Optional. Description of the access group.
  # @!attribute [rw] principal
  #   @return [::Google::Cloud::Dataplex::V1::DataProduct::Principal]
  #     Required. The principal entity associated with this access group.
  class AccessGroup
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration for access approval for the data product.
  # @!attribute [rw] approver_emails
  #   @return [::Array<::String>]
  #     Optional. Specifies the email addresses of users who are potential
  #     approvers and are notified when an access request is made for the data
  #     product. The maximum number of emails allowed is 10.
  class AccessApprovalConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dataplex::V1::DataProduct::AccessGroup]
  class AccessGroupsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#asset_count::Integer (readonly)

Returns Output only. Number of data assets associated with this data product.

Returns:

  • (::Integer)

    Output only. Number of data assets associated with this data product.



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 101

class DataProduct
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the principal entity associated with an access group, as per
  # https://cloud.google.com/iam/docs/principals-overview.
  # @!attribute [rw] google_group
  #   @return [::String]
  #     Optional. Email of the Google Group, as per
  #     https://cloud.google.com/iam/docs/principals-overview#google-group.
  # @!attribute [rw] service_account
  #   @return [::String]
  #     Optional. Specifies the email of the producer service account, as per
  #     https://cloud.google.com/iam/docs/principals-overview#service-account.
  class Principal
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Custom user defined access groups at the data product level. These are used
  # for granting different levels of access (IAM roles) on the individual data
  # product's data assets.
  # @!attribute [rw] id
  #   @return [::String]
  #     Required. Unique identifier of the access group within the data product.
  #     User defined. Eg. "analyst", "developer", etc.
  # @!attribute [rw] display_name
  #   @return [::String]
  #     Required. User friendly display name of the access group.
  #     Eg. "Analyst", "Developer", etc.
  # @!attribute [rw] description
  #   @return [::String]
  #     Optional. Description of the access group.
  # @!attribute [rw] principal
  #   @return [::Google::Cloud::Dataplex::V1::DataProduct::Principal]
  #     Required. The principal entity associated with this access group.
  class AccessGroup
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration for access approval for the data product.
  # @!attribute [rw] approver_emails
  #   @return [::Array<::String>]
  #     Optional. Specifies the email addresses of users who are potential
  #     approvers and are notified when an access request is made for the data
  #     product. The maximum number of emails allowed is 10.
  class AccessApprovalConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dataplex::V1::DataProduct::AccessGroup]
  class AccessGroupsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time at which the data product was created.

Returns:



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 101

class DataProduct
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the principal entity associated with an access group, as per
  # https://cloud.google.com/iam/docs/principals-overview.
  # @!attribute [rw] google_group
  #   @return [::String]
  #     Optional. Email of the Google Group, as per
  #     https://cloud.google.com/iam/docs/principals-overview#google-group.
  # @!attribute [rw] service_account
  #   @return [::String]
  #     Optional. Specifies the email of the producer service account, as per
  #     https://cloud.google.com/iam/docs/principals-overview#service-account.
  class Principal
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Custom user defined access groups at the data product level. These are used
  # for granting different levels of access (IAM roles) on the individual data
  # product's data assets.
  # @!attribute [rw] id
  #   @return [::String]
  #     Required. Unique identifier of the access group within the data product.
  #     User defined. Eg. "analyst", "developer", etc.
  # @!attribute [rw] display_name
  #   @return [::String]
  #     Required. User friendly display name of the access group.
  #     Eg. "Analyst", "Developer", etc.
  # @!attribute [rw] description
  #   @return [::String]
  #     Optional. Description of the access group.
  # @!attribute [rw] principal
  #   @return [::Google::Cloud::Dataplex::V1::DataProduct::Principal]
  #     Required. The principal entity associated with this access group.
  class AccessGroup
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration for access approval for the data product.
  # @!attribute [rw] approver_emails
  #   @return [::Array<::String>]
  #     Optional. Specifies the email addresses of users who are potential
  #     approvers and are notified when an access request is made for the data
  #     product. The maximum number of emails allowed is 10.
  class AccessApprovalConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dataplex::V1::DataProduct::AccessGroup]
  class AccessGroupsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#description::String

Returns Optional. Description of the data product.

Returns:

  • (::String)

    Optional. Description of the data product.



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 101

class DataProduct
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the principal entity associated with an access group, as per
  # https://cloud.google.com/iam/docs/principals-overview.
  # @!attribute [rw] google_group
  #   @return [::String]
  #     Optional. Email of the Google Group, as per
  #     https://cloud.google.com/iam/docs/principals-overview#google-group.
  # @!attribute [rw] service_account
  #   @return [::String]
  #     Optional. Specifies the email of the producer service account, as per
  #     https://cloud.google.com/iam/docs/principals-overview#service-account.
  class Principal
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Custom user defined access groups at the data product level. These are used
  # for granting different levels of access (IAM roles) on the individual data
  # product's data assets.
  # @!attribute [rw] id
  #   @return [::String]
  #     Required. Unique identifier of the access group within the data product.
  #     User defined. Eg. "analyst", "developer", etc.
  # @!attribute [rw] display_name
  #   @return [::String]
  #     Required. User friendly display name of the access group.
  #     Eg. "Analyst", "Developer", etc.
  # @!attribute [rw] description
  #   @return [::String]
  #     Optional. Description of the access group.
  # @!attribute [rw] principal
  #   @return [::Google::Cloud::Dataplex::V1::DataProduct::Principal]
  #     Required. The principal entity associated with this access group.
  class AccessGroup
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration for access approval for the data product.
  # @!attribute [rw] approver_emails
  #   @return [::Array<::String>]
  #     Optional. Specifies the email addresses of users who are potential
  #     approvers and are notified when an access request is made for the data
  #     product. The maximum number of emails allowed is 10.
  class AccessApprovalConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dataplex::V1::DataProduct::AccessGroup]
  class AccessGroupsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#display_name::String

Returns Required. User-friendly display name of the data product.

Returns:

  • (::String)

    Required. User-friendly display name of the data product.



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 101

class DataProduct
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the principal entity associated with an access group, as per
  # https://cloud.google.com/iam/docs/principals-overview.
  # @!attribute [rw] google_group
  #   @return [::String]
  #     Optional. Email of the Google Group, as per
  #     https://cloud.google.com/iam/docs/principals-overview#google-group.
  # @!attribute [rw] service_account
  #   @return [::String]
  #     Optional. Specifies the email of the producer service account, as per
  #     https://cloud.google.com/iam/docs/principals-overview#service-account.
  class Principal
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Custom user defined access groups at the data product level. These are used
  # for granting different levels of access (IAM roles) on the individual data
  # product's data assets.
  # @!attribute [rw] id
  #   @return [::String]
  #     Required. Unique identifier of the access group within the data product.
  #     User defined. Eg. "analyst", "developer", etc.
  # @!attribute [rw] display_name
  #   @return [::String]
  #     Required. User friendly display name of the access group.
  #     Eg. "Analyst", "Developer", etc.
  # @!attribute [rw] description
  #   @return [::String]
  #     Optional. Description of the access group.
  # @!attribute [rw] principal
  #   @return [::Google::Cloud::Dataplex::V1::DataProduct::Principal]
  #     Required. The principal entity associated with this access group.
  class AccessGroup
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration for access approval for the data product.
  # @!attribute [rw] approver_emails
  #   @return [::Array<::String>]
  #     Optional. Specifies the email addresses of users who are potential
  #     approvers and are notified when an access request is made for the data
  #     product. The maximum number of emails allowed is 10.
  class AccessApprovalConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dataplex::V1::DataProduct::AccessGroup]
  class AccessGroupsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#etag::String

Returns Optional. This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.

Returns:

  • (::String)

    Optional. This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 101

class DataProduct
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the principal entity associated with an access group, as per
  # https://cloud.google.com/iam/docs/principals-overview.
  # @!attribute [rw] google_group
  #   @return [::String]
  #     Optional. Email of the Google Group, as per
  #     https://cloud.google.com/iam/docs/principals-overview#google-group.
  # @!attribute [rw] service_account
  #   @return [::String]
  #     Optional. Specifies the email of the producer service account, as per
  #     https://cloud.google.com/iam/docs/principals-overview#service-account.
  class Principal
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Custom user defined access groups at the data product level. These are used
  # for granting different levels of access (IAM roles) on the individual data
  # product's data assets.
  # @!attribute [rw] id
  #   @return [::String]
  #     Required. Unique identifier of the access group within the data product.
  #     User defined. Eg. "analyst", "developer", etc.
  # @!attribute [rw] display_name
  #   @return [::String]
  #     Required. User friendly display name of the access group.
  #     Eg. "Analyst", "Developer", etc.
  # @!attribute [rw] description
  #   @return [::String]
  #     Optional. Description of the access group.
  # @!attribute [rw] principal
  #   @return [::Google::Cloud::Dataplex::V1::DataProduct::Principal]
  #     Required. The principal entity associated with this access group.
  class AccessGroup
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration for access approval for the data product.
  # @!attribute [rw] approver_emails
  #   @return [::Array<::String>]
  #     Optional. Specifies the email addresses of users who are potential
  #     approvers and are notified when an access request is made for the data
  #     product. The maximum number of emails allowed is 10.
  class AccessApprovalConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dataplex::V1::DataProduct::AccessGroup]
  class AccessGroupsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#icon::String

Returns Optional. Base64 encoded image representing the data product. Max Size: 3.0MiB Expected image dimensions are 512x512 pixels, however the API only performs validation on size of the encoded data. Note: For byte fields, the content of the fields are base64-encoded (which increases the size of the data by 33-36%) when using JSON on the wire.

Returns:

  • (::String)

    Optional. Base64 encoded image representing the data product. Max Size: 3.0MiB Expected image dimensions are 512x512 pixels, however the API only performs validation on size of the encoded data. Note: For byte fields, the content of the fields are base64-encoded (which increases the size of the data by 33-36%) when using JSON on the wire.



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 101

class DataProduct
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the principal entity associated with an access group, as per
  # https://cloud.google.com/iam/docs/principals-overview.
  # @!attribute [rw] google_group
  #   @return [::String]
  #     Optional. Email of the Google Group, as per
  #     https://cloud.google.com/iam/docs/principals-overview#google-group.
  # @!attribute [rw] service_account
  #   @return [::String]
  #     Optional. Specifies the email of the producer service account, as per
  #     https://cloud.google.com/iam/docs/principals-overview#service-account.
  class Principal
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Custom user defined access groups at the data product level. These are used
  # for granting different levels of access (IAM roles) on the individual data
  # product's data assets.
  # @!attribute [rw] id
  #   @return [::String]
  #     Required. Unique identifier of the access group within the data product.
  #     User defined. Eg. "analyst", "developer", etc.
  # @!attribute [rw] display_name
  #   @return [::String]
  #     Required. User friendly display name of the access group.
  #     Eg. "Analyst", "Developer", etc.
  # @!attribute [rw] description
  #   @return [::String]
  #     Optional. Description of the access group.
  # @!attribute [rw] principal
  #   @return [::Google::Cloud::Dataplex::V1::DataProduct::Principal]
  #     Required. The principal entity associated with this access group.
  class AccessGroup
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration for access approval for the data product.
  # @!attribute [rw] approver_emails
  #   @return [::Array<::String>]
  #     Optional. Specifies the email addresses of users who are potential
  #     approvers and are notified when an access request is made for the data
  #     product. The maximum number of emails allowed is 10.
  class AccessApprovalConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dataplex::V1::DataProduct::AccessGroup]
  class AccessGroupsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#labels::Google::Protobuf::Map{::String => ::String}

Returns Optional. User-defined labels for the data product.

Example:

 {
   "environment": "production",
   "billing": "marketing-department"
 }
 ```.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional. User-defined labels for the data product.

    Example:

     {
       "environment": "production",
       "billing": "marketing-department"
     }
    


101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 101

class DataProduct
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the principal entity associated with an access group, as per
  # https://cloud.google.com/iam/docs/principals-overview.
  # @!attribute [rw] google_group
  #   @return [::String]
  #     Optional. Email of the Google Group, as per
  #     https://cloud.google.com/iam/docs/principals-overview#google-group.
  # @!attribute [rw] service_account
  #   @return [::String]
  #     Optional. Specifies the email of the producer service account, as per
  #     https://cloud.google.com/iam/docs/principals-overview#service-account.
  class Principal
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Custom user defined access groups at the data product level. These are used
  # for granting different levels of access (IAM roles) on the individual data
  # product's data assets.
  # @!attribute [rw] id
  #   @return [::String]
  #     Required. Unique identifier of the access group within the data product.
  #     User defined. Eg. "analyst", "developer", etc.
  # @!attribute [rw] display_name
  #   @return [::String]
  #     Required. User friendly display name of the access group.
  #     Eg. "Analyst", "Developer", etc.
  # @!attribute [rw] description
  #   @return [::String]
  #     Optional. Description of the access group.
  # @!attribute [rw] principal
  #   @return [::Google::Cloud::Dataplex::V1::DataProduct::Principal]
  #     Required. The principal entity associated with this access group.
  class AccessGroup
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration for access approval for the data product.
  # @!attribute [rw] approver_emails
  #   @return [::Array<::String>]
  #     Optional. Specifies the email addresses of users who are potential
  #     approvers and are notified when an access request is made for the data
  #     product. The maximum number of emails allowed is 10.
  class AccessApprovalConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dataplex::V1::DataProduct::AccessGroup]
  class AccessGroupsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#name::String

Returns Identifier. Resource name of the data product. Format: projects/{project_id_or_number}/locations/{location_id}/dataProducts/{data_product_id}.

Returns:

  • (::String)

    Identifier. Resource name of the data product. Format: projects/{project_id_or_number}/locations/{location_id}/dataProducts/{data_product_id}.



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 101

class DataProduct
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the principal entity associated with an access group, as per
  # https://cloud.google.com/iam/docs/principals-overview.
  # @!attribute [rw] google_group
  #   @return [::String]
  #     Optional. Email of the Google Group, as per
  #     https://cloud.google.com/iam/docs/principals-overview#google-group.
  # @!attribute [rw] service_account
  #   @return [::String]
  #     Optional. Specifies the email of the producer service account, as per
  #     https://cloud.google.com/iam/docs/principals-overview#service-account.
  class Principal
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Custom user defined access groups at the data product level. These are used
  # for granting different levels of access (IAM roles) on the individual data
  # product's data assets.
  # @!attribute [rw] id
  #   @return [::String]
  #     Required. Unique identifier of the access group within the data product.
  #     User defined. Eg. "analyst", "developer", etc.
  # @!attribute [rw] display_name
  #   @return [::String]
  #     Required. User friendly display name of the access group.
  #     Eg. "Analyst", "Developer", etc.
  # @!attribute [rw] description
  #   @return [::String]
  #     Optional. Description of the access group.
  # @!attribute [rw] principal
  #   @return [::Google::Cloud::Dataplex::V1::DataProduct::Principal]
  #     Required. The principal entity associated with this access group.
  class AccessGroup
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration for access approval for the data product.
  # @!attribute [rw] approver_emails
  #   @return [::Array<::String>]
  #     Optional. Specifies the email addresses of users who are potential
  #     approvers and are notified when an access request is made for the data
  #     product. The maximum number of emails allowed is 10.
  class AccessApprovalConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dataplex::V1::DataProduct::AccessGroup]
  class AccessGroupsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#owner_emails::Array<::String>

Returns Required. Emails of the data product owners.

Returns:

  • (::Array<::String>)

    Required. Emails of the data product owners.



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 101

class DataProduct
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the principal entity associated with an access group, as per
  # https://cloud.google.com/iam/docs/principals-overview.
  # @!attribute [rw] google_group
  #   @return [::String]
  #     Optional. Email of the Google Group, as per
  #     https://cloud.google.com/iam/docs/principals-overview#google-group.
  # @!attribute [rw] service_account
  #   @return [::String]
  #     Optional. Specifies the email of the producer service account, as per
  #     https://cloud.google.com/iam/docs/principals-overview#service-account.
  class Principal
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Custom user defined access groups at the data product level. These are used
  # for granting different levels of access (IAM roles) on the individual data
  # product's data assets.
  # @!attribute [rw] id
  #   @return [::String]
  #     Required. Unique identifier of the access group within the data product.
  #     User defined. Eg. "analyst", "developer", etc.
  # @!attribute [rw] display_name
  #   @return [::String]
  #     Required. User friendly display name of the access group.
  #     Eg. "Analyst", "Developer", etc.
  # @!attribute [rw] description
  #   @return [::String]
  #     Optional. Description of the access group.
  # @!attribute [rw] principal
  #   @return [::Google::Cloud::Dataplex::V1::DataProduct::Principal]
  #     Required. The principal entity associated with this access group.
  class AccessGroup
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration for access approval for the data product.
  # @!attribute [rw] approver_emails
  #   @return [::Array<::String>]
  #     Optional. Specifies the email addresses of users who are potential
  #     approvers and are notified when an access request is made for the data
  #     product. The maximum number of emails allowed is 10.
  class AccessApprovalConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dataplex::V1::DataProduct::AccessGroup]
  class AccessGroupsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#uid::String (readonly)

Returns Output only. System generated unique ID for the data product. This ID will be different if the data product is deleted and re-created with the same name.

Returns:

  • (::String)

    Output only. System generated unique ID for the data product. This ID will be different if the data product is deleted and re-created with the same name.



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 101

class DataProduct
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the principal entity associated with an access group, as per
  # https://cloud.google.com/iam/docs/principals-overview.
  # @!attribute [rw] google_group
  #   @return [::String]
  #     Optional. Email of the Google Group, as per
  #     https://cloud.google.com/iam/docs/principals-overview#google-group.
  # @!attribute [rw] service_account
  #   @return [::String]
  #     Optional. Specifies the email of the producer service account, as per
  #     https://cloud.google.com/iam/docs/principals-overview#service-account.
  class Principal
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Custom user defined access groups at the data product level. These are used
  # for granting different levels of access (IAM roles) on the individual data
  # product's data assets.
  # @!attribute [rw] id
  #   @return [::String]
  #     Required. Unique identifier of the access group within the data product.
  #     User defined. Eg. "analyst", "developer", etc.
  # @!attribute [rw] display_name
  #   @return [::String]
  #     Required. User friendly display name of the access group.
  #     Eg. "Analyst", "Developer", etc.
  # @!attribute [rw] description
  #   @return [::String]
  #     Optional. Description of the access group.
  # @!attribute [rw] principal
  #   @return [::Google::Cloud::Dataplex::V1::DataProduct::Principal]
  #     Required. The principal entity associated with this access group.
  class AccessGroup
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration for access approval for the data product.
  # @!attribute [rw] approver_emails
  #   @return [::Array<::String>]
  #     Optional. Specifies the email addresses of users who are potential
  #     approvers and are notified when an access request is made for the data
  #     product. The maximum number of emails allowed is 10.
  class AccessApprovalConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dataplex::V1::DataProduct::AccessGroup]
  class AccessGroupsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time at which the data product was last updated.

Returns:



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 101

class DataProduct
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the principal entity associated with an access group, as per
  # https://cloud.google.com/iam/docs/principals-overview.
  # @!attribute [rw] google_group
  #   @return [::String]
  #     Optional. Email of the Google Group, as per
  #     https://cloud.google.com/iam/docs/principals-overview#google-group.
  # @!attribute [rw] service_account
  #   @return [::String]
  #     Optional. Specifies the email of the producer service account, as per
  #     https://cloud.google.com/iam/docs/principals-overview#service-account.
  class Principal
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Custom user defined access groups at the data product level. These are used
  # for granting different levels of access (IAM roles) on the individual data
  # product's data assets.
  # @!attribute [rw] id
  #   @return [::String]
  #     Required. Unique identifier of the access group within the data product.
  #     User defined. Eg. "analyst", "developer", etc.
  # @!attribute [rw] display_name
  #   @return [::String]
  #     Required. User friendly display name of the access group.
  #     Eg. "Analyst", "Developer", etc.
  # @!attribute [rw] description
  #   @return [::String]
  #     Optional. Description of the access group.
  # @!attribute [rw] principal
  #   @return [::Google::Cloud::Dataplex::V1::DataProduct::Principal]
  #     Required. The principal entity associated with this access group.
  class AccessGroup
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration for access approval for the data product.
  # @!attribute [rw] approver_emails
  #   @return [::Array<::String>]
  #     Optional. Specifies the email addresses of users who are potential
  #     approvers and are notified when an access request is made for the data
  #     product. The maximum number of emails allowed is 10.
  class AccessApprovalConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dataplex::V1::DataProduct::AccessGroup]
  class AccessGroupsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end