Class: Google::Cloud::Dataplex::V1::DataProduct::AccessGroup

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataplex/v1/data_products.rb

Overview

Custom user defined access groups at the data product level. These are used for granting different levels of access (IAM roles) on the individual data product's data assets.

Instance Attribute Summary collapse

Instance Attribute Details

#description::String

Returns Optional. Description of the access group.

Returns:

  • (::String)

    Optional. Description of the access group.



137
138
139
140
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 137

class AccessGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#display_name::String

Returns Required. User friendly display name of the access group. Eg. "Analyst", "Developer", etc.

Returns:

  • (::String)

    Required. User friendly display name of the access group. Eg. "Analyst", "Developer", etc.



137
138
139
140
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 137

class AccessGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#id::String

Returns Required. Unique identifier of the access group within the data product. User defined. Eg. "analyst", "developer", etc.

Returns:

  • (::String)

    Required. Unique identifier of the access group within the data product. User defined. Eg. "analyst", "developer", etc.



137
138
139
140
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 137

class AccessGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#principal::Google::Cloud::Dataplex::V1::DataProduct::Principal

Returns Required. The principal entity associated with this access group.

Returns:



137
138
139
140
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 137

class AccessGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end