Class: Google::Cloud::Dataplex::V1::DataProfileResult::PostScanActionsResult

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataplex/v1/data_profile.rb

Overview

The result of post scan actions of DataProfileScan job.

Defined Under Namespace

Classes: BigQueryExportResult

Instance Attribute Summary collapse

Instance Attribute Details

#bigquery_export_result::Google::Cloud::Dataplex::V1::DataProfileResult::PostScanActionsResult::BigQueryExportResult (readonly)

Returns Output only. The result of BigQuery export post scan action.

Returns:



325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
# File 'proto_docs/google/cloud/dataplex/v1/data_profile.rb', line 325

class PostScanActionsResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The result of BigQuery export post scan action.
  # @!attribute [r] state
  #   @return [::Google::Cloud::Dataplex::V1::DataProfileResult::PostScanActionsResult::BigQueryExportResult::State]
  #     Output only. Execution state for the BigQuery exporting.
  # @!attribute [r] message
  #   @return [::String]
  #     Output only. Additional information about the BigQuery exporting.
  class BigQueryExportResult
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Execution state for the exporting.
    module State
      # The exporting state is unspecified.
      STATE_UNSPECIFIED = 0

      # The exporting completed successfully.
      SUCCEEDED = 1

      # The exporting is no longer running due to an error.
      FAILED = 2

      # The exporting is skipped due to no valid scan result to export
      # (usually caused by scan failed).
      SKIPPED = 3
    end
  end
end