Class: Google::Cloud::Dataplex::V1::DataQualityResult
- Inherits:
-
Object
- Object
- Google::Cloud::Dataplex::V1::DataQualityResult
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataplex/v1/data_quality.rb
Overview
The output of a DataQualityScan.
Defined Under Namespace
Classes: AnomalyDetectionGeneratedAssets, PostScanActionsResult
Instance Attribute Summary collapse
-
#anomaly_detection_generated_assets ⇒ ::Google::Cloud::Dataplex::V1::DataQualityResult::AnomalyDetectionGeneratedAssets
readonly
Output only.
-
#catalog_publishing_status ⇒ ::Google::Cloud::Dataplex::V1::DataScanCatalogPublishingStatus
readonly
Output only.
-
#columns ⇒ ::Array<::Google::Cloud::Dataplex::V1::DataQualityColumnResult>
readonly
Output only.
-
#dimensions ⇒ ::Array<::Google::Cloud::Dataplex::V1::DataQualityDimensionResult>
readonly
Output only.
-
#passed ⇒ ::Boolean
readonly
Output only.
-
#post_scan_actions_result ⇒ ::Google::Cloud::Dataplex::V1::DataQualityResult::PostScanActionsResult
readonly
Output only.
-
#row_count ⇒ ::Integer
readonly
Output only.
-
#rules ⇒ ::Array<::Google::Cloud::Dataplex::V1::DataQualityRuleResult>
readonly
Output only.
-
#scanned_data ⇒ ::Google::Cloud::Dataplex::V1::ScannedData
readonly
Output only.
-
#score ⇒ ::Float
readonly
Output only.
Instance Attribute Details
#anomaly_detection_generated_assets ⇒ ::Google::Cloud::Dataplex::V1::DataQualityResult::AnomalyDetectionGeneratedAssets (readonly)
Returns Output only. The generated assets for anomaly detection.
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'proto_docs/google/cloud/dataplex/v1/data_quality.rb', line 200 class DataQualityResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The result of post scan actions of DataQualityScan job. # @!attribute [r] bigquery_export_result # @return [::Google::Cloud::Dataplex::V1::DataQualityResult::PostScanActionsResult::BigQueryExportResult] # Output only. The result of BigQuery export post scan action. class PostScanActionsResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The result of BigQuery export post scan action. # @!attribute [r] state # @return [::Google::Cloud::Dataplex::V1::DataQualityResult::PostScanActionsResult::BigQueryExportResult::State] # Output only. Execution state for the BigQuery exporting. # @!attribute [r] message # @return [::String] # Output only. Additional information about the BigQuery exporting. class BigQueryExportResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Execution state for the exporting. module State # The exporting state is unspecified. STATE_UNSPECIFIED = 0 # The exporting completed successfully. SUCCEEDED = 1 # The exporting is no longer running due to an error. FAILED = 2 # The exporting is skipped due to no valid scan result to export # (usually caused by scan failed). SKIPPED = 3 end end end # The assets generated by Anomaly Detection Data Scan. # @!attribute [r] result_table # @return [::String] # Output only. The result table for anomaly detection. # Format: # PROJECT_ID.DATASET_ID.TABLE_ID # If the result table is set at AnomalyDetectionAssets, the result table # here would be the same as the one set in the # AnomalyDetectionAssets.result_table. # @!attribute [r] data_intermediate_table # @return [::String] # Output only. The intermediate table for data anomaly detection. # Format: # PROJECT_ID.DATASET_ID.TABLE_ID # @!attribute [r] freshness_intermediate_table # @return [::String] # Output only. The intermediate table for freshness anomaly detection. # Format: # PROJECT_ID.DATASET_ID.TABLE_ID # @!attribute [r] volume_intermediate_table # @return [::String] # Output only. The intermediate table for volume anomaly detection. # Format: # PROJECT_ID.DATASET_ID.TABLE_ID class AnomalyDetectionGeneratedAssets include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#catalog_publishing_status ⇒ ::Google::Cloud::Dataplex::V1::DataScanCatalogPublishingStatus (readonly)
Returns Output only. The status of publishing the data scan as Dataplex Universal Catalog metadata.
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'proto_docs/google/cloud/dataplex/v1/data_quality.rb', line 200 class DataQualityResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The result of post scan actions of DataQualityScan job. # @!attribute [r] bigquery_export_result # @return [::Google::Cloud::Dataplex::V1::DataQualityResult::PostScanActionsResult::BigQueryExportResult] # Output only. The result of BigQuery export post scan action. class PostScanActionsResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The result of BigQuery export post scan action. # @!attribute [r] state # @return [::Google::Cloud::Dataplex::V1::DataQualityResult::PostScanActionsResult::BigQueryExportResult::State] # Output only. Execution state for the BigQuery exporting. # @!attribute [r] message # @return [::String] # Output only. Additional information about the BigQuery exporting. class BigQueryExportResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Execution state for the exporting. module State # The exporting state is unspecified. STATE_UNSPECIFIED = 0 # The exporting completed successfully. SUCCEEDED = 1 # The exporting is no longer running due to an error. FAILED = 2 # The exporting is skipped due to no valid scan result to export # (usually caused by scan failed). SKIPPED = 3 end end end # The assets generated by Anomaly Detection Data Scan. # @!attribute [r] result_table # @return [::String] # Output only. The result table for anomaly detection. # Format: # PROJECT_ID.DATASET_ID.TABLE_ID # If the result table is set at AnomalyDetectionAssets, the result table # here would be the same as the one set in the # AnomalyDetectionAssets.result_table. # @!attribute [r] data_intermediate_table # @return [::String] # Output only. The intermediate table for data anomaly detection. # Format: # PROJECT_ID.DATASET_ID.TABLE_ID # @!attribute [r] freshness_intermediate_table # @return [::String] # Output only. The intermediate table for freshness anomaly detection. # Format: # PROJECT_ID.DATASET_ID.TABLE_ID # @!attribute [r] volume_intermediate_table # @return [::String] # Output only. The intermediate table for volume anomaly detection. # Format: # PROJECT_ID.DATASET_ID.TABLE_ID class AnomalyDetectionGeneratedAssets include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#columns ⇒ ::Array<::Google::Cloud::Dataplex::V1::DataQualityColumnResult> (readonly)
Returns Output only. A list of results at the column level.
A column will have a corresponding DataQualityColumnResult if and only if
there is at least one rule with the 'column' field set to it.
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'proto_docs/google/cloud/dataplex/v1/data_quality.rb', line 200 class DataQualityResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The result of post scan actions of DataQualityScan job. # @!attribute [r] bigquery_export_result # @return [::Google::Cloud::Dataplex::V1::DataQualityResult::PostScanActionsResult::BigQueryExportResult] # Output only. The result of BigQuery export post scan action. class PostScanActionsResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The result of BigQuery export post scan action. # @!attribute [r] state # @return [::Google::Cloud::Dataplex::V1::DataQualityResult::PostScanActionsResult::BigQueryExportResult::State] # Output only. Execution state for the BigQuery exporting. # @!attribute [r] message # @return [::String] # Output only. Additional information about the BigQuery exporting. class BigQueryExportResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Execution state for the exporting. module State # The exporting state is unspecified. STATE_UNSPECIFIED = 0 # The exporting completed successfully. SUCCEEDED = 1 # The exporting is no longer running due to an error. FAILED = 2 # The exporting is skipped due to no valid scan result to export # (usually caused by scan failed). SKIPPED = 3 end end end # The assets generated by Anomaly Detection Data Scan. # @!attribute [r] result_table # @return [::String] # Output only. The result table for anomaly detection. # Format: # PROJECT_ID.DATASET_ID.TABLE_ID # If the result table is set at AnomalyDetectionAssets, the result table # here would be the same as the one set in the # AnomalyDetectionAssets.result_table. # @!attribute [r] data_intermediate_table # @return [::String] # Output only. The intermediate table for data anomaly detection. # Format: # PROJECT_ID.DATASET_ID.TABLE_ID # @!attribute [r] freshness_intermediate_table # @return [::String] # Output only. The intermediate table for freshness anomaly detection. # Format: # PROJECT_ID.DATASET_ID.TABLE_ID # @!attribute [r] volume_intermediate_table # @return [::String] # Output only. The intermediate table for volume anomaly detection. # Format: # PROJECT_ID.DATASET_ID.TABLE_ID class AnomalyDetectionGeneratedAssets include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#dimensions ⇒ ::Array<::Google::Cloud::Dataplex::V1::DataQualityDimensionResult> (readonly)
Returns Output only. A list of results at the dimension level.
A dimension will have a corresponding DataQualityDimensionResult if and
only if there is at least one rule with the 'dimension' field set to it.
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'proto_docs/google/cloud/dataplex/v1/data_quality.rb', line 200 class DataQualityResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The result of post scan actions of DataQualityScan job. # @!attribute [r] bigquery_export_result # @return [::Google::Cloud::Dataplex::V1::DataQualityResult::PostScanActionsResult::BigQueryExportResult] # Output only. The result of BigQuery export post scan action. class PostScanActionsResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The result of BigQuery export post scan action. # @!attribute [r] state # @return [::Google::Cloud::Dataplex::V1::DataQualityResult::PostScanActionsResult::BigQueryExportResult::State] # Output only. Execution state for the BigQuery exporting. # @!attribute [r] message # @return [::String] # Output only. Additional information about the BigQuery exporting. class BigQueryExportResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Execution state for the exporting. module State # The exporting state is unspecified. STATE_UNSPECIFIED = 0 # The exporting completed successfully. SUCCEEDED = 1 # The exporting is no longer running due to an error. FAILED = 2 # The exporting is skipped due to no valid scan result to export # (usually caused by scan failed). SKIPPED = 3 end end end # The assets generated by Anomaly Detection Data Scan. # @!attribute [r] result_table # @return [::String] # Output only. The result table for anomaly detection. # Format: # PROJECT_ID.DATASET_ID.TABLE_ID # If the result table is set at AnomalyDetectionAssets, the result table # here would be the same as the one set in the # AnomalyDetectionAssets.result_table. # @!attribute [r] data_intermediate_table # @return [::String] # Output only. The intermediate table for data anomaly detection. # Format: # PROJECT_ID.DATASET_ID.TABLE_ID # @!attribute [r] freshness_intermediate_table # @return [::String] # Output only. The intermediate table for freshness anomaly detection. # Format: # PROJECT_ID.DATASET_ID.TABLE_ID # @!attribute [r] volume_intermediate_table # @return [::String] # Output only. The intermediate table for volume anomaly detection. # Format: # PROJECT_ID.DATASET_ID.TABLE_ID class AnomalyDetectionGeneratedAssets include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#passed ⇒ ::Boolean (readonly)
Returns Output only. Overall data quality result -- true if all rules passed.
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'proto_docs/google/cloud/dataplex/v1/data_quality.rb', line 200 class DataQualityResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The result of post scan actions of DataQualityScan job. # @!attribute [r] bigquery_export_result # @return [::Google::Cloud::Dataplex::V1::DataQualityResult::PostScanActionsResult::BigQueryExportResult] # Output only. The result of BigQuery export post scan action. class PostScanActionsResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The result of BigQuery export post scan action. # @!attribute [r] state # @return [::Google::Cloud::Dataplex::V1::DataQualityResult::PostScanActionsResult::BigQueryExportResult::State] # Output only. Execution state for the BigQuery exporting. # @!attribute [r] message # @return [::String] # Output only. Additional information about the BigQuery exporting. class BigQueryExportResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Execution state for the exporting. module State # The exporting state is unspecified. STATE_UNSPECIFIED = 0 # The exporting completed successfully. SUCCEEDED = 1 # The exporting is no longer running due to an error. FAILED = 2 # The exporting is skipped due to no valid scan result to export # (usually caused by scan failed). SKIPPED = 3 end end end # The assets generated by Anomaly Detection Data Scan. # @!attribute [r] result_table # @return [::String] # Output only. The result table for anomaly detection. # Format: # PROJECT_ID.DATASET_ID.TABLE_ID # If the result table is set at AnomalyDetectionAssets, the result table # here would be the same as the one set in the # AnomalyDetectionAssets.result_table. # @!attribute [r] data_intermediate_table # @return [::String] # Output only. The intermediate table for data anomaly detection. # Format: # PROJECT_ID.DATASET_ID.TABLE_ID # @!attribute [r] freshness_intermediate_table # @return [::String] # Output only. The intermediate table for freshness anomaly detection. # Format: # PROJECT_ID.DATASET_ID.TABLE_ID # @!attribute [r] volume_intermediate_table # @return [::String] # Output only. The intermediate table for volume anomaly detection. # Format: # PROJECT_ID.DATASET_ID.TABLE_ID class AnomalyDetectionGeneratedAssets include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#post_scan_actions_result ⇒ ::Google::Cloud::Dataplex::V1::DataQualityResult::PostScanActionsResult (readonly)
Returns Output only. The result of post scan actions.
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'proto_docs/google/cloud/dataplex/v1/data_quality.rb', line 200 class DataQualityResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The result of post scan actions of DataQualityScan job. # @!attribute [r] bigquery_export_result # @return [::Google::Cloud::Dataplex::V1::DataQualityResult::PostScanActionsResult::BigQueryExportResult] # Output only. The result of BigQuery export post scan action. class PostScanActionsResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The result of BigQuery export post scan action. # @!attribute [r] state # @return [::Google::Cloud::Dataplex::V1::DataQualityResult::PostScanActionsResult::BigQueryExportResult::State] # Output only. Execution state for the BigQuery exporting. # @!attribute [r] message # @return [::String] # Output only. Additional information about the BigQuery exporting. class BigQueryExportResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Execution state for the exporting. module State # The exporting state is unspecified. STATE_UNSPECIFIED = 0 # The exporting completed successfully. SUCCEEDED = 1 # The exporting is no longer running due to an error. FAILED = 2 # The exporting is skipped due to no valid scan result to export # (usually caused by scan failed). SKIPPED = 3 end end end # The assets generated by Anomaly Detection Data Scan. # @!attribute [r] result_table # @return [::String] # Output only. The result table for anomaly detection. # Format: # PROJECT_ID.DATASET_ID.TABLE_ID # If the result table is set at AnomalyDetectionAssets, the result table # here would be the same as the one set in the # AnomalyDetectionAssets.result_table. # @!attribute [r] data_intermediate_table # @return [::String] # Output only. The intermediate table for data anomaly detection. # Format: # PROJECT_ID.DATASET_ID.TABLE_ID # @!attribute [r] freshness_intermediate_table # @return [::String] # Output only. The intermediate table for freshness anomaly detection. # Format: # PROJECT_ID.DATASET_ID.TABLE_ID # @!attribute [r] volume_intermediate_table # @return [::String] # Output only. The intermediate table for volume anomaly detection. # Format: # PROJECT_ID.DATASET_ID.TABLE_ID class AnomalyDetectionGeneratedAssets include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#row_count ⇒ ::Integer (readonly)
Returns Output only. The count of rows processed.
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'proto_docs/google/cloud/dataplex/v1/data_quality.rb', line 200 class DataQualityResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The result of post scan actions of DataQualityScan job. # @!attribute [r] bigquery_export_result # @return [::Google::Cloud::Dataplex::V1::DataQualityResult::PostScanActionsResult::BigQueryExportResult] # Output only. The result of BigQuery export post scan action. class PostScanActionsResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The result of BigQuery export post scan action. # @!attribute [r] state # @return [::Google::Cloud::Dataplex::V1::DataQualityResult::PostScanActionsResult::BigQueryExportResult::State] # Output only. Execution state for the BigQuery exporting. # @!attribute [r] message # @return [::String] # Output only. Additional information about the BigQuery exporting. class BigQueryExportResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Execution state for the exporting. module State # The exporting state is unspecified. STATE_UNSPECIFIED = 0 # The exporting completed successfully. SUCCEEDED = 1 # The exporting is no longer running due to an error. FAILED = 2 # The exporting is skipped due to no valid scan result to export # (usually caused by scan failed). SKIPPED = 3 end end end # The assets generated by Anomaly Detection Data Scan. # @!attribute [r] result_table # @return [::String] # Output only. The result table for anomaly detection. # Format: # PROJECT_ID.DATASET_ID.TABLE_ID # If the result table is set at AnomalyDetectionAssets, the result table # here would be the same as the one set in the # AnomalyDetectionAssets.result_table. # @!attribute [r] data_intermediate_table # @return [::String] # Output only. The intermediate table for data anomaly detection. # Format: # PROJECT_ID.DATASET_ID.TABLE_ID # @!attribute [r] freshness_intermediate_table # @return [::String] # Output only. The intermediate table for freshness anomaly detection. # Format: # PROJECT_ID.DATASET_ID.TABLE_ID # @!attribute [r] volume_intermediate_table # @return [::String] # Output only. The intermediate table for volume anomaly detection. # Format: # PROJECT_ID.DATASET_ID.TABLE_ID class AnomalyDetectionGeneratedAssets include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#rules ⇒ ::Array<::Google::Cloud::Dataplex::V1::DataQualityRuleResult> (readonly)
Returns Output only. A list of all the rules in a job, and their results.
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'proto_docs/google/cloud/dataplex/v1/data_quality.rb', line 200 class DataQualityResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The result of post scan actions of DataQualityScan job. # @!attribute [r] bigquery_export_result # @return [::Google::Cloud::Dataplex::V1::DataQualityResult::PostScanActionsResult::BigQueryExportResult] # Output only. The result of BigQuery export post scan action. class PostScanActionsResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The result of BigQuery export post scan action. # @!attribute [r] state # @return [::Google::Cloud::Dataplex::V1::DataQualityResult::PostScanActionsResult::BigQueryExportResult::State] # Output only. Execution state for the BigQuery exporting. # @!attribute [r] message # @return [::String] # Output only. Additional information about the BigQuery exporting. class BigQueryExportResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Execution state for the exporting. module State # The exporting state is unspecified. STATE_UNSPECIFIED = 0 # The exporting completed successfully. SUCCEEDED = 1 # The exporting is no longer running due to an error. FAILED = 2 # The exporting is skipped due to no valid scan result to export # (usually caused by scan failed). SKIPPED = 3 end end end # The assets generated by Anomaly Detection Data Scan. # @!attribute [r] result_table # @return [::String] # Output only. The result table for anomaly detection. # Format: # PROJECT_ID.DATASET_ID.TABLE_ID # If the result table is set at AnomalyDetectionAssets, the result table # here would be the same as the one set in the # AnomalyDetectionAssets.result_table. # @!attribute [r] data_intermediate_table # @return [::String] # Output only. The intermediate table for data anomaly detection. # Format: # PROJECT_ID.DATASET_ID.TABLE_ID # @!attribute [r] freshness_intermediate_table # @return [::String] # Output only. The intermediate table for freshness anomaly detection. # Format: # PROJECT_ID.DATASET_ID.TABLE_ID # @!attribute [r] volume_intermediate_table # @return [::String] # Output only. The intermediate table for volume anomaly detection. # Format: # PROJECT_ID.DATASET_ID.TABLE_ID class AnomalyDetectionGeneratedAssets include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#scanned_data ⇒ ::Google::Cloud::Dataplex::V1::ScannedData (readonly)
Returns Output only. The data scanned for this result.
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'proto_docs/google/cloud/dataplex/v1/data_quality.rb', line 200 class DataQualityResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The result of post scan actions of DataQualityScan job. # @!attribute [r] bigquery_export_result # @return [::Google::Cloud::Dataplex::V1::DataQualityResult::PostScanActionsResult::BigQueryExportResult] # Output only. The result of BigQuery export post scan action. class PostScanActionsResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The result of BigQuery export post scan action. # @!attribute [r] state # @return [::Google::Cloud::Dataplex::V1::DataQualityResult::PostScanActionsResult::BigQueryExportResult::State] # Output only. Execution state for the BigQuery exporting. # @!attribute [r] message # @return [::String] # Output only. Additional information about the BigQuery exporting. class BigQueryExportResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Execution state for the exporting. module State # The exporting state is unspecified. STATE_UNSPECIFIED = 0 # The exporting completed successfully. SUCCEEDED = 1 # The exporting is no longer running due to an error. FAILED = 2 # The exporting is skipped due to no valid scan result to export # (usually caused by scan failed). SKIPPED = 3 end end end # The assets generated by Anomaly Detection Data Scan. # @!attribute [r] result_table # @return [::String] # Output only. The result table for anomaly detection. # Format: # PROJECT_ID.DATASET_ID.TABLE_ID # If the result table is set at AnomalyDetectionAssets, the result table # here would be the same as the one set in the # AnomalyDetectionAssets.result_table. # @!attribute [r] data_intermediate_table # @return [::String] # Output only. The intermediate table for data anomaly detection. # Format: # PROJECT_ID.DATASET_ID.TABLE_ID # @!attribute [r] freshness_intermediate_table # @return [::String] # Output only. The intermediate table for freshness anomaly detection. # Format: # PROJECT_ID.DATASET_ID.TABLE_ID # @!attribute [r] volume_intermediate_table # @return [::String] # Output only. The intermediate table for volume anomaly detection. # Format: # PROJECT_ID.DATASET_ID.TABLE_ID class AnomalyDetectionGeneratedAssets include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#score ⇒ ::Float (readonly)
Returns Output only. The overall data quality score.
The score ranges between 0, 100.
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'proto_docs/google/cloud/dataplex/v1/data_quality.rb', line 200 class DataQualityResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The result of post scan actions of DataQualityScan job. # @!attribute [r] bigquery_export_result # @return [::Google::Cloud::Dataplex::V1::DataQualityResult::PostScanActionsResult::BigQueryExportResult] # Output only. The result of BigQuery export post scan action. class PostScanActionsResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The result of BigQuery export post scan action. # @!attribute [r] state # @return [::Google::Cloud::Dataplex::V1::DataQualityResult::PostScanActionsResult::BigQueryExportResult::State] # Output only. Execution state for the BigQuery exporting. # @!attribute [r] message # @return [::String] # Output only. Additional information about the BigQuery exporting. class BigQueryExportResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Execution state for the exporting. module State # The exporting state is unspecified. STATE_UNSPECIFIED = 0 # The exporting completed successfully. SUCCEEDED = 1 # The exporting is no longer running due to an error. FAILED = 2 # The exporting is skipped due to no valid scan result to export # (usually caused by scan failed). SKIPPED = 3 end end end # The assets generated by Anomaly Detection Data Scan. # @!attribute [r] result_table # @return [::String] # Output only. The result table for anomaly detection. # Format: # PROJECT_ID.DATASET_ID.TABLE_ID # If the result table is set at AnomalyDetectionAssets, the result table # here would be the same as the one set in the # AnomalyDetectionAssets.result_table. # @!attribute [r] data_intermediate_table # @return [::String] # Output only. The intermediate table for data anomaly detection. # Format: # PROJECT_ID.DATASET_ID.TABLE_ID # @!attribute [r] freshness_intermediate_table # @return [::String] # Output only. The intermediate table for freshness anomaly detection. # Format: # PROJECT_ID.DATASET_ID.TABLE_ID # @!attribute [r] volume_intermediate_table # @return [::String] # Output only. The intermediate table for volume anomaly detection. # Format: # PROJECT_ID.DATASET_ID.TABLE_ID class AnomalyDetectionGeneratedAssets include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |