Class: Google::Cloud::Dataplex::V1::DataQualityResult::PostScanActionsResult
- Inherits:
-
Object
- Object
- Google::Cloud::Dataplex::V1::DataQualityResult::PostScanActionsResult
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataplex/v1/data_quality.rb
Overview
The result of post scan actions of DataQualityScan job.
Defined Under Namespace
Classes: BigQueryExportResult
Instance Attribute Summary collapse
-
#bigquery_export_result ⇒ ::Google::Cloud::Dataplex::V1::DataQualityResult::PostScanActionsResult::BigQueryExportResult
readonly
Output only.
Instance Attribute Details
#bigquery_export_result ⇒ ::Google::Cloud::Dataplex::V1::DataQualityResult::PostScanActionsResult::BigQueryExportResult (readonly)
Returns Output only. The result of BigQuery export post scan action.
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'proto_docs/google/cloud/dataplex/v1/data_quality.rb', line 208 class PostScanActionsResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The result of BigQuery export post scan action. # @!attribute [r] state # @return [::Google::Cloud::Dataplex::V1::DataQualityResult::PostScanActionsResult::BigQueryExportResult::State] # Output only. Execution state for the BigQuery exporting. # @!attribute [r] message # @return [::String] # Output only. Additional information about the BigQuery exporting. class BigQueryExportResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Execution state for the exporting. module State # The exporting state is unspecified. STATE_UNSPECIFIED = 0 # The exporting completed successfully. SUCCEEDED = 1 # The exporting is no longer running due to an error. FAILED = 2 # The exporting is skipped due to no valid scan result to export # (usually caused by scan failed). SKIPPED = 3 end end end |