Class: Google::Cloud::Dataplex::V1::DataQualityResult::PostScanActionsResult::BigQueryExportResult
- Inherits:
-
Object
- Object
- Google::Cloud::Dataplex::V1::DataQualityResult::PostScanActionsResult::BigQueryExportResult
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataplex/v1/data_quality.rb
Overview
The result of BigQuery export post scan action.
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#message ⇒ ::String
readonly
Output only.
-
#state ⇒ ::Google::Cloud::Dataplex::V1::DataQualityResult::PostScanActionsResult::BigQueryExportResult::State
readonly
Output only.
Instance Attribute Details
#message ⇒ ::String (readonly)
Returns Output only. Additional information about the BigQuery exporting.
219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'proto_docs/google/cloud/dataplex/v1/data_quality.rb', line 219 class BigQueryExportResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Execution state for the exporting. module State # The exporting state is unspecified. STATE_UNSPECIFIED = 0 # The exporting completed successfully. SUCCEEDED = 1 # The exporting is no longer running due to an error. FAILED = 2 # The exporting is skipped due to no valid scan result to export # (usually caused by scan failed). SKIPPED = 3 end end |
#state ⇒ ::Google::Cloud::Dataplex::V1::DataQualityResult::PostScanActionsResult::BigQueryExportResult::State (readonly)
Returns Output only. Execution state for the BigQuery exporting.
219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'proto_docs/google/cloud/dataplex/v1/data_quality.rb', line 219 class BigQueryExportResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Execution state for the exporting. module State # The exporting state is unspecified. STATE_UNSPECIFIED = 0 # The exporting completed successfully. SUCCEEDED = 1 # The exporting is no longer running due to an error. FAILED = 2 # The exporting is skipped due to no valid scan result to export # (usually caused by scan failed). SKIPPED = 3 end end |