Class: Google::Cloud::Dataplex::V1::DataQualityRule::DebugQuery

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataplex/v1/data_quality.rb

Overview

Specifies a SQL statement that is evaluated to return up to 10 scalar values that are used to debug rules. If the rule fails, the values can help diagnose the cause of the failure.

The SQL statement must use GoogleSQL syntax, and must not contain any semicolons.

You can use the data reference parameter ${data()} to reference the source table with all of its precondition filters applied. Examples of precondition filters include row filters, incremental data filters, and sampling. For more information, see Data reference parameter.

You can also name results with an explicit alias using [AS] alias. For more information, see BigQuery explicit aliases.

Example: SELECT MIN(col1) AS min_col1, MAX(col1) AS max_col1 FROM $\\{data()}

Instance Attribute Summary collapse

Instance Attribute Details

#description::String

Returns Optional. Specifies the description of the debug query.

  • The maximum length is 1,024 characters.

Returns:

  • (::String)

    Optional. Specifies the description of the debug query.

    • The maximum length is 1,024 characters.


810
811
812
813
# File 'proto_docs/google/cloud/dataplex/v1/data_quality.rb', line 810

class DebugQuery
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#sql_statement::String

Returns Required. Specifies the SQL statement to be executed.

Returns:

  • (::String)

    Required. Specifies the SQL statement to be executed.



810
811
812
813
# File 'proto_docs/google/cloud/dataplex/v1/data_quality.rb', line 810

class DebugQuery
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end