Class: Google::Cloud::Dataplex::V1::DataQualityRule::RuleSource::RulePathElement::EntrySource

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataplex/v1/data_quality.rb

Overview

Entry source represents information about the related source entry.

Instance Attribute Summary collapse

Instance Attribute Details

#display_name::String (readonly)

Returns Output only. The display name of the entry.

Returns:

  • (::String)

    Output only. The display name of the entry.



759
760
761
762
# File 'proto_docs/google/cloud/dataplex/v1/data_quality.rb', line 759

class EntrySource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#entry::String (readonly)

Returns Output only. The entry name in the form of: projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}/entries/{entry_id}.

Returns:

  • (::String)

    Output only. The entry name in the form of: projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}/entries/{entry_id}



759
760
761
762
# File 'proto_docs/google/cloud/dataplex/v1/data_quality.rb', line 759

class EntrySource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#entry_type::String (readonly)

Returns Output only. The entry type to represent the current characteristics of the entry in the form of: projects/{project_id_or_number}/locations/{location_id}/entryTypes/{entry-type-id}.

Returns:

  • (::String)

    Output only. The entry type to represent the current characteristics of the entry in the form of: projects/{project_id_or_number}/locations/{location_id}/entryTypes/{entry-type-id}.



759
760
761
762
# File 'proto_docs/google/cloud/dataplex/v1/data_quality.rb', line 759

class EntrySource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end