Class: Google::Cloud::Dataplex::V1::DataQualityRuleResult::DebugQueryResult

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataplex/v1/data_quality.rb

Overview

Contains a single result from the debug query.

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Specifies the name of the result. Available if provided with an explicit alias using [AS] alias.

Returns:

  • (::String)

    Specifies the name of the result. Available if provided with an explicit alias using [AS] alias.



340
341
342
343
# File 'proto_docs/google/cloud/dataplex/v1/data_quality.rb', line 340

class DebugQueryResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#type::String

Returns Indicates the data type of the result. For more information, see BigQuery data types.

Returns:

  • (::String)

    Indicates the data type of the result. For more information, see BigQuery data types.



340
341
342
343
# File 'proto_docs/google/cloud/dataplex/v1/data_quality.rb', line 340

class DebugQueryResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#value::String

Returns Represents the value of the result as a string.

Returns:

  • (::String)

    Represents the value of the result as a string.



340
341
342
343
# File 'proto_docs/google/cloud/dataplex/v1/data_quality.rb', line 340

class DebugQueryResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end