Class: Google::Cloud::Dataplex::V1::DataQualityRuleTemplate

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataplex/v1/data_quality_rule_template.rb

Overview

DataQualityRuleTemplate represents a template which can be reused across multiple data quality rules.

Defined Under Namespace

Classes: InputParametersEntry, ParameterDescription, Sql

Instance Attribute Summary collapse

Instance Attribute Details

#capabilities::Array<::String> (readonly)

Returns Output only. A list of features or properties supported by this rule template.

Returns:

  • (::Array<::String>)

    Output only. A list of features or properties supported by this rule template.



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'proto_docs/google/cloud/dataplex/v1/data_quality_rule_template.rb', line 45

class DataQualityRuleTemplate
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Templatized SQL query for data quality rules. It can have parameters that
  # can be substituted with values when a rule is created using this template.
  # @!attribute [r] query
  #   @return [::String]
  #     Output only. Templatized SQL query for data quality rules.
  class Sql
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Description of the input parameter. It can include the type(s) supported
  # by the parameter and intended usage. It is for information purposes only
  # and does not affect the behavior of the rule template.
  # @!attribute [r] description
  #   @return [::String]
  #     Output only. Description of the input parameter. It can include the
  #     type(s) supported by the parameter and intended usage. It is for
  #     information purposes only and does not affect the behavior of the rule
  #     template.
  # @!attribute [r] default_value
  #   @return [::String]
  #     Output only. The default value for the parameter if no value is provided.
  class ParameterDescription
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dataplex::V1::DataQualityRuleTemplate::ParameterDescription]
  class InputParametersEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#dimension::String (readonly)

Returns Output only. The dimension a rule template belongs to. Rule level results are also aggregated at the dimension level.

Returns:

  • (::String)

    Output only. The dimension a rule template belongs to. Rule level results are also aggregated at the dimension level.



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'proto_docs/google/cloud/dataplex/v1/data_quality_rule_template.rb', line 45

class DataQualityRuleTemplate
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Templatized SQL query for data quality rules. It can have parameters that
  # can be substituted with values when a rule is created using this template.
  # @!attribute [r] query
  #   @return [::String]
  #     Output only. Templatized SQL query for data quality rules.
  class Sql
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Description of the input parameter. It can include the type(s) supported
  # by the parameter and intended usage. It is for information purposes only
  # and does not affect the behavior of the rule template.
  # @!attribute [r] description
  #   @return [::String]
  #     Output only. Description of the input parameter. It can include the
  #     type(s) supported by the parameter and intended usage. It is for
  #     information purposes only and does not affect the behavior of the rule
  #     template.
  # @!attribute [r] default_value
  #   @return [::String]
  #     Output only. The default value for the parameter if no value is provided.
  class ParameterDescription
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dataplex::V1::DataQualityRuleTemplate::ParameterDescription]
  class InputParametersEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#input_parameters::Google::Protobuf::Map{::String => ::Google::Cloud::Dataplex::V1::DataQualityRuleTemplate::ParameterDescription} (readonly)

Returns Output only. Description for input parameters.

Returns:



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'proto_docs/google/cloud/dataplex/v1/data_quality_rule_template.rb', line 45

class DataQualityRuleTemplate
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Templatized SQL query for data quality rules. It can have parameters that
  # can be substituted with values when a rule is created using this template.
  # @!attribute [r] query
  #   @return [::String]
  #     Output only. Templatized SQL query for data quality rules.
  class Sql
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Description of the input parameter. It can include the type(s) supported
  # by the parameter and intended usage. It is for information purposes only
  # and does not affect the behavior of the rule template.
  # @!attribute [r] description
  #   @return [::String]
  #     Output only. Description of the input parameter. It can include the
  #     type(s) supported by the parameter and intended usage. It is for
  #     information purposes only and does not affect the behavior of the rule
  #     template.
  # @!attribute [r] default_value
  #   @return [::String]
  #     Output only. The default value for the parameter if no value is provided.
  class ParameterDescription
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dataplex::V1::DataQualityRuleTemplate::ParameterDescription]
  class InputParametersEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#name::String (readonly)

Returns Output only. The name of the rule template in the format: projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}/entries/{entry_id}.

Returns:

  • (::String)

    Output only. The name of the rule template in the format: projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}/entries/{entry_id}



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'proto_docs/google/cloud/dataplex/v1/data_quality_rule_template.rb', line 45

class DataQualityRuleTemplate
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Templatized SQL query for data quality rules. It can have parameters that
  # can be substituted with values when a rule is created using this template.
  # @!attribute [r] query
  #   @return [::String]
  #     Output only. Templatized SQL query for data quality rules.
  class Sql
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Description of the input parameter. It can include the type(s) supported
  # by the parameter and intended usage. It is for information purposes only
  # and does not affect the behavior of the rule template.
  # @!attribute [r] description
  #   @return [::String]
  #     Output only. Description of the input parameter. It can include the
  #     type(s) supported by the parameter and intended usage. It is for
  #     information purposes only and does not affect the behavior of the rule
  #     template.
  # @!attribute [r] default_value
  #   @return [::String]
  #     Output only. The default value for the parameter if no value is provided.
  class ParameterDescription
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dataplex::V1::DataQualityRuleTemplate::ParameterDescription]
  class InputParametersEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#sql_collection::Array<::Google::Cloud::Dataplex::V1::DataQualityRuleTemplate::Sql> (readonly)

Returns Output only. Collection of SQLs for data quality rules. Currently only one SQL is supported.

Returns:



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'proto_docs/google/cloud/dataplex/v1/data_quality_rule_template.rb', line 45

class DataQualityRuleTemplate
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Templatized SQL query for data quality rules. It can have parameters that
  # can be substituted with values when a rule is created using this template.
  # @!attribute [r] query
  #   @return [::String]
  #     Output only. Templatized SQL query for data quality rules.
  class Sql
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Description of the input parameter. It can include the type(s) supported
  # by the parameter and intended usage. It is for information purposes only
  # and does not affect the behavior of the rule template.
  # @!attribute [r] description
  #   @return [::String]
  #     Output only. Description of the input parameter. It can include the
  #     type(s) supported by the parameter and intended usage. It is for
  #     information purposes only and does not affect the behavior of the rule
  #     template.
  # @!attribute [r] default_value
  #   @return [::String]
  #     Output only. The default value for the parameter if no value is provided.
  class ParameterDescription
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dataplex::V1::DataQualityRuleTemplate::ParameterDescription]
  class InputParametersEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end