Class: Google::Cloud::Dataplex::V1::DataQualityRuleTemplate::ParameterDescription

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataplex/v1/data_quality_rule_template.rb

Overview

Description of the input parameter. It can include the type(s) supported by the parameter and intended usage. It is for information purposes only and does not affect the behavior of the rule template.

Instance Attribute Summary collapse

Instance Attribute Details

#default_value::String (readonly)

Returns Output only. The default value for the parameter if no value is provided.

Returns:

  • (::String)

    Output only. The default value for the parameter if no value is provided.



71
72
73
74
# File 'proto_docs/google/cloud/dataplex/v1/data_quality_rule_template.rb', line 71

class ParameterDescription
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#description::String (readonly)

Returns Output only. Description of the input parameter. It can include the type(s) supported by the parameter and intended usage. It is for information purposes only and does not affect the behavior of the rule template.

Returns:

  • (::String)

    Output only. Description of the input parameter. It can include the type(s) supported by the parameter and intended usage. It is for information purposes only and does not affect the behavior of the rule template.



71
72
73
74
# File 'proto_docs/google/cloud/dataplex/v1/data_quality_rule_template.rb', line 71

class ParameterDescription
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end