Class: Google::Cloud::Dataplex::V1::DataQualityRuleTemplate::Sql
- Inherits:
-
Object
- Object
- Google::Cloud::Dataplex::V1::DataQualityRuleTemplate::Sql
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataplex/v1/data_quality_rule_template.rb
Overview
Templatized SQL query for data quality rules. It can have parameters that can be substituted with values when a rule is created using this template.
Instance Attribute Summary collapse
-
#query ⇒ ::String
readonly
Output only.