Class: Google::Cloud::Dataplex::V1::DataScan

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataplex/v1/datascans.rb

Overview

Represents a user-visible job which provides the insights for the related data source.

For example:

  • Data quality: generates queries based on the rules and runs against the data to get data quality check results. For more information, see Auto data quality overview.
  • Data profile: analyzes the data in tables and generates insights about the structure, content and relationships (such as null percent, cardinality, min/max/mean, etc). For more information, see About data profiling.
  • Data discovery: scans data in Cloud Storage buckets to extract and then catalog metadata. For more information, see Discover and catalog Cloud Storage data.
  • Data documentation: analyzes the table or dataset metadata and generates insights. For tables, insights include descriptions and sample SQL queries. For datasets, insights include descriptions, schema relationships and sample SQL queries. For more information, see Generate data insights in BigQuery.

Defined Under Namespace

Classes: ExecutionSpec, ExecutionStatus, LabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time when the scan was created.

Returns:



420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 420

class DataScan
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # DataScan execution settings.
  # @!attribute [rw] trigger
  #   @return [::Google::Cloud::Dataplex::V1::Trigger]
  #     Optional. Spec related to how often and when a scan should be triggered.
  #
  #     If not specified, the default is `OnDemand`, which means the scan will
  #     not run until the user calls `RunDataScan` API.
  # @!attribute [rw] field
  #   @return [::String]
  #     Immutable. The unnested field (of type *Date* or *Timestamp*) that
  #     contains values which monotonically increase over time.
  #
  #     If not specified, a data scan will run for all data in the table.
  class ExecutionSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Status of the data scan execution.
  # @!attribute [rw] latest_job_start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the latest DataScanJob started.
  # @!attribute [rw] latest_job_end_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the latest DataScanJob ended.
  # @!attribute [rw] latest_job_create_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the DataScanJob execution was created.
  class ExecutionStatus
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#data::Google::Cloud::Dataplex::V1::DataSource

Returns Required. The data source for DataScan.

Returns:



420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 420

class DataScan
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # DataScan execution settings.
  # @!attribute [rw] trigger
  #   @return [::Google::Cloud::Dataplex::V1::Trigger]
  #     Optional. Spec related to how often and when a scan should be triggered.
  #
  #     If not specified, the default is `OnDemand`, which means the scan will
  #     not run until the user calls `RunDataScan` API.
  # @!attribute [rw] field
  #   @return [::String]
  #     Immutable. The unnested field (of type *Date* or *Timestamp*) that
  #     contains values which monotonically increase over time.
  #
  #     If not specified, a data scan will run for all data in the table.
  class ExecutionSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Status of the data scan execution.
  # @!attribute [rw] latest_job_start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the latest DataScanJob started.
  # @!attribute [rw] latest_job_end_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the latest DataScanJob ended.
  # @!attribute [rw] latest_job_create_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the DataScanJob execution was created.
  class ExecutionStatus
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#data_discovery_result::Google::Cloud::Dataplex::V1::DataDiscoveryResult (readonly)

Returns Output only. The result of a data discovery scan.

Note: The following fields are mutually exclusive: data_discovery_result, data_quality_result, data_profile_result, data_documentation_result. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Dataplex::V1::DataDiscoveryResult)

    Output only. The result of a data discovery scan.

    Note: The following fields are mutually exclusive: data_discovery_result, data_quality_result, data_profile_result, data_documentation_result. If a field in that set is populated, all other fields in the set will automatically be cleared.



420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 420

class DataScan
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # DataScan execution settings.
  # @!attribute [rw] trigger
  #   @return [::Google::Cloud::Dataplex::V1::Trigger]
  #     Optional. Spec related to how often and when a scan should be triggered.
  #
  #     If not specified, the default is `OnDemand`, which means the scan will
  #     not run until the user calls `RunDataScan` API.
  # @!attribute [rw] field
  #   @return [::String]
  #     Immutable. The unnested field (of type *Date* or *Timestamp*) that
  #     contains values which monotonically increase over time.
  #
  #     If not specified, a data scan will run for all data in the table.
  class ExecutionSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Status of the data scan execution.
  # @!attribute [rw] latest_job_start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the latest DataScanJob started.
  # @!attribute [rw] latest_job_end_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the latest DataScanJob ended.
  # @!attribute [rw] latest_job_create_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the DataScanJob execution was created.
  class ExecutionStatus
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#data_discovery_spec::Google::Cloud::Dataplex::V1::DataDiscoverySpec

Returns Settings for a data discovery scan.

Note: The following fields are mutually exclusive: data_discovery_spec, data_quality_spec, data_profile_spec, data_documentation_spec. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Dataplex::V1::DataDiscoverySpec)

    Settings for a data discovery scan.

    Note: The following fields are mutually exclusive: data_discovery_spec, data_quality_spec, data_profile_spec, data_documentation_spec. If a field in that set is populated, all other fields in the set will automatically be cleared.



420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 420

class DataScan
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # DataScan execution settings.
  # @!attribute [rw] trigger
  #   @return [::Google::Cloud::Dataplex::V1::Trigger]
  #     Optional. Spec related to how often and when a scan should be triggered.
  #
  #     If not specified, the default is `OnDemand`, which means the scan will
  #     not run until the user calls `RunDataScan` API.
  # @!attribute [rw] field
  #   @return [::String]
  #     Immutable. The unnested field (of type *Date* or *Timestamp*) that
  #     contains values which monotonically increase over time.
  #
  #     If not specified, a data scan will run for all data in the table.
  class ExecutionSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Status of the data scan execution.
  # @!attribute [rw] latest_job_start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the latest DataScanJob started.
  # @!attribute [rw] latest_job_end_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the latest DataScanJob ended.
  # @!attribute [rw] latest_job_create_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the DataScanJob execution was created.
  class ExecutionStatus
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#data_documentation_result::Google::Cloud::Dataplex::V1::DataDocumentationResult (readonly)

Returns Output only. The result of a data documentation scan.

Note: The following fields are mutually exclusive: data_documentation_result, data_quality_result, data_profile_result, data_discovery_result. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Dataplex::V1::DataDocumentationResult)

    Output only. The result of a data documentation scan.

    Note: The following fields are mutually exclusive: data_documentation_result, data_quality_result, data_profile_result, data_discovery_result. If a field in that set is populated, all other fields in the set will automatically be cleared.



420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 420

class DataScan
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # DataScan execution settings.
  # @!attribute [rw] trigger
  #   @return [::Google::Cloud::Dataplex::V1::Trigger]
  #     Optional. Spec related to how often and when a scan should be triggered.
  #
  #     If not specified, the default is `OnDemand`, which means the scan will
  #     not run until the user calls `RunDataScan` API.
  # @!attribute [rw] field
  #   @return [::String]
  #     Immutable. The unnested field (of type *Date* or *Timestamp*) that
  #     contains values which monotonically increase over time.
  #
  #     If not specified, a data scan will run for all data in the table.
  class ExecutionSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Status of the data scan execution.
  # @!attribute [rw] latest_job_start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the latest DataScanJob started.
  # @!attribute [rw] latest_job_end_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the latest DataScanJob ended.
  # @!attribute [rw] latest_job_create_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the DataScanJob execution was created.
  class ExecutionStatus
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#data_documentation_spec::Google::Cloud::Dataplex::V1::DataDocumentationSpec

Returns Settings for a data documentation scan.

Note: The following fields are mutually exclusive: data_documentation_spec, data_quality_spec, data_profile_spec, data_discovery_spec. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Dataplex::V1::DataDocumentationSpec)

    Settings for a data documentation scan.

    Note: The following fields are mutually exclusive: data_documentation_spec, data_quality_spec, data_profile_spec, data_discovery_spec. If a field in that set is populated, all other fields in the set will automatically be cleared.



420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 420

class DataScan
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # DataScan execution settings.
  # @!attribute [rw] trigger
  #   @return [::Google::Cloud::Dataplex::V1::Trigger]
  #     Optional. Spec related to how often and when a scan should be triggered.
  #
  #     If not specified, the default is `OnDemand`, which means the scan will
  #     not run until the user calls `RunDataScan` API.
  # @!attribute [rw] field
  #   @return [::String]
  #     Immutable. The unnested field (of type *Date* or *Timestamp*) that
  #     contains values which monotonically increase over time.
  #
  #     If not specified, a data scan will run for all data in the table.
  class ExecutionSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Status of the data scan execution.
  # @!attribute [rw] latest_job_start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the latest DataScanJob started.
  # @!attribute [rw] latest_job_end_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the latest DataScanJob ended.
  # @!attribute [rw] latest_job_create_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the DataScanJob execution was created.
  class ExecutionStatus
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#data_profile_result::Google::Cloud::Dataplex::V1::DataProfileResult (readonly)

Returns Output only. The result of a data profile scan.

Note: The following fields are mutually exclusive: data_profile_result, data_quality_result, data_discovery_result, data_documentation_result. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Dataplex::V1::DataProfileResult)

    Output only. The result of a data profile scan.

    Note: The following fields are mutually exclusive: data_profile_result, data_quality_result, data_discovery_result, data_documentation_result. If a field in that set is populated, all other fields in the set will automatically be cleared.



420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 420

class DataScan
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # DataScan execution settings.
  # @!attribute [rw] trigger
  #   @return [::Google::Cloud::Dataplex::V1::Trigger]
  #     Optional. Spec related to how often and when a scan should be triggered.
  #
  #     If not specified, the default is `OnDemand`, which means the scan will
  #     not run until the user calls `RunDataScan` API.
  # @!attribute [rw] field
  #   @return [::String]
  #     Immutable. The unnested field (of type *Date* or *Timestamp*) that
  #     contains values which monotonically increase over time.
  #
  #     If not specified, a data scan will run for all data in the table.
  class ExecutionSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Status of the data scan execution.
  # @!attribute [rw] latest_job_start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the latest DataScanJob started.
  # @!attribute [rw] latest_job_end_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the latest DataScanJob ended.
  # @!attribute [rw] latest_job_create_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the DataScanJob execution was created.
  class ExecutionStatus
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#data_profile_spec::Google::Cloud::Dataplex::V1::DataProfileSpec

Returns Settings for a data profile scan.

Note: The following fields are mutually exclusive: data_profile_spec, data_quality_spec, data_discovery_spec, data_documentation_spec. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Dataplex::V1::DataProfileSpec)

    Settings for a data profile scan.

    Note: The following fields are mutually exclusive: data_profile_spec, data_quality_spec, data_discovery_spec, data_documentation_spec. If a field in that set is populated, all other fields in the set will automatically be cleared.



420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 420

class DataScan
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # DataScan execution settings.
  # @!attribute [rw] trigger
  #   @return [::Google::Cloud::Dataplex::V1::Trigger]
  #     Optional. Spec related to how often and when a scan should be triggered.
  #
  #     If not specified, the default is `OnDemand`, which means the scan will
  #     not run until the user calls `RunDataScan` API.
  # @!attribute [rw] field
  #   @return [::String]
  #     Immutable. The unnested field (of type *Date* or *Timestamp*) that
  #     contains values which monotonically increase over time.
  #
  #     If not specified, a data scan will run for all data in the table.
  class ExecutionSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Status of the data scan execution.
  # @!attribute [rw] latest_job_start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the latest DataScanJob started.
  # @!attribute [rw] latest_job_end_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the latest DataScanJob ended.
  # @!attribute [rw] latest_job_create_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the DataScanJob execution was created.
  class ExecutionStatus
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#data_quality_result::Google::Cloud::Dataplex::V1::DataQualityResult (readonly)

Returns Output only. The result of a data quality scan.

Note: The following fields are mutually exclusive: data_quality_result, data_profile_result, data_discovery_result, data_documentation_result. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Dataplex::V1::DataQualityResult)

    Output only. The result of a data quality scan.

    Note: The following fields are mutually exclusive: data_quality_result, data_profile_result, data_discovery_result, data_documentation_result. If a field in that set is populated, all other fields in the set will automatically be cleared.



420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 420

class DataScan
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # DataScan execution settings.
  # @!attribute [rw] trigger
  #   @return [::Google::Cloud::Dataplex::V1::Trigger]
  #     Optional. Spec related to how often and when a scan should be triggered.
  #
  #     If not specified, the default is `OnDemand`, which means the scan will
  #     not run until the user calls `RunDataScan` API.
  # @!attribute [rw] field
  #   @return [::String]
  #     Immutable. The unnested field (of type *Date* or *Timestamp*) that
  #     contains values which monotonically increase over time.
  #
  #     If not specified, a data scan will run for all data in the table.
  class ExecutionSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Status of the data scan execution.
  # @!attribute [rw] latest_job_start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the latest DataScanJob started.
  # @!attribute [rw] latest_job_end_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the latest DataScanJob ended.
  # @!attribute [rw] latest_job_create_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the DataScanJob execution was created.
  class ExecutionStatus
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#data_quality_spec::Google::Cloud::Dataplex::V1::DataQualitySpec

Returns Settings for a data quality scan.

Note: The following fields are mutually exclusive: data_quality_spec, data_profile_spec, data_discovery_spec, data_documentation_spec. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Dataplex::V1::DataQualitySpec)

    Settings for a data quality scan.

    Note: The following fields are mutually exclusive: data_quality_spec, data_profile_spec, data_discovery_spec, data_documentation_spec. If a field in that set is populated, all other fields in the set will automatically be cleared.



420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 420

class DataScan
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # DataScan execution settings.
  # @!attribute [rw] trigger
  #   @return [::Google::Cloud::Dataplex::V1::Trigger]
  #     Optional. Spec related to how often and when a scan should be triggered.
  #
  #     If not specified, the default is `OnDemand`, which means the scan will
  #     not run until the user calls `RunDataScan` API.
  # @!attribute [rw] field
  #   @return [::String]
  #     Immutable. The unnested field (of type *Date* or *Timestamp*) that
  #     contains values which monotonically increase over time.
  #
  #     If not specified, a data scan will run for all data in the table.
  class ExecutionSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Status of the data scan execution.
  # @!attribute [rw] latest_job_start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the latest DataScanJob started.
  # @!attribute [rw] latest_job_end_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the latest DataScanJob ended.
  # @!attribute [rw] latest_job_create_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the DataScanJob execution was created.
  class ExecutionStatus
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#description::String

Returns Optional. Description of the scan.

  • Must be between 1-1024 characters.

Returns:

  • (::String)

    Optional. Description of the scan.

    • Must be between 1-1024 characters.


420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 420

class DataScan
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # DataScan execution settings.
  # @!attribute [rw] trigger
  #   @return [::Google::Cloud::Dataplex::V1::Trigger]
  #     Optional. Spec related to how often and when a scan should be triggered.
  #
  #     If not specified, the default is `OnDemand`, which means the scan will
  #     not run until the user calls `RunDataScan` API.
  # @!attribute [rw] field
  #   @return [::String]
  #     Immutable. The unnested field (of type *Date* or *Timestamp*) that
  #     contains values which monotonically increase over time.
  #
  #     If not specified, a data scan will run for all data in the table.
  class ExecutionSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Status of the data scan execution.
  # @!attribute [rw] latest_job_start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the latest DataScanJob started.
  # @!attribute [rw] latest_job_end_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the latest DataScanJob ended.
  # @!attribute [rw] latest_job_create_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the DataScanJob execution was created.
  class ExecutionStatus
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#display_name::String

Returns Optional. User friendly display name.

  • Must be between 1-256 characters.

Returns:

  • (::String)

    Optional. User friendly display name.

    • Must be between 1-256 characters.


420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 420

class DataScan
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # DataScan execution settings.
  # @!attribute [rw] trigger
  #   @return [::Google::Cloud::Dataplex::V1::Trigger]
  #     Optional. Spec related to how often and when a scan should be triggered.
  #
  #     If not specified, the default is `OnDemand`, which means the scan will
  #     not run until the user calls `RunDataScan` API.
  # @!attribute [rw] field
  #   @return [::String]
  #     Immutable. The unnested field (of type *Date* or *Timestamp*) that
  #     contains values which monotonically increase over time.
  #
  #     If not specified, a data scan will run for all data in the table.
  class ExecutionSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Status of the data scan execution.
  # @!attribute [rw] latest_job_start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the latest DataScanJob started.
  # @!attribute [rw] latest_job_end_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the latest DataScanJob ended.
  # @!attribute [rw] latest_job_create_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the DataScanJob execution was created.
  class ExecutionStatus
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#execution_identity::Google::Cloud::Dataplex::V1::ExecutionIdentity

Returns Optional. Immutable. The identity to run the datascan. If not specified, defaults to the Dataplex Service Agent.

Returns:



420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 420

class DataScan
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # DataScan execution settings.
  # @!attribute [rw] trigger
  #   @return [::Google::Cloud::Dataplex::V1::Trigger]
  #     Optional. Spec related to how often and when a scan should be triggered.
  #
  #     If not specified, the default is `OnDemand`, which means the scan will
  #     not run until the user calls `RunDataScan` API.
  # @!attribute [rw] field
  #   @return [::String]
  #     Immutable. The unnested field (of type *Date* or *Timestamp*) that
  #     contains values which monotonically increase over time.
  #
  #     If not specified, a data scan will run for all data in the table.
  class ExecutionSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Status of the data scan execution.
  # @!attribute [rw] latest_job_start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the latest DataScanJob started.
  # @!attribute [rw] latest_job_end_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the latest DataScanJob ended.
  # @!attribute [rw] latest_job_create_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the DataScanJob execution was created.
  class ExecutionStatus
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#execution_spec::Google::Cloud::Dataplex::V1::DataScan::ExecutionSpec

Returns Optional. DataScan execution settings.

If not specified, the fields in it will use their default values.

Returns:



420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 420

class DataScan
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # DataScan execution settings.
  # @!attribute [rw] trigger
  #   @return [::Google::Cloud::Dataplex::V1::Trigger]
  #     Optional. Spec related to how often and when a scan should be triggered.
  #
  #     If not specified, the default is `OnDemand`, which means the scan will
  #     not run until the user calls `RunDataScan` API.
  # @!attribute [rw] field
  #   @return [::String]
  #     Immutable. The unnested field (of type *Date* or *Timestamp*) that
  #     contains values which monotonically increase over time.
  #
  #     If not specified, a data scan will run for all data in the table.
  class ExecutionSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Status of the data scan execution.
  # @!attribute [rw] latest_job_start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the latest DataScanJob started.
  # @!attribute [rw] latest_job_end_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the latest DataScanJob ended.
  # @!attribute [rw] latest_job_create_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the DataScanJob execution was created.
  class ExecutionStatus
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#execution_status::Google::Cloud::Dataplex::V1::DataScan::ExecutionStatus (readonly)

Returns Output only. Status of the data scan execution.

Returns:



420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 420

class DataScan
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # DataScan execution settings.
  # @!attribute [rw] trigger
  #   @return [::Google::Cloud::Dataplex::V1::Trigger]
  #     Optional. Spec related to how often and when a scan should be triggered.
  #
  #     If not specified, the default is `OnDemand`, which means the scan will
  #     not run until the user calls `RunDataScan` API.
  # @!attribute [rw] field
  #   @return [::String]
  #     Immutable. The unnested field (of type *Date* or *Timestamp*) that
  #     contains values which monotonically increase over time.
  #
  #     If not specified, a data scan will run for all data in the table.
  class ExecutionSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Status of the data scan execution.
  # @!attribute [rw] latest_job_start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the latest DataScanJob started.
  # @!attribute [rw] latest_job_end_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the latest DataScanJob ended.
  # @!attribute [rw] latest_job_create_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the DataScanJob execution was created.
  class ExecutionStatus
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#labels::Google::Protobuf::Map{::String => ::String}

Returns Optional. User-defined labels for the scan.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional. User-defined labels for the scan.



420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 420

class DataScan
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # DataScan execution settings.
  # @!attribute [rw] trigger
  #   @return [::Google::Cloud::Dataplex::V1::Trigger]
  #     Optional. Spec related to how often and when a scan should be triggered.
  #
  #     If not specified, the default is `OnDemand`, which means the scan will
  #     not run until the user calls `RunDataScan` API.
  # @!attribute [rw] field
  #   @return [::String]
  #     Immutable. The unnested field (of type *Date* or *Timestamp*) that
  #     contains values which monotonically increase over time.
  #
  #     If not specified, a data scan will run for all data in the table.
  class ExecutionSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Status of the data scan execution.
  # @!attribute [rw] latest_job_start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the latest DataScanJob started.
  # @!attribute [rw] latest_job_end_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the latest DataScanJob ended.
  # @!attribute [rw] latest_job_create_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the DataScanJob execution was created.
  class ExecutionStatus
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#name::String (readonly)

Returns Output only. Identifier. The relative resource name of the scan, of the form: projects/{project}/locations/{location_id}/dataScans/{datascan_id}, where project refers to a project_id or project_number and location_id refers to a Google Cloud region.

Returns:

  • (::String)

    Output only. Identifier. The relative resource name of the scan, of the form: projects/{project}/locations/{location_id}/dataScans/{datascan_id}, where project refers to a project_id or project_number and location_id refers to a Google Cloud region.



420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 420

class DataScan
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # DataScan execution settings.
  # @!attribute [rw] trigger
  #   @return [::Google::Cloud::Dataplex::V1::Trigger]
  #     Optional. Spec related to how often and when a scan should be triggered.
  #
  #     If not specified, the default is `OnDemand`, which means the scan will
  #     not run until the user calls `RunDataScan` API.
  # @!attribute [rw] field
  #   @return [::String]
  #     Immutable. The unnested field (of type *Date* or *Timestamp*) that
  #     contains values which monotonically increase over time.
  #
  #     If not specified, a data scan will run for all data in the table.
  class ExecutionSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Status of the data scan execution.
  # @!attribute [rw] latest_job_start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the latest DataScanJob started.
  # @!attribute [rw] latest_job_end_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the latest DataScanJob ended.
  # @!attribute [rw] latest_job_create_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the DataScanJob execution was created.
  class ExecutionStatus
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#state::Google::Cloud::Dataplex::V1::State (readonly)

Returns Output only. Current state of the DataScan.

Returns:



420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 420

class DataScan
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # DataScan execution settings.
  # @!attribute [rw] trigger
  #   @return [::Google::Cloud::Dataplex::V1::Trigger]
  #     Optional. Spec related to how often and when a scan should be triggered.
  #
  #     If not specified, the default is `OnDemand`, which means the scan will
  #     not run until the user calls `RunDataScan` API.
  # @!attribute [rw] field
  #   @return [::String]
  #     Immutable. The unnested field (of type *Date* or *Timestamp*) that
  #     contains values which monotonically increase over time.
  #
  #     If not specified, a data scan will run for all data in the table.
  class ExecutionSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Status of the data scan execution.
  # @!attribute [rw] latest_job_start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the latest DataScanJob started.
  # @!attribute [rw] latest_job_end_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the latest DataScanJob ended.
  # @!attribute [rw] latest_job_create_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the DataScanJob execution was created.
  class ExecutionStatus
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#type::Google::Cloud::Dataplex::V1::DataScanType (readonly)

Returns Output only. The type of DataScan.

Returns:



420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 420

class DataScan
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # DataScan execution settings.
  # @!attribute [rw] trigger
  #   @return [::Google::Cloud::Dataplex::V1::Trigger]
  #     Optional. Spec related to how often and when a scan should be triggered.
  #
  #     If not specified, the default is `OnDemand`, which means the scan will
  #     not run until the user calls `RunDataScan` API.
  # @!attribute [rw] field
  #   @return [::String]
  #     Immutable. The unnested field (of type *Date* or *Timestamp*) that
  #     contains values which monotonically increase over time.
  #
  #     If not specified, a data scan will run for all data in the table.
  class ExecutionSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Status of the data scan execution.
  # @!attribute [rw] latest_job_start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the latest DataScanJob started.
  # @!attribute [rw] latest_job_end_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the latest DataScanJob ended.
  # @!attribute [rw] latest_job_create_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the DataScanJob execution was created.
  class ExecutionStatus
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#uid::String (readonly)

Returns Output only. System generated globally unique ID for the scan. This ID will be different if the scan is deleted and re-created with the same name.

Returns:

  • (::String)

    Output only. System generated globally unique ID for the scan. This ID will be different if the scan is deleted and re-created with the same name.



420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 420

class DataScan
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # DataScan execution settings.
  # @!attribute [rw] trigger
  #   @return [::Google::Cloud::Dataplex::V1::Trigger]
  #     Optional. Spec related to how often and when a scan should be triggered.
  #
  #     If not specified, the default is `OnDemand`, which means the scan will
  #     not run until the user calls `RunDataScan` API.
  # @!attribute [rw] field
  #   @return [::String]
  #     Immutable. The unnested field (of type *Date* or *Timestamp*) that
  #     contains values which monotonically increase over time.
  #
  #     If not specified, a data scan will run for all data in the table.
  class ExecutionSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Status of the data scan execution.
  # @!attribute [rw] latest_job_start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the latest DataScanJob started.
  # @!attribute [rw] latest_job_end_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the latest DataScanJob ended.
  # @!attribute [rw] latest_job_create_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the DataScanJob execution was created.
  class ExecutionStatus
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time when the scan was last updated.

Returns:



420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 420

class DataScan
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # DataScan execution settings.
  # @!attribute [rw] trigger
  #   @return [::Google::Cloud::Dataplex::V1::Trigger]
  #     Optional. Spec related to how often and when a scan should be triggered.
  #
  #     If not specified, the default is `OnDemand`, which means the scan will
  #     not run until the user calls `RunDataScan` API.
  # @!attribute [rw] field
  #   @return [::String]
  #     Immutable. The unnested field (of type *Date* or *Timestamp*) that
  #     contains values which monotonically increase over time.
  #
  #     If not specified, a data scan will run for all data in the table.
  class ExecutionSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Status of the data scan execution.
  # @!attribute [rw] latest_job_start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the latest DataScanJob started.
  # @!attribute [rw] latest_job_end_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the latest DataScanJob ended.
  # @!attribute [rw] latest_job_create_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time when the DataScanJob execution was created.
  class ExecutionStatus
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end