Class: Google::Cloud::Dataplex::V1::DataScanJob

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataplex/v1/datascans.rb

Overview

A DataScanJob represents an instance of DataScan execution.

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

#create_time::Google::Protobuf::Timestamp (readonly)



512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 512

class DataScanJob
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Execution state for the DataScanJob.
  module State
    # The DataScanJob state is unspecified.
    STATE_UNSPECIFIED = 0

    # The DataScanJob is running.
    RUNNING = 1

    # The DataScanJob is canceling.
    CANCELING = 2

    # The DataScanJob cancellation was successful.
    CANCELLED = 3

    # The DataScanJob completed successfully.
    SUCCEEDED = 4

    # The DataScanJob is no longer running due to an error.
    FAILED = 5

    # The DataScanJob has been created but not started to run yet.
    PENDING = 7
  end
end

#data_discovery_result::Google::Cloud::Dataplex::V1::DataDiscoveryResult (readonly)



512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 512

class DataScanJob
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Execution state for the DataScanJob.
  module State
    # The DataScanJob state is unspecified.
    STATE_UNSPECIFIED = 0

    # The DataScanJob is running.
    RUNNING = 1

    # The DataScanJob is canceling.
    CANCELING = 2

    # The DataScanJob cancellation was successful.
    CANCELLED = 3

    # The DataScanJob completed successfully.
    SUCCEEDED = 4

    # The DataScanJob is no longer running due to an error.
    FAILED = 5

    # The DataScanJob has been created but not started to run yet.
    PENDING = 7
  end
end

#data_discovery_spec::Google::Cloud::Dataplex::V1::DataDiscoverySpec (readonly)



512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 512

class DataScanJob
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Execution state for the DataScanJob.
  module State
    # The DataScanJob state is unspecified.
    STATE_UNSPECIFIED = 0

    # The DataScanJob is running.
    RUNNING = 1

    # The DataScanJob is canceling.
    CANCELING = 2

    # The DataScanJob cancellation was successful.
    CANCELLED = 3

    # The DataScanJob completed successfully.
    SUCCEEDED = 4

    # The DataScanJob is no longer running due to an error.
    FAILED = 5

    # The DataScanJob has been created but not started to run yet.
    PENDING = 7
  end
end

#data_documentation_result::Google::Cloud::Dataplex::V1::DataDocumentationResult (readonly)



512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 512

class DataScanJob
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Execution state for the DataScanJob.
  module State
    # The DataScanJob state is unspecified.
    STATE_UNSPECIFIED = 0

    # The DataScanJob is running.
    RUNNING = 1

    # The DataScanJob is canceling.
    CANCELING = 2

    # The DataScanJob cancellation was successful.
    CANCELLED = 3

    # The DataScanJob completed successfully.
    SUCCEEDED = 4

    # The DataScanJob is no longer running due to an error.
    FAILED = 5

    # The DataScanJob has been created but not started to run yet.
    PENDING = 7
  end
end

#data_documentation_spec::Google::Cloud::Dataplex::V1::DataDocumentationSpec (readonly)



512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 512

class DataScanJob
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Execution state for the DataScanJob.
  module State
    # The DataScanJob state is unspecified.
    STATE_UNSPECIFIED = 0

    # The DataScanJob is running.
    RUNNING = 1

    # The DataScanJob is canceling.
    CANCELING = 2

    # The DataScanJob cancellation was successful.
    CANCELLED = 3

    # The DataScanJob completed successfully.
    SUCCEEDED = 4

    # The DataScanJob is no longer running due to an error.
    FAILED = 5

    # The DataScanJob has been created but not started to run yet.
    PENDING = 7
  end
end

#data_profile_result::Google::Cloud::Dataplex::V1::DataProfileResult (readonly)



512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 512

class DataScanJob
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Execution state for the DataScanJob.
  module State
    # The DataScanJob state is unspecified.
    STATE_UNSPECIFIED = 0

    # The DataScanJob is running.
    RUNNING = 1

    # The DataScanJob is canceling.
    CANCELING = 2

    # The DataScanJob cancellation was successful.
    CANCELLED = 3

    # The DataScanJob completed successfully.
    SUCCEEDED = 4

    # The DataScanJob is no longer running due to an error.
    FAILED = 5

    # The DataScanJob has been created but not started to run yet.
    PENDING = 7
  end
end

#data_profile_spec::Google::Cloud::Dataplex::V1::DataProfileSpec (readonly)



512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 512

class DataScanJob
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Execution state for the DataScanJob.
  module State
    # The DataScanJob state is unspecified.
    STATE_UNSPECIFIED = 0

    # The DataScanJob is running.
    RUNNING = 1

    # The DataScanJob is canceling.
    CANCELING = 2

    # The DataScanJob cancellation was successful.
    CANCELLED = 3

    # The DataScanJob completed successfully.
    SUCCEEDED = 4

    # The DataScanJob is no longer running due to an error.
    FAILED = 5

    # The DataScanJob has been created but not started to run yet.
    PENDING = 7
  end
end

#data_quality_result::Google::Cloud::Dataplex::V1::DataQualityResult (readonly)



512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 512

class DataScanJob
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Execution state for the DataScanJob.
  module State
    # The DataScanJob state is unspecified.
    STATE_UNSPECIFIED = 0

    # The DataScanJob is running.
    RUNNING = 1

    # The DataScanJob is canceling.
    CANCELING = 2

    # The DataScanJob cancellation was successful.
    CANCELLED = 3

    # The DataScanJob completed successfully.
    SUCCEEDED = 4

    # The DataScanJob is no longer running due to an error.
    FAILED = 5

    # The DataScanJob has been created but not started to run yet.
    PENDING = 7
  end
end

#data_quality_spec::Google::Cloud::Dataplex::V1::DataQualitySpec (readonly)



512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 512

class DataScanJob
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Execution state for the DataScanJob.
  module State
    # The DataScanJob state is unspecified.
    STATE_UNSPECIFIED = 0

    # The DataScanJob is running.
    RUNNING = 1

    # The DataScanJob is canceling.
    CANCELING = 2

    # The DataScanJob cancellation was successful.
    CANCELLED = 3

    # The DataScanJob completed successfully.
    SUCCEEDED = 4

    # The DataScanJob is no longer running due to an error.
    FAILED = 5

    # The DataScanJob has been created but not started to run yet.
    PENDING = 7
  end
end

#end_time::Google::Protobuf::Timestamp (readonly)



512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 512

class DataScanJob
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Execution state for the DataScanJob.
  module State
    # The DataScanJob state is unspecified.
    STATE_UNSPECIFIED = 0

    # The DataScanJob is running.
    RUNNING = 1

    # The DataScanJob is canceling.
    CANCELING = 2

    # The DataScanJob cancellation was successful.
    CANCELLED = 3

    # The DataScanJob completed successfully.
    SUCCEEDED = 4

    # The DataScanJob is no longer running due to an error.
    FAILED = 5

    # The DataScanJob has been created but not started to run yet.
    PENDING = 7
  end
end

#message::String (readonly)



512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 512

class DataScanJob
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Execution state for the DataScanJob.
  module State
    # The DataScanJob state is unspecified.
    STATE_UNSPECIFIED = 0

    # The DataScanJob is running.
    RUNNING = 1

    # The DataScanJob is canceling.
    CANCELING = 2

    # The DataScanJob cancellation was successful.
    CANCELLED = 3

    # The DataScanJob completed successfully.
    SUCCEEDED = 4

    # The DataScanJob is no longer running due to an error.
    FAILED = 5

    # The DataScanJob has been created but not started to run yet.
    PENDING = 7
  end
end

#name::String (readonly)



512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 512

class DataScanJob
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Execution state for the DataScanJob.
  module State
    # The DataScanJob state is unspecified.
    STATE_UNSPECIFIED = 0

    # The DataScanJob is running.
    RUNNING = 1

    # The DataScanJob is canceling.
    CANCELING = 2

    # The DataScanJob cancellation was successful.
    CANCELLED = 3

    # The DataScanJob completed successfully.
    SUCCEEDED = 4

    # The DataScanJob is no longer running due to an error.
    FAILED = 5

    # The DataScanJob has been created but not started to run yet.
    PENDING = 7
  end
end

#start_time::Google::Protobuf::Timestamp (readonly)



512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 512

class DataScanJob
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Execution state for the DataScanJob.
  module State
    # The DataScanJob state is unspecified.
    STATE_UNSPECIFIED = 0

    # The DataScanJob is running.
    RUNNING = 1

    # The DataScanJob is canceling.
    CANCELING = 2

    # The DataScanJob cancellation was successful.
    CANCELLED = 3

    # The DataScanJob completed successfully.
    SUCCEEDED = 4

    # The DataScanJob is no longer running due to an error.
    FAILED = 5

    # The DataScanJob has been created but not started to run yet.
    PENDING = 7
  end
end

#state::Google::Cloud::Dataplex::V1::DataScanJob::State (readonly)



512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 512

class DataScanJob
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Execution state for the DataScanJob.
  module State
    # The DataScanJob state is unspecified.
    STATE_UNSPECIFIED = 0

    # The DataScanJob is running.
    RUNNING = 1

    # The DataScanJob is canceling.
    CANCELING = 2

    # The DataScanJob cancellation was successful.
    CANCELLED = 3

    # The DataScanJob completed successfully.
    SUCCEEDED = 4

    # The DataScanJob is no longer running due to an error.
    FAILED = 5

    # The DataScanJob has been created but not started to run yet.
    PENDING = 7
  end
end

#type::Google::Cloud::Dataplex::V1::DataScanType (readonly)



512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 512

class DataScanJob
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Execution state for the DataScanJob.
  module State
    # The DataScanJob state is unspecified.
    STATE_UNSPECIFIED = 0

    # The DataScanJob is running.
    RUNNING = 1

    # The DataScanJob is canceling.
    CANCELING = 2

    # The DataScanJob cancellation was successful.
    CANCELLED = 3

    # The DataScanJob completed successfully.
    SUCCEEDED = 4

    # The DataScanJob is no longer running due to an error.
    FAILED = 5

    # The DataScanJob has been created but not started to run yet.
    PENDING = 7
  end
end

#uid::String (readonly)



512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 512

class DataScanJob
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Execution state for the DataScanJob.
  module State
    # The DataScanJob state is unspecified.
    STATE_UNSPECIFIED = 0

    # The DataScanJob is running.
    RUNNING = 1

    # The DataScanJob is canceling.
    CANCELING = 2

    # The DataScanJob cancellation was successful.
    CANCELLED = 3

    # The DataScanJob completed successfully.
    SUCCEEDED = 4

    # The DataScanJob is no longer running due to an error.
    FAILED = 5

    # The DataScanJob has been created but not started to run yet.
    PENDING = 7
  end
end