Class: Google::Cloud::Dataplex::V1::DeleteDataAssetRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataplex/v1/data_products.rb

Overview

Request message for deleting a data asset.

Instance Attribute Summary collapse

Instance Attribute Details

#etag::String

Returns Optional. The etag of the data asset. If this is provided, it must match the server's etag. If the etag is provided and does not match the server-computed etag, the request must fail with a ABORTED error code.

Returns:

  • (::String)

    Optional. The etag of the data asset. If this is provided, it must match the server's etag. If the etag is provided and does not match the server-computed etag, the request must fail with a ABORTED error code.



500
501
502
503
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 500

class DeleteDataAssetRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Required. The name of the data asset to delete. Format: projects/{project_id_or_number}/locations/{location_id}/dataProducts/{data_product_id}/dataAssets/{data_asset_id}.

Returns:

  • (::String)

    Required. The name of the data asset to delete. Format: projects/{project_id_or_number}/locations/{location_id}/dataProducts/{data_product_id}/dataAssets/{data_asset_id}



500
501
502
503
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 500

class DeleteDataAssetRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#validate_only::Boolean

Returns Optional. Validates the request without actually deleting the data asset. Defaults to false.

Returns:

  • (::Boolean)

    Optional. Validates the request without actually deleting the data asset. Defaults to false.



500
501
502
503
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 500

class DeleteDataAssetRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end