Class: Google::Cloud::Dataplex::V1::DeletePartitionRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Dataplex::V1::DeletePartitionRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataplex/v1/metadata.rb
Overview
Delete metadata partition request.
Instance Attribute Summary collapse
-
#etag ⇒ ::String
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#name ⇒ ::String
Required.
Instance Attribute Details
#etag ⇒ ::String
Deprecated.
This field is deprecated and may be removed in the next major version update.
Returns Optional. The etag associated with the partition.
233 234 235 236 |
# File 'proto_docs/google/cloud/dataplex/v1/metadata.rb', line 233 class DeletePartitionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
233 234 235 236 |
# File 'proto_docs/google/cloud/dataplex/v1/metadata.rb', line 233 class DeletePartitionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |