Class: Google::Cloud::Dataplex::V1::EntryLink

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataplex/v1/catalog.rb

Overview

EntryLink represents a link between two Entries.

Defined Under Namespace

Classes: AspectsEntry, EntryReference

Instance Attribute Summary collapse

Instance Attribute Details

#aspects::Google::Protobuf::Map{::String => ::Google::Cloud::Dataplex::V1::Aspect}

Returns Optional. The aspects that are attached to the entry link. The format of the aspect key has to be the following: {project_id_or_number}.{location_id}.{aspect_type_id} Currently, only a single aspect of a Dataplex-owned Aspect Type is allowed.

Returns:

  • (::Google::Protobuf::Map{::String => ::Google::Cloud::Dataplex::V1::Aspect})

    Optional. The aspects that are attached to the entry link. The format of the aspect key has to be the following: {project_id_or_number}.{location_id}.{aspect_type_id} Currently, only a single aspect of a Dataplex-owned Aspect Type is allowed.



1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
1916
1917
1918
1919
1920
1921
1922
1923
1924
1925
1926
1927
1928
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 1884

class EntryLink
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Reference to the Entry that is linked through the Entry Link.
  # @!attribute [rw] name
  #   @return [::String]
  #     Required. Immutable. The relative resource name of the referenced Entry,
  #     of the form:
  #     `projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}/entries/{entry_id}`
  # @!attribute [rw] path
  #   @return [::String]
  #     Immutable. The path in the Entry that is referenced in the Entry Link.
  #     Empty path denotes that the Entry itself is referenced in the Entry
  #     Link.
  # @!attribute [rw] type
  #   @return [::Google::Cloud::Dataplex::V1::EntryLink::EntryReference::Type]
  #     Required. Immutable. The reference type of the Entry.
  class EntryReference
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Reference type of the Entry.
    module Type
      # Unspecified reference type. Implies that the Entry is referenced
      # in a non-directional Entry Link.
      UNSPECIFIED = 0

      # The Entry is referenced as the source of the directional Entry Link.
      SOURCE = 2

      # The Entry is referenced as the target of the directional Entry Link.
      TARGET = 3
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dataplex::V1::Aspect]
  class AspectsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time when the Entry Link was created.

Returns:



1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
1916
1917
1918
1919
1920
1921
1922
1923
1924
1925
1926
1927
1928
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 1884

class EntryLink
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Reference to the Entry that is linked through the Entry Link.
  # @!attribute [rw] name
  #   @return [::String]
  #     Required. Immutable. The relative resource name of the referenced Entry,
  #     of the form:
  #     `projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}/entries/{entry_id}`
  # @!attribute [rw] path
  #   @return [::String]
  #     Immutable. The path in the Entry that is referenced in the Entry Link.
  #     Empty path denotes that the Entry itself is referenced in the Entry
  #     Link.
  # @!attribute [rw] type
  #   @return [::Google::Cloud::Dataplex::V1::EntryLink::EntryReference::Type]
  #     Required. Immutable. The reference type of the Entry.
  class EntryReference
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Reference type of the Entry.
    module Type
      # Unspecified reference type. Implies that the Entry is referenced
      # in a non-directional Entry Link.
      UNSPECIFIED = 0

      # The Entry is referenced as the source of the directional Entry Link.
      SOURCE = 2

      # The Entry is referenced as the target of the directional Entry Link.
      TARGET = 3
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dataplex::V1::Aspect]
  class AspectsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#entry_link_type::String

Returns Required. Immutable. Relative resource name of the Entry Link Type used to create this Entry Link. For example:

  • Entry link between synonym terms in a glossary: projects/dataplex-types/locations/global/entryLinkTypes/synonym
  • Entry link between related terms in a glossary: projects/dataplex-types/locations/global/entryLinkTypes/related
  • Entry link between glossary terms and data assets: projects/dataplex-types/locations/global/entryLinkTypes/definition.

Returns:

  • (::String)

    Required. Immutable. Relative resource name of the Entry Link Type used to create this Entry Link. For example:

    • Entry link between synonym terms in a glossary: projects/dataplex-types/locations/global/entryLinkTypes/synonym
    • Entry link between related terms in a glossary: projects/dataplex-types/locations/global/entryLinkTypes/related
    • Entry link between glossary terms and data assets: projects/dataplex-types/locations/global/entryLinkTypes/definition


1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
1916
1917
1918
1919
1920
1921
1922
1923
1924
1925
1926
1927
1928
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 1884

class EntryLink
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Reference to the Entry that is linked through the Entry Link.
  # @!attribute [rw] name
  #   @return [::String]
  #     Required. Immutable. The relative resource name of the referenced Entry,
  #     of the form:
  #     `projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}/entries/{entry_id}`
  # @!attribute [rw] path
  #   @return [::String]
  #     Immutable. The path in the Entry that is referenced in the Entry Link.
  #     Empty path denotes that the Entry itself is referenced in the Entry
  #     Link.
  # @!attribute [rw] type
  #   @return [::Google::Cloud::Dataplex::V1::EntryLink::EntryReference::Type]
  #     Required. Immutable. The reference type of the Entry.
  class EntryReference
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Reference type of the Entry.
    module Type
      # Unspecified reference type. Implies that the Entry is referenced
      # in a non-directional Entry Link.
      UNSPECIFIED = 0

      # The Entry is referenced as the source of the directional Entry Link.
      SOURCE = 2

      # The Entry is referenced as the target of the directional Entry Link.
      TARGET = 3
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dataplex::V1::Aspect]
  class AspectsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#entry_references::Array<::Google::Cloud::Dataplex::V1::EntryLink::EntryReference>

Returns Required. Immutable. Specifies the Entries referenced in the Entry Link. There should be exactly two entry references.

Returns:



1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
1916
1917
1918
1919
1920
1921
1922
1923
1924
1925
1926
1927
1928
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 1884

class EntryLink
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Reference to the Entry that is linked through the Entry Link.
  # @!attribute [rw] name
  #   @return [::String]
  #     Required. Immutable. The relative resource name of the referenced Entry,
  #     of the form:
  #     `projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}/entries/{entry_id}`
  # @!attribute [rw] path
  #   @return [::String]
  #     Immutable. The path in the Entry that is referenced in the Entry Link.
  #     Empty path denotes that the Entry itself is referenced in the Entry
  #     Link.
  # @!attribute [rw] type
  #   @return [::Google::Cloud::Dataplex::V1::EntryLink::EntryReference::Type]
  #     Required. Immutable. The reference type of the Entry.
  class EntryReference
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Reference type of the Entry.
    module Type
      # Unspecified reference type. Implies that the Entry is referenced
      # in a non-directional Entry Link.
      UNSPECIFIED = 0

      # The Entry is referenced as the source of the directional Entry Link.
      SOURCE = 2

      # The Entry is referenced as the target of the directional Entry Link.
      TARGET = 3
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dataplex::V1::Aspect]
  class AspectsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#name::String (readonly)

Returns Output only. Immutable. Identifier. The relative resource name of the Entry Link, of the form: projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}/entryLinks/{entry_link_id}.

Returns:

  • (::String)

    Output only. Immutable. Identifier. The relative resource name of the Entry Link, of the form: projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}/entryLinks/{entry_link_id}



1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
1916
1917
1918
1919
1920
1921
1922
1923
1924
1925
1926
1927
1928
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 1884

class EntryLink
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Reference to the Entry that is linked through the Entry Link.
  # @!attribute [rw] name
  #   @return [::String]
  #     Required. Immutable. The relative resource name of the referenced Entry,
  #     of the form:
  #     `projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}/entries/{entry_id}`
  # @!attribute [rw] path
  #   @return [::String]
  #     Immutable. The path in the Entry that is referenced in the Entry Link.
  #     Empty path denotes that the Entry itself is referenced in the Entry
  #     Link.
  # @!attribute [rw] type
  #   @return [::Google::Cloud::Dataplex::V1::EntryLink::EntryReference::Type]
  #     Required. Immutable. The reference type of the Entry.
  class EntryReference
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Reference type of the Entry.
    module Type
      # Unspecified reference type. Implies that the Entry is referenced
      # in a non-directional Entry Link.
      UNSPECIFIED = 0

      # The Entry is referenced as the source of the directional Entry Link.
      SOURCE = 2

      # The Entry is referenced as the target of the directional Entry Link.
      TARGET = 3
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dataplex::V1::Aspect]
  class AspectsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time when the Entry Link was last updated.

Returns:



1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
1916
1917
1918
1919
1920
1921
1922
1923
1924
1925
1926
1927
1928
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 1884

class EntryLink
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Reference to the Entry that is linked through the Entry Link.
  # @!attribute [rw] name
  #   @return [::String]
  #     Required. Immutable. The relative resource name of the referenced Entry,
  #     of the form:
  #     `projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}/entries/{entry_id}`
  # @!attribute [rw] path
  #   @return [::String]
  #     Immutable. The path in the Entry that is referenced in the Entry Link.
  #     Empty path denotes that the Entry itself is referenced in the Entry
  #     Link.
  # @!attribute [rw] type
  #   @return [::Google::Cloud::Dataplex::V1::EntryLink::EntryReference::Type]
  #     Required. Immutable. The reference type of the Entry.
  class EntryReference
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Reference type of the Entry.
    module Type
      # Unspecified reference type. Implies that the Entry is referenced
      # in a non-directional Entry Link.
      UNSPECIFIED = 0

      # The Entry is referenced as the source of the directional Entry Link.
      SOURCE = 2

      # The Entry is referenced as the target of the directional Entry Link.
      TARGET = 3
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dataplex::V1::Aspect]
  class AspectsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end