Class: Google::Cloud::Dataplex::V1::EntryLink::EntryReference

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataplex/v1/catalog.rb

Overview

Reference to the Entry that is linked through the Entry Link.

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Required. Immutable. The relative resource name of the referenced Entry, of the form: projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}/entries/{entry_id}.

Returns:

  • (::String)

    Required. Immutable. The relative resource name of the referenced Entry, of the form: projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}/entries/{entry_id}



1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
1916
1917
1918
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 1902

class EntryReference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Reference type of the Entry.
  module Type
    # Unspecified reference type. Implies that the Entry is referenced
    # in a non-directional Entry Link.
    UNSPECIFIED = 0

    # The Entry is referenced as the source of the directional Entry Link.
    SOURCE = 2

    # The Entry is referenced as the target of the directional Entry Link.
    TARGET = 3
  end
end

#path::String

Returns Immutable. The path in the Entry that is referenced in the Entry Link. Empty path denotes that the Entry itself is referenced in the Entry Link.

Returns:

  • (::String)

    Immutable. The path in the Entry that is referenced in the Entry Link. Empty path denotes that the Entry itself is referenced in the Entry Link.



1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
1916
1917
1918
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 1902

class EntryReference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Reference type of the Entry.
  module Type
    # Unspecified reference type. Implies that the Entry is referenced
    # in a non-directional Entry Link.
    UNSPECIFIED = 0

    # The Entry is referenced as the source of the directional Entry Link.
    SOURCE = 2

    # The Entry is referenced as the target of the directional Entry Link.
    TARGET = 3
  end
end

#type::Google::Cloud::Dataplex::V1::EntryLink::EntryReference::Type

Returns Required. Immutable. The reference type of the Entry.

Returns:



1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
1916
1917
1918
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 1902

class EntryReference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Reference type of the Entry.
  module Type
    # Unspecified reference type. Implies that the Entry is referenced
    # in a non-directional Entry Link.
    UNSPECIFIED = 0

    # The Entry is referenced as the source of the directional Entry Link.
    SOURCE = 2

    # The Entry is referenced as the target of the directional Entry Link.
    TARGET = 3
  end
end