Class: Google::Cloud::Dataplex::V1::ExecutionIdentity::ServiceAccount

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataplex/v1/datascans.rb

Overview

The service account

Instance Attribute Summary collapse

Instance Attribute Details

#email::String

Returns Required. Service account email. The datascan will execute with this service account's credentials. The user calling this API must have permissions to act as this service account. Dataplex service agent must be granted iam.serviceAccounts.getAccessToken permission on this service account, for example, through the iam.serviceAccountTokenCreator role .

Returns:

  • (::String)

    Required. Service account email. The datascan will execute with this service account's credentials. The user calling this API must have permissions to act as this service account. Dataplex service agent must be granted iam.serviceAccounts.getAccessToken permission on this service account, for example, through the iam.serviceAccountTokenCreator role .



508
509
510
511
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 508

class ServiceAccount
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end