Class: Google::Cloud::Dataplex::V1::GetMetadataFeedRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataplex/v1/catalog.rb

Overview

Request message for GetMetadataFeed.

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Required. The resource name of the metadata feed, in the format projects/{project_id_or_number}/locations/{location_id}/MetadataFeeds/{metadata_feed_id}.

Returns:

  • (::String)

    Required. The resource name of the metadata feed, in the format projects/{project_id_or_number}/locations/{location_id}/MetadataFeeds/{metadata_feed_id}.



2192
2193
2194
2195
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 2192

class GetMetadataFeedRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end