Class: Google::Cloud::Dataplex::V1::ListDataAssetsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataplex/v1/data_products.rb

Overview

Request message for listing data assets.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Optional. Filter expression that filters data assets listed in the response.

Returns:

  • (::String)

    Optional. Filter expression that filters data assets listed in the response.



547
548
549
550
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 547

class ListDataAssetsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#order_by::String

Returns Optional. Order by expression that orders data assets listed in the response.

Supported order_by fields are: name or create_time.

If not specified, the ordering is undefined.

Returns:

  • (::String)

    Optional. Order by expression that orders data assets listed in the response.

    Supported order_by fields are: name or create_time.

    If not specified, the ordering is undefined.



547
548
549
550
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 547

class ListDataAssetsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Optional. The maximum number of data assets to return. The service may return fewer than this value. If unspecified, at most 50 data assets will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.

Returns:

  • (::Integer)

    Optional. The maximum number of data assets to return. The service may return fewer than this value. If unspecified, at most 50 data assets will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.



547
548
549
550
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 547

class ListDataAssetsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A page token, received from a previous ListDataAssets call. Provide this to retrieve the subsequent page.

When paginating, all other parameters provided to ListDataAssets must match the call that provided the page token.

Returns:

  • (::String)

    Optional. A page token, received from a previous ListDataAssets call. Provide this to retrieve the subsequent page.

    When paginating, all other parameters provided to ListDataAssets must match the call that provided the page token.



547
548
549
550
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 547

class ListDataAssetsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent, which has this collection of data assets. Format: projects/{project_id_or_number}/locations/{location_id}/dataProducts/{data_product_id}.

Returns:

  • (::String)

    Required. The parent, which has this collection of data assets. Format: projects/{project_id_or_number}/locations/{location_id}/dataProducts/{data_product_id}



547
548
549
550
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 547

class ListDataAssetsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end