Class: Google::Cloud::Dataplex::V1::ListDataProductsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataplex/v1/data_products.rb

Overview

Request message for listing data products.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Optional. Filter expression that filters data products listed in the response.

Example of using this filter is: display_name="my-data-product".

Returns:

  • (::String)

    Optional. Filter expression that filters data products listed in the response.

    Example of using this filter is: display_name="my-data-product"



369
370
371
372
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 369

class ListDataProductsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#order_by::String

Returns Optional. Order by expression that orders data products listed in the response.

Supported Order by fields are: name or create_time.

If not specified, the ordering is undefined.

Ordering by create_time is not supported when listing resources across locations (i.e. when request contains /locations/-).

Returns:

  • (::String)

    Optional. Order by expression that orders data products listed in the response.

    Supported Order by fields are: name or create_time.

    If not specified, the ordering is undefined.

    Ordering by create_time is not supported when listing resources across locations (i.e. when request contains /locations/-).



369
370
371
372
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 369

class ListDataProductsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Optional. The maximum number of data products to return. The service may return fewer than this value. If unspecified, at most 50 data products will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.

Returns:

  • (::Integer)

    Optional. The maximum number of data products to return. The service may return fewer than this value. If unspecified, at most 50 data products will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.



369
370
371
372
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 369

class ListDataProductsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A page token, received from a previous ListDataProducts call. Provide this to retrieve the subsequent page.

When paginating, all other parameters provided to ListDataProducts must match the call that provided the page token.

Returns:

  • (::String)

    Optional. A page token, received from a previous ListDataProducts call. Provide this to retrieve the subsequent page.

    When paginating, all other parameters provided to ListDataProducts must match the call that provided the page token.



369
370
371
372
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 369

class ListDataProductsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent, which has this collection of data products.

Format: projects/{project_id_or_number}/locations/{location_id}.

Supports listing across all locations with the wildcard - (hyphen) character. Example: projects/{project_id_or_number}/locations/-.

Returns:

  • (::String)

    Required. The parent, which has this collection of data products.

    Format: projects/{project_id_or_number}/locations/{location_id}.

    Supports listing across all locations with the wildcard - (hyphen) character. Example: projects/{project_id_or_number}/locations/-



369
370
371
372
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 369

class ListDataProductsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end