Class: Google::Cloud::Dataplex::V1::ListMetadataFeedsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataplex/v1/catalog.rb

Overview

Request message for ListMetadataFeedsRequest.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Optional. Filter request. Filters are case-sensitive. The service supports the following formats:

  • labels.key1 = "value1"
  • labels:key1
  • name = "value"

You can combine filters with AND, OR, and NOT operators.

Returns:

  • (::String)

    Optional. Filter request. Filters are case-sensitive. The service supports the following formats:

    • labels.key1 = "value1"
    • labels:key1
    • name = "value"

    You can combine filters with AND, OR, and NOT operators.



2228
2229
2230
2231
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 2228

class ListMetadataFeedsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#order_by::String

Returns Optional. The field to sort the results by, either name or create_time. If not specified, the ordering is undefined.

Returns:

  • (::String)

    Optional. The field to sort the results by, either name or create_time. If not specified, the ordering is undefined.



2228
2229
2230
2231
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 2228

class ListMetadataFeedsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns Optional. The maximum number of metadata feeds to return. The service might return fewer feeds than this value. If unspecified, at most 10 feeds are returned. The maximum value is 1,000.

Returns:

  • (::Integer)

    Optional. The maximum number of metadata feeds to return. The service might return fewer feeds than this value. If unspecified, at most 10 feeds are returned. The maximum value is 1,000.



2228
2229
2230
2231
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 2228

class ListMetadataFeedsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. The page token received from a previous ListMetadataFeeds call. Provide this token to retrieve the subsequent page of results. When paginating, all other parameters that are provided to the ListMetadataFeeds request must match the call that provided the page token.

Returns:

  • (::String)

    Optional. The page token received from a previous ListMetadataFeeds call. Provide this token to retrieve the subsequent page of results. When paginating, all other parameters that are provided to the ListMetadataFeeds request must match the call that provided the page token.



2228
2229
2230
2231
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 2228

class ListMetadataFeedsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The resource name of the parent location, in the format projects/{project_id_or_number}/locations/{location_id}.

Returns:

  • (::String)

    Required. The resource name of the parent location, in the format projects/{project_id_or_number}/locations/{location_id}



2228
2229
2230
2231
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 2228

class ListMetadataFeedsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end