Class: Google::Cloud::Dataplex::V1::ListMetadataFeedsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataplex/v1/catalog.rb

Overview

Response message for ListMetadataFeeds.

Instance Attribute Summary collapse

Instance Attribute Details

#metadata_feeds::Array<::Google::Cloud::Dataplex::V1::MetadataFeed>

Returns List of metadata feeds under the specified parent location.

Returns:



2244
2245
2246
2247
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 2244

class ListMetadataFeedsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String

Returns A token to retrieve the next page of results. If there are no more results in the list, the value is empty.

Returns:

  • (::String)

    A token to retrieve the next page of results. If there are no more results in the list, the value is empty.



2244
2245
2246
2247
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 2244

class ListMetadataFeedsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#unreachable::Array<::String>

Returns Unordered list. Locations that the service couldn't reach.

Returns:

  • (::Array<::String>)

    Unordered list. Locations that the service couldn't reach.



2244
2245
2246
2247
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 2244

class ListMetadataFeedsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end