Class: Google::Cloud::Dataplex::V1::LookupContextResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataplex/v1/catalog.rb

Overview

Lookup Context response.

Instance Attribute Summary collapse

Instance Attribute Details

#context::String

Returns Pre-formatted block of text containing the context for the requested resources.

Returns:

  • (::String)

    Pre-formatted block of text containing the context for the requested resources.



1164
1165
1166
1167
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 1164

class LookupContextResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end