Class: Google::Cloud::Dataplex::V1::LookupEntryLinksRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataplex/v1/catalog.rb

Overview

Request message for LookupEntryLinks.

Defined Under Namespace

Modules: EntryMode

Instance Attribute Summary collapse

Instance Attribute Details

#entry::String

Returns Required. The resource name of the referred Entry. Format: projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}/entries/{entry_id}. Entry Links which references this entry will be returned in the response.

Returns:

  • (::String)

    Required. The resource name of the referred Entry. Format: projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}/entries/{entry_id}. Entry Links which references this entry will be returned in the response.



2011
2012
2013
2014
2015
2016
2017
2018
2019
2020
2021
2022
2023
2024
2025
2026
2027
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 2011

class LookupEntryLinksRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Mode of entry reference.
  module EntryMode
    # Unspecified entry mode. Returns both directional and non-directional
    # entry links which references the entry.
    ENTRY_MODE_UNSPECIFIED = 0

    # Returns all directed entry links which references the entry as source.
    SOURCE = 1

    # Return all directed entry links which references the entry as target.
    TARGET = 2
  end
end

#entry_link_types::Array<::String>

Returns Entry link types to filter the response by. If empty, all entry link types will be returned. At most 10 entry link types can be specified.

Returns:

  • (::Array<::String>)

    Entry link types to filter the response by. If empty, all entry link types will be returned. At most 10 entry link types can be specified.



2011
2012
2013
2014
2015
2016
2017
2018
2019
2020
2021
2022
2023
2024
2025
2026
2027
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 2011

class LookupEntryLinksRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Mode of entry reference.
  module EntryMode
    # Unspecified entry mode. Returns both directional and non-directional
    # entry links which references the entry.
    ENTRY_MODE_UNSPECIFIED = 0

    # Returns all directed entry links which references the entry as source.
    SOURCE = 1

    # Return all directed entry links which references the entry as target.
    TARGET = 2
  end
end

#entry_mode::Google::Cloud::Dataplex::V1::LookupEntryLinksRequest::EntryMode

Returns Mode of entry reference.



2011
2012
2013
2014
2015
2016
2017
2018
2019
2020
2021
2022
2023
2024
2025
2026
2027
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 2011

class LookupEntryLinksRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Mode of entry reference.
  module EntryMode
    # Unspecified entry mode. Returns both directional and non-directional
    # entry links which references the entry.
    ENTRY_MODE_UNSPECIFIED = 0

    # Returns all directed entry links which references the entry as source.
    SOURCE = 1

    # Return all directed entry links which references the entry as target.
    TARGET = 2
  end
end

#name::String

Returns Required. The project to which the request should be attributed to Format: projects/{project_id_or_number}/locations/{location_id}.

Returns:

  • (::String)

    Required. The project to which the request should be attributed to Format: projects/{project_id_or_number}/locations/{location_id}.



2011
2012
2013
2014
2015
2016
2017
2018
2019
2020
2021
2022
2023
2024
2025
2026
2027
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 2011

class LookupEntryLinksRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Mode of entry reference.
  module EntryMode
    # Unspecified entry mode. Returns both directional and non-directional
    # entry links which references the entry.
    ENTRY_MODE_UNSPECIFIED = 0

    # Returns all directed entry links which references the entry as source.
    SOURCE = 1

    # Return all directed entry links which references the entry as target.
    TARGET = 2
  end
end

#page_size::Integer

Returns Maximum number of EntryLinks to return. The service may return fewer than this value. If unspecified, at most 10 EntryLinks will be returned. The maximum value is 10; values above 10 will be coerced to 10.

Returns:

  • (::Integer)

    Maximum number of EntryLinks to return. The service may return fewer than this value. If unspecified, at most 10 EntryLinks will be returned. The maximum value is 10; values above 10 will be coerced to 10.



2011
2012
2013
2014
2015
2016
2017
2018
2019
2020
2021
2022
2023
2024
2025
2026
2027
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 2011

class LookupEntryLinksRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Mode of entry reference.
  module EntryMode
    # Unspecified entry mode. Returns both directional and non-directional
    # entry links which references the entry.
    ENTRY_MODE_UNSPECIFIED = 0

    # Returns all directed entry links which references the entry as source.
    SOURCE = 1

    # Return all directed entry links which references the entry as target.
    TARGET = 2
  end
end

#page_token::String

Returns Page token received from a previous LookupEntryLinks call. Provide this to retrieve the subsequent page. When paginating, all other parameters that are provided to the LookupEntryLinks request must match the call that provided the page token.

Returns:

  • (::String)

    Page token received from a previous LookupEntryLinks call. Provide this to retrieve the subsequent page. When paginating, all other parameters that are provided to the LookupEntryLinks request must match the call that provided the page token.



2011
2012
2013
2014
2015
2016
2017
2018
2019
2020
2021
2022
2023
2024
2025
2026
2027
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 2011

class LookupEntryLinksRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Mode of entry reference.
  module EntryMode
    # Unspecified entry mode. Returns both directional and non-directional
    # entry links which references the entry.
    ENTRY_MODE_UNSPECIFIED = 0

    # Returns all directed entry links which references the entry as source.
    SOURCE = 1

    # Return all directed entry links which references the entry as target.
    TARGET = 2
  end
end