Module: Google::Cloud::Dataplex::V1::LookupEntryLinksRequest::EntryMode

Defined in:
proto_docs/google/cloud/dataplex/v1/catalog.rb

Overview

Mode of entry reference.

Constant Summary collapse

ENTRY_MODE_UNSPECIFIED =

Unspecified entry mode. Returns both directional and non-directional entry links which references the entry.

0
SOURCE =

Returns all directed entry links which references the entry as source.

1
TARGET =

Return all directed entry links which references the entry as target.

2