Class: Google::Cloud::Dataplex::V1::MetadataJob::ExportJobSpec

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataplex/v1/catalog.rb

Overview

Job specification for a metadata export job.

Defined Under Namespace

Classes: ExportJobScope

Instance Attribute Summary collapse

Instance Attribute Details

#output_path::String

Returns Required. The root path of the Cloud Storage bucket to export the metadata to, in the format gs://{bucket}/. You can optionally specify a custom prefix after the bucket name, in the format gs://{bucket}/{prefix}/. The maximum length of the custom prefix is 128 characters. Dataplex Universal Catalog constructs the object path for the exported files by using the bucket name and prefix that you provide, followed by a system-generated path.

The bucket must be in the same VPC Service Controls perimeter as the job.

Returns:

  • (::String)

    Required. The root path of the Cloud Storage bucket to export the metadata to, in the format gs://{bucket}/. You can optionally specify a custom prefix after the bucket name, in the format gs://{bucket}/{prefix}/. The maximum length of the custom prefix is 128 characters. Dataplex Universal Catalog constructs the object path for the exported files by using the bucket name and prefix that you provide, followed by a system-generated path.

    The bucket must be in the same VPC Service Controls perimeter as the job.



1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
1744
1745
1746
1747
1748
1749
1750
1751
1752
1753
1754
1755
1756
1757
1758
1759
1760
1761
1762
1763
1764
1765
1766
1767
1768
1769
1770
1771
1772
1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 1722

class ExportJobSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The scope of the export job.
  # @!attribute [rw] organization_level
  #   @return [::Boolean]
  #     Whether the metadata export job is an organization-level export job.
  #
  #     - If `true`, the job exports the entries from the same organization and
  #     VPC Service Controls perimeter as the job. The project that the job
  #     belongs to determines the VPC Service Controls perimeter. If you set
  #     the job scope to be at the organization level, then don't provide a
  #     list of projects or entry groups.
  #     - If `false`, you must specify a list of projects or a list of entry
  #     groups whose entries you want to export.
  #
  #     The default is `false`.
  # @!attribute [rw] projects
  #   @return [::Array<::String>]
  #     The projects whose metadata you want to export, in the format
  #     `projects/{project_id_or_number}`. Only the entries from
  #     the specified projects are exported.
  #
  #     The projects must be in the same organization and VPC Service Controls
  #     perimeter as the job.
  #
  #     If you set the job scope to be a list of projects, then set the
  #     organization-level export flag to false and don't provide a list of
  #     entry groups.
  # @!attribute [rw] entry_groups
  #   @return [::Array<::String>]
  #     The entry groups whose metadata you want to export, in the format
  #     `projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}`.
  #     Only the entries in the specified entry groups are exported.
  #
  #     The entry groups must be in the same location and the same VPC Service
  #     Controls perimeter as the job.
  #
  #     If you set the job scope to be a list of entry groups, then set the
  #     organization-level export flag to false and don't provide a list of
  #     projects.
  # @!attribute [rw] entry_types
  #   @return [::Array<::String>]
  #     The entry types that are in scope for the export job, specified as
  #     relative resource names in the format
  #     `projects/{project_id_or_number}/locations/{location}/entryTypes/{entry_type_id}`.
  #     Only entries that belong to the specified entry types are affected by
  #     the job.
  # @!attribute [rw] aspect_types
  #   @return [::Array<::String>]
  #     The aspect types that are in scope for the export job, specified as
  #     relative resource names in the format
  #     `projects/{project_id_or_number}/locations/{location}/aspectTypes/{aspect_type_id}`.
  #     Only aspects that belong to the specified aspect types are affected by
  #     the job.
  class ExportJobScope
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#scope::Google::Cloud::Dataplex::V1::MetadataJob::ExportJobSpec::ExportJobScope

Returns Required. The scope of the export job.

Returns:



1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
1744
1745
1746
1747
1748
1749
1750
1751
1752
1753
1754
1755
1756
1757
1758
1759
1760
1761
1762
1763
1764
1765
1766
1767
1768
1769
1770
1771
1772
1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 1722

class ExportJobSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The scope of the export job.
  # @!attribute [rw] organization_level
  #   @return [::Boolean]
  #     Whether the metadata export job is an organization-level export job.
  #
  #     - If `true`, the job exports the entries from the same organization and
  #     VPC Service Controls perimeter as the job. The project that the job
  #     belongs to determines the VPC Service Controls perimeter. If you set
  #     the job scope to be at the organization level, then don't provide a
  #     list of projects or entry groups.
  #     - If `false`, you must specify a list of projects or a list of entry
  #     groups whose entries you want to export.
  #
  #     The default is `false`.
  # @!attribute [rw] projects
  #   @return [::Array<::String>]
  #     The projects whose metadata you want to export, in the format
  #     `projects/{project_id_or_number}`. Only the entries from
  #     the specified projects are exported.
  #
  #     The projects must be in the same organization and VPC Service Controls
  #     perimeter as the job.
  #
  #     If you set the job scope to be a list of projects, then set the
  #     organization-level export flag to false and don't provide a list of
  #     entry groups.
  # @!attribute [rw] entry_groups
  #   @return [::Array<::String>]
  #     The entry groups whose metadata you want to export, in the format
  #     `projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}`.
  #     Only the entries in the specified entry groups are exported.
  #
  #     The entry groups must be in the same location and the same VPC Service
  #     Controls perimeter as the job.
  #
  #     If you set the job scope to be a list of entry groups, then set the
  #     organization-level export flag to false and don't provide a list of
  #     projects.
  # @!attribute [rw] entry_types
  #   @return [::Array<::String>]
  #     The entry types that are in scope for the export job, specified as
  #     relative resource names in the format
  #     `projects/{project_id_or_number}/locations/{location}/entryTypes/{entry_type_id}`.
  #     Only entries that belong to the specified entry types are affected by
  #     the job.
  # @!attribute [rw] aspect_types
  #   @return [::Array<::String>]
  #     The aspect types that are in scope for the export job, specified as
  #     relative resource names in the format
  #     `projects/{project_id_or_number}/locations/{location}/aspectTypes/{aspect_type_id}`.
  #     Only aspects that belong to the specified aspect types are affected by
  #     the job.
  class ExportJobScope
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end