Class: Google::Cloud::Dataplex::V1::MetadataJob::ExportJobSpec::ExportJobScope
- Inherits:
-
Object
- Object
- Google::Cloud::Dataplex::V1::MetadataJob::ExportJobSpec::ExportJobScope
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataplex/v1/catalog.rb
Overview
The scope of the export job.
Instance Attribute Summary collapse
-
#aspect_types ⇒ ::Array<::String>
The aspect types that are in scope for the export job, specified as relative resource names in the format
projects/{project_id_or_number}/locations/{location}/aspectTypes/{aspect_type_id}. -
#entry_groups ⇒ ::Array<::String>
The entry groups whose metadata you want to export, in the format
projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}. -
#entry_types ⇒ ::Array<::String>
The entry types that are in scope for the export job, specified as relative resource names in the format
projects/{project_id_or_number}/locations/{location}/entryTypes/{entry_type_id}. -
#organization_level ⇒ ::Boolean
Whether the metadata export job is an organization-level export job.
-
#projects ⇒ ::Array<::String>
The projects whose metadata you want to export, in the format
projects/{project_id_or_number}.
Instance Attribute Details
#aspect_types ⇒ ::Array<::String>
1676 1677 1678 1679 |
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 1676 class ExportJobScope include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#entry_groups ⇒ ::Array<::String>
1676 1677 1678 1679 |
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 1676 class ExportJobScope include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#entry_types ⇒ ::Array<::String>
1676 1677 1678 1679 |
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 1676 class ExportJobScope include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#organization_level ⇒ ::Boolean
1676 1677 1678 1679 |
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 1676 class ExportJobScope include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#projects ⇒ ::Array<::String>
1676 1677 1678 1679 |
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 1676 class ExportJobScope include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |