Class: Google::Cloud::Dataplex::V1::MetadataJob::Status

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataplex/v1/catalog.rb

Overview

Metadata job status.

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

#completion_percent::Integer (readonly)

Returns Output only. Progress tracking.

Returns:

  • (::Integer)

    Output only. Progress tracking.



1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 1695

class Status
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # State of a metadata job.
  module State
    # State unspecified.
    STATE_UNSPECIFIED = 0

    # The job is queued.
    QUEUED = 1

    # The job is running.
    RUNNING = 2

    # The job is being canceled.
    CANCELING = 3

    # The job is canceled.
    CANCELED = 4

    # The job succeeded.
    SUCCEEDED = 5

    # The job failed.
    FAILED = 6

    # The job completed with some errors.
    SUCCEEDED_WITH_ERRORS = 7
  end
end

#message::String (readonly)

Returns Output only. Message relating to the progression of a metadata job.

Returns:

  • (::String)

    Output only. Message relating to the progression of a metadata job.



1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 1695

class Status
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # State of a metadata job.
  module State
    # State unspecified.
    STATE_UNSPECIFIED = 0

    # The job is queued.
    QUEUED = 1

    # The job is running.
    RUNNING = 2

    # The job is being canceled.
    CANCELING = 3

    # The job is canceled.
    CANCELED = 4

    # The job succeeded.
    SUCCEEDED = 5

    # The job failed.
    FAILED = 6

    # The job completed with some errors.
    SUCCEEDED_WITH_ERRORS = 7
  end
end

#state::Google::Cloud::Dataplex::V1::MetadataJob::Status::State (readonly)

Returns Output only. State of the metadata job.

Returns:



1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 1695

class Status
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # State of a metadata job.
  module State
    # State unspecified.
    STATE_UNSPECIFIED = 0

    # The job is queued.
    QUEUED = 1

    # The job is running.
    RUNNING = 2

    # The job is being canceled.
    CANCELING = 3

    # The job is canceled.
    CANCELED = 4

    # The job succeeded.
    SUCCEEDED = 5

    # The job failed.
    FAILED = 6

    # The job completed with some errors.
    SUCCEEDED_WITH_ERRORS = 7
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time when the status was updated.

Returns:



1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 1695

class Status
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # State of a metadata job.
  module State
    # State unspecified.
    STATE_UNSPECIFIED = 0

    # The job is queued.
    QUEUED = 1

    # The job is running.
    RUNNING = 2

    # The job is being canceled.
    CANCELING = 3

    # The job is canceled.
    CANCELED = 4

    # The job succeeded.
    SUCCEEDED = 5

    # The job failed.
    FAILED = 6

    # The job completed with some errors.
    SUCCEEDED_WITH_ERRORS = 7
  end
end