Class: Google::Cloud::Dataplex::V1::RequestDataProductAccessRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataplex/v1/data_products.rb

Overview

Message for requesting access to a Data Product.

Instance Attribute Summary collapse

Instance Attribute Details

#change_request::Google::Cloud::Dataplex::V1::ChangeRequest

Returns Required. The change request for the data product access request.

Returns:



422
423
424
425
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 422

class RequestDataProductAccessRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The resource name of the data product. Format: projects/{project_number}/locations/{location_id}/dataProducts/{data_product_id}.

Returns:

  • (::String)

    Required. The resource name of the data product. Format: projects/{project_number}/locations/{location_id}/dataProducts/{data_product_id}



422
423
424
425
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 422

class RequestDataProductAccessRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#validate_only::Boolean

Returns Optional. Validates the request without actually creating the access change request. Defaults to false.

Returns:

  • (::Boolean)

    Optional. Validates the request without actually creating the access change request. Defaults to false.



422
423
424
425
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 422

class RequestDataProductAccessRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end