Class: Google::Cloud::Dataplex::V1::ScannedData
- Inherits:
-
Object
- Object
- Google::Cloud::Dataplex::V1::ScannedData
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataplex/v1/processing.rb
Overview
The data scanned during processing (e.g. in incremental DataScan)
Defined Under Namespace
Classes: IncrementalField
Instance Attribute Summary collapse
-
#incremental_field ⇒ ::Google::Cloud::Dataplex::V1::ScannedData::IncrementalField
The range denoted by values of an incremental field.
Instance Attribute Details
#incremental_field ⇒ ::Google::Cloud::Dataplex::V1::ScannedData::IncrementalField
Returns The range denoted by values of an incremental field.
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'proto_docs/google/cloud/dataplex/v1/processing.rb', line 119 class ScannedData include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A data range denoted by a pair of start/end values of a field. # @!attribute [r] field # @return [::String] # Output only. The field that contains values which monotonically increases # over time (e.g. a timestamp column). # @!attribute [r] start # @return [::String] # Output only. Value that marks the start of the range. # @!attribute [r] end # @return [::String] # Output only. Value that marks the end of the range. class IncrementalField include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |