Class: Google::Cloud::Dataplex::V1::Task::SparkTaskConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Dataplex::V1::Task::SparkTaskConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataplex/v1/tasks.rb
Overview
User-specified config for running a Spark task.
Instance Attribute Summary collapse
-
#archive_uris ⇒ ::Array<::String>
Optional.
-
#file_uris ⇒ ::Array<::String>
Optional.
-
#infrastructure_spec ⇒ ::Google::Cloud::Dataplex::V1::Task::InfrastructureSpec
Optional.
-
#main_class ⇒ ::String
The name of the driver's main class.
-
#main_jar_file_uri ⇒ ::String
The Cloud Storage URI of the jar file that contains the main class.
-
#python_script_file ⇒ ::String
The Gcloud Storage URI of the main Python file to use as the driver.
-
#sql_script ⇒ ::String
The query text.
-
#sql_script_file ⇒ ::String
A reference to a query file.
Instance Attribute Details
#archive_uris ⇒ ::Array<::String>
301 302 303 304 |
# File 'proto_docs/google/cloud/dataplex/v1/tasks.rb', line 301 class SparkTaskConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#file_uris ⇒ ::Array<::String>
301 302 303 304 |
# File 'proto_docs/google/cloud/dataplex/v1/tasks.rb', line 301 class SparkTaskConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#infrastructure_spec ⇒ ::Google::Cloud::Dataplex::V1::Task::InfrastructureSpec
301 302 303 304 |
# File 'proto_docs/google/cloud/dataplex/v1/tasks.rb', line 301 class SparkTaskConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#main_class ⇒ ::String
301 302 303 304 |
# File 'proto_docs/google/cloud/dataplex/v1/tasks.rb', line 301 class SparkTaskConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#main_jar_file_uri ⇒ ::String
301 302 303 304 |
# File 'proto_docs/google/cloud/dataplex/v1/tasks.rb', line 301 class SparkTaskConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#python_script_file ⇒ ::String
301 302 303 304 |
# File 'proto_docs/google/cloud/dataplex/v1/tasks.rb', line 301 class SparkTaskConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#sql_script ⇒ ::String
301 302 303 304 |
# File 'proto_docs/google/cloud/dataplex/v1/tasks.rb', line 301 class SparkTaskConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#sql_script_file ⇒ ::String
301 302 303 304 |
# File 'proto_docs/google/cloud/dataplex/v1/tasks.rb', line 301 class SparkTaskConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |