Class: Google::Cloud::Dataplex::V1::Trigger::OneTime
- Inherits:
-
Object
- Object
- Google::Cloud::Dataplex::V1::Trigger::OneTime
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataplex/v1/processing.rb
Overview
The scan runs once using create API.
Instance Attribute Summary collapse
Instance Attribute Details
#ttl_after_scan_completion ⇒ ::Google::Protobuf::Duration
Returns Optional. Time to live for OneTime scans. default value is 24 hours, minimum value is 0 seconds, and maximum value is 365 days. The time is calculated from the data scan job completion time. If value is set as 0 seconds, the scan will be immediately deleted upon job completion, regardless of whether the job succeeded or failed.
79 80 81 82 |
# File 'proto_docs/google/cloud/dataplex/v1/processing.rb', line 79 class OneTime include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |