Class: Google::Cloud::Dataplex::V1::UpdateDataAssetRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataplex/v1/data_products.rb

Overview

Request message for updating a data asset.

Instance Attribute Summary collapse

Instance Attribute Details

#data_asset::Google::Cloud::Dataplex::V1::DataAsset

Returns Required. The data asset to update. The data asset's name field is used to identify the data asset to update.

Returns:



479
480
481
482
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 479

class UpdateDataAssetRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_mask::Google::Protobuf::FieldMask

Returns Optional. The list of fields to update. If this is empty or not set, then all the fields will be updated.

Returns:



479
480
481
482
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 479

class UpdateDataAssetRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#validate_only::Boolean

Returns Optional. Validates the request without actually updating the data asset. Defaults to false.

Returns:

  • (::Boolean)

    Optional. Validates the request without actually updating the data asset. Defaults to false.



479
480
481
482
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 479

class UpdateDataAssetRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end