Class: Google::Cloud::Dataplex::V1::UpdateDataProductRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Dataplex::V1::UpdateDataProductRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataplex/v1/data_products.rb
Overview
Request message for updating a data product.
Instance Attribute Summary collapse
-
#data_product ⇒ ::Google::Cloud::Dataplex::V1::DataProduct
Required.
-
#update_mask ⇒ ::Google::Protobuf::FieldMask
Optional.
-
#validate_only ⇒ ::Boolean
Optional.
Instance Attribute Details
#data_product ⇒ ::Google::Cloud::Dataplex::V1::DataProduct
Returns Required. The data product to update.
The data product's name field is used to identify the data product to
update.
404 405 406 407 |
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 404 class UpdateDataProductRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_mask ⇒ ::Google::Protobuf::FieldMask
Returns Optional. The list of fields to update. If this is empty or not set, then all the fields will be updated.
404 405 406 407 |
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 404 class UpdateDataProductRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#validate_only ⇒ ::Boolean
Returns Optional. Validates the request without actually updating the data product. Default: false.
404 405 406 407 |
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 404 class UpdateDataProductRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |