Class: Google::Cloud::Dataplex::V1::AspectType::MetadataTemplate
- Inherits:
-
Object
- Object
- Google::Cloud::Dataplex::V1::AspectType::MetadataTemplate
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataplex/v1/catalog.rb
Overview
MetadataTemplate definition for an AspectType.
Defined Under Namespace
Classes: Annotations, Constraints, EnumValue
Instance Attribute Summary collapse
-
#annotations ⇒ ::Google::Cloud::Dataplex::V1::AspectType::MetadataTemplate::Annotations
Optional.
-
#array_items ⇒ ::Google::Cloud::Dataplex::V1::AspectType::MetadataTemplate
Optional.
-
#constraints ⇒ ::Google::Cloud::Dataplex::V1::AspectType::MetadataTemplate::Constraints
Optional.
-
#enum_values ⇒ ::Array<::Google::Cloud::Dataplex::V1::AspectType::MetadataTemplate::EnumValue>
Optional.
-
#index ⇒ ::Integer
Optional.
-
#map_items ⇒ ::Google::Cloud::Dataplex::V1::AspectType::MetadataTemplate
Optional.
-
#name ⇒ ::String
Required.
-
#record_fields ⇒ ::Array<::Google::Cloud::Dataplex::V1::AspectType::MetadataTemplate>
Optional.
-
#type ⇒ ::String
Required.
-
#type_id ⇒ ::String
Optional.
-
#type_ref ⇒ ::String
Optional.
Instance Attribute Details
#annotations ⇒ ::Google::Cloud::Dataplex::V1::AspectType::MetadataTemplate::Annotations
Returns Optional. Specifies annotations on this field.
152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 152 class MetadataTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Definition of Enumvalue, to be used for enum fields. # @!attribute [rw] index # @return [::Integer] # Required. Index for the enum value. It can't be modified. # @!attribute [rw] name # @return [::String] # Required. Name of the enumvalue. This is the actual value that the # aspect can contain. # @!attribute [rw] deprecated # @return [::String] # Optional. You can set this message if you need to deprecate an enum # value. class EnumValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Definition of the constraints of a field. # @!attribute [rw] required # @return [::Boolean] # Optional. Marks this field as optional or required. class Constraints include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Definition of the annotations of a field. # @!attribute [rw] deprecated # @return [::String] # Optional. Marks a field as deprecated. You can include a deprecation # message. # @!attribute [rw] display_name # @return [::String] # Optional. Display name for a field. # @!attribute [rw] description # @return [::String] # Optional. Description for a field. # @!attribute [rw] display_order # @return [::Integer] # Optional. Display order for a field. You can use this to reorder where # a field is rendered. # @!attribute [rw] string_type # @return [::String] # Optional. You can use String Type annotations to specify special # meaning to string fields. The following values are supported: # # * richText: The field must be interpreted as a rich text field. # * url: A fully qualified URL link. # * resource: A service qualified resource reference. # @!attribute [rw] string_values # @return [::Array<::String>] # Optional. Suggested hints for string fields. You can use them to # suggest values to users through console. class Annotations include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#array_items ⇒ ::Google::Cloud::Dataplex::V1::AspectType::MetadataTemplate
Returns Optional. If the type is array, set array_items. array_items can refer to a primitive field or a complex (record only) field. To specify a primitive field, you only need to set name and type in the nested MetadataTemplate. The recommended value for the name field is item, as this isn't used in the actual payload.
152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 152 class MetadataTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Definition of Enumvalue, to be used for enum fields. # @!attribute [rw] index # @return [::Integer] # Required. Index for the enum value. It can't be modified. # @!attribute [rw] name # @return [::String] # Required. Name of the enumvalue. This is the actual value that the # aspect can contain. # @!attribute [rw] deprecated # @return [::String] # Optional. You can set this message if you need to deprecate an enum # value. class EnumValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Definition of the constraints of a field. # @!attribute [rw] required # @return [::Boolean] # Optional. Marks this field as optional or required. class Constraints include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Definition of the annotations of a field. # @!attribute [rw] deprecated # @return [::String] # Optional. Marks a field as deprecated. You can include a deprecation # message. # @!attribute [rw] display_name # @return [::String] # Optional. Display name for a field. # @!attribute [rw] description # @return [::String] # Optional. Description for a field. # @!attribute [rw] display_order # @return [::Integer] # Optional. Display order for a field. You can use this to reorder where # a field is rendered. # @!attribute [rw] string_type # @return [::String] # Optional. You can use String Type annotations to specify special # meaning to string fields. The following values are supported: # # * richText: The field must be interpreted as a rich text field. # * url: A fully qualified URL link. # * resource: A service qualified resource reference. # @!attribute [rw] string_values # @return [::Array<::String>] # Optional. Suggested hints for string fields. You can use them to # suggest values to users through console. class Annotations include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#constraints ⇒ ::Google::Cloud::Dataplex::V1::AspectType::MetadataTemplate::Constraints
Returns Optional. Specifies the constraints on this field.
152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 152 class MetadataTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Definition of Enumvalue, to be used for enum fields. # @!attribute [rw] index # @return [::Integer] # Required. Index for the enum value. It can't be modified. # @!attribute [rw] name # @return [::String] # Required. Name of the enumvalue. This is the actual value that the # aspect can contain. # @!attribute [rw] deprecated # @return [::String] # Optional. You can set this message if you need to deprecate an enum # value. class EnumValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Definition of the constraints of a field. # @!attribute [rw] required # @return [::Boolean] # Optional. Marks this field as optional or required. class Constraints include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Definition of the annotations of a field. # @!attribute [rw] deprecated # @return [::String] # Optional. Marks a field as deprecated. You can include a deprecation # message. # @!attribute [rw] display_name # @return [::String] # Optional. Display name for a field. # @!attribute [rw] description # @return [::String] # Optional. Description for a field. # @!attribute [rw] display_order # @return [::Integer] # Optional. Display order for a field. You can use this to reorder where # a field is rendered. # @!attribute [rw] string_type # @return [::String] # Optional. You can use String Type annotations to specify special # meaning to string fields. The following values are supported: # # * richText: The field must be interpreted as a rich text field. # * url: A fully qualified URL link. # * resource: A service qualified resource reference. # @!attribute [rw] string_values # @return [::Array<::String>] # Optional. Suggested hints for string fields. You can use them to # suggest values to users through console. class Annotations include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#enum_values ⇒ ::Array<::Google::Cloud::Dataplex::V1::AspectType::MetadataTemplate::EnumValue>
Returns Optional. The list of values for an enum type. You must define it if the type is enum.
152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 152 class MetadataTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Definition of Enumvalue, to be used for enum fields. # @!attribute [rw] index # @return [::Integer] # Required. Index for the enum value. It can't be modified. # @!attribute [rw] name # @return [::String] # Required. Name of the enumvalue. This is the actual value that the # aspect can contain. # @!attribute [rw] deprecated # @return [::String] # Optional. You can set this message if you need to deprecate an enum # value. class EnumValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Definition of the constraints of a field. # @!attribute [rw] required # @return [::Boolean] # Optional. Marks this field as optional or required. class Constraints include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Definition of the annotations of a field. # @!attribute [rw] deprecated # @return [::String] # Optional. Marks a field as deprecated. You can include a deprecation # message. # @!attribute [rw] display_name # @return [::String] # Optional. Display name for a field. # @!attribute [rw] description # @return [::String] # Optional. Description for a field. # @!attribute [rw] display_order # @return [::Integer] # Optional. Display order for a field. You can use this to reorder where # a field is rendered. # @!attribute [rw] string_type # @return [::String] # Optional. You can use String Type annotations to specify special # meaning to string fields. The following values are supported: # # * richText: The field must be interpreted as a rich text field. # * url: A fully qualified URL link. # * resource: A service qualified resource reference. # @!attribute [rw] string_values # @return [::Array<::String>] # Optional. Suggested hints for string fields. You can use them to # suggest values to users through console. class Annotations include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#index ⇒ ::Integer
Returns Optional. Index is used to encode Template messages. The value of index can range between 1 and 2,147,483,647. Index must be unique within all fields in a Template. (Nested Templates can reuse indexes). Once a Template is defined, the index cannot be changed, because it identifies the field in the actual storage format. Index is a mandatory field, but it is optional for top level fields, and map/array "values" definitions.
152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 152 class MetadataTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Definition of Enumvalue, to be used for enum fields. # @!attribute [rw] index # @return [::Integer] # Required. Index for the enum value. It can't be modified. # @!attribute [rw] name # @return [::String] # Required. Name of the enumvalue. This is the actual value that the # aspect can contain. # @!attribute [rw] deprecated # @return [::String] # Optional. You can set this message if you need to deprecate an enum # value. class EnumValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Definition of the constraints of a field. # @!attribute [rw] required # @return [::Boolean] # Optional. Marks this field as optional or required. class Constraints include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Definition of the annotations of a field. # @!attribute [rw] deprecated # @return [::String] # Optional. Marks a field as deprecated. You can include a deprecation # message. # @!attribute [rw] display_name # @return [::String] # Optional. Display name for a field. # @!attribute [rw] description # @return [::String] # Optional. Description for a field. # @!attribute [rw] display_order # @return [::Integer] # Optional. Display order for a field. You can use this to reorder where # a field is rendered. # @!attribute [rw] string_type # @return [::String] # Optional. You can use String Type annotations to specify special # meaning to string fields. The following values are supported: # # * richText: The field must be interpreted as a rich text field. # * url: A fully qualified URL link. # * resource: A service qualified resource reference. # @!attribute [rw] string_values # @return [::Array<::String>] # Optional. Suggested hints for string fields. You can use them to # suggest values to users through console. class Annotations include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#map_items ⇒ ::Google::Cloud::Dataplex::V1::AspectType::MetadataTemplate
Returns Optional. If the type is map, set map_items. map_items can refer to a primitive field or a complex (record only) field. To specify a primitive field, you only need to set name and type in the nested MetadataTemplate. The recommended value for the name field is item, as this isn't used in the actual payload.
152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 152 class MetadataTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Definition of Enumvalue, to be used for enum fields. # @!attribute [rw] index # @return [::Integer] # Required. Index for the enum value. It can't be modified. # @!attribute [rw] name # @return [::String] # Required. Name of the enumvalue. This is the actual value that the # aspect can contain. # @!attribute [rw] deprecated # @return [::String] # Optional. You can set this message if you need to deprecate an enum # value. class EnumValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Definition of the constraints of a field. # @!attribute [rw] required # @return [::Boolean] # Optional. Marks this field as optional or required. class Constraints include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Definition of the annotations of a field. # @!attribute [rw] deprecated # @return [::String] # Optional. Marks a field as deprecated. You can include a deprecation # message. # @!attribute [rw] display_name # @return [::String] # Optional. Display name for a field. # @!attribute [rw] description # @return [::String] # Optional. Description for a field. # @!attribute [rw] display_order # @return [::Integer] # Optional. Display order for a field. You can use this to reorder where # a field is rendered. # @!attribute [rw] string_type # @return [::String] # Optional. You can use String Type annotations to specify special # meaning to string fields. The following values are supported: # # * richText: The field must be interpreted as a rich text field. # * url: A fully qualified URL link. # * resource: A service qualified resource reference. # @!attribute [rw] string_values # @return [::Array<::String>] # Optional. Suggested hints for string fields. You can use them to # suggest values to users through console. class Annotations include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#name ⇒ ::String
Returns Required. The name of the field.
152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 152 class MetadataTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Definition of Enumvalue, to be used for enum fields. # @!attribute [rw] index # @return [::Integer] # Required. Index for the enum value. It can't be modified. # @!attribute [rw] name # @return [::String] # Required. Name of the enumvalue. This is the actual value that the # aspect can contain. # @!attribute [rw] deprecated # @return [::String] # Optional. You can set this message if you need to deprecate an enum # value. class EnumValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Definition of the constraints of a field. # @!attribute [rw] required # @return [::Boolean] # Optional. Marks this field as optional or required. class Constraints include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Definition of the annotations of a field. # @!attribute [rw] deprecated # @return [::String] # Optional. Marks a field as deprecated. You can include a deprecation # message. # @!attribute [rw] display_name # @return [::String] # Optional. Display name for a field. # @!attribute [rw] description # @return [::String] # Optional. Description for a field. # @!attribute [rw] display_order # @return [::Integer] # Optional. Display order for a field. You can use this to reorder where # a field is rendered. # @!attribute [rw] string_type # @return [::String] # Optional. You can use String Type annotations to specify special # meaning to string fields. The following values are supported: # # * richText: The field must be interpreted as a rich text field. # * url: A fully qualified URL link. # * resource: A service qualified resource reference. # @!attribute [rw] string_values # @return [::Array<::String>] # Optional. Suggested hints for string fields. You can use them to # suggest values to users through console. class Annotations include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#record_fields ⇒ ::Array<::Google::Cloud::Dataplex::V1::AspectType::MetadataTemplate>
Returns Optional. Field definition. You must specify it if the type is record. It defines the nested fields.
152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 152 class MetadataTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Definition of Enumvalue, to be used for enum fields. # @!attribute [rw] index # @return [::Integer] # Required. Index for the enum value. It can't be modified. # @!attribute [rw] name # @return [::String] # Required. Name of the enumvalue. This is the actual value that the # aspect can contain. # @!attribute [rw] deprecated # @return [::String] # Optional. You can set this message if you need to deprecate an enum # value. class EnumValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Definition of the constraints of a field. # @!attribute [rw] required # @return [::Boolean] # Optional. Marks this field as optional or required. class Constraints include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Definition of the annotations of a field. # @!attribute [rw] deprecated # @return [::String] # Optional. Marks a field as deprecated. You can include a deprecation # message. # @!attribute [rw] display_name # @return [::String] # Optional. Display name for a field. # @!attribute [rw] description # @return [::String] # Optional. Description for a field. # @!attribute [rw] display_order # @return [::Integer] # Optional. Display order for a field. You can use this to reorder where # a field is rendered. # @!attribute [rw] string_type # @return [::String] # Optional. You can use String Type annotations to specify special # meaning to string fields. The following values are supported: # # * richText: The field must be interpreted as a rich text field. # * url: A fully qualified URL link. # * resource: A service qualified resource reference. # @!attribute [rw] string_values # @return [::Array<::String>] # Optional. Suggested hints for string fields. You can use them to # suggest values to users through console. class Annotations include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#type ⇒ ::String
Returns Required. The datatype of this field. The following values are supported:
Primitive types:
- string
- int
- bool
- double
- datetime. Must be of the format RFC3339 UTC "Zulu" (Examples: "2014-10-02T15:01:23Z" and "2014-10-02T15:01:23.045123456Z").
Complex types:
- enum
- array
- map
- record.
152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 152 class MetadataTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Definition of Enumvalue, to be used for enum fields. # @!attribute [rw] index # @return [::Integer] # Required. Index for the enum value. It can't be modified. # @!attribute [rw] name # @return [::String] # Required. Name of the enumvalue. This is the actual value that the # aspect can contain. # @!attribute [rw] deprecated # @return [::String] # Optional. You can set this message if you need to deprecate an enum # value. class EnumValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Definition of the constraints of a field. # @!attribute [rw] required # @return [::Boolean] # Optional. Marks this field as optional or required. class Constraints include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Definition of the annotations of a field. # @!attribute [rw] deprecated # @return [::String] # Optional. Marks a field as deprecated. You can include a deprecation # message. # @!attribute [rw] display_name # @return [::String] # Optional. Display name for a field. # @!attribute [rw] description # @return [::String] # Optional. Description for a field. # @!attribute [rw] display_order # @return [::Integer] # Optional. Display order for a field. You can use this to reorder where # a field is rendered. # @!attribute [rw] string_type # @return [::String] # Optional. You can use String Type annotations to specify special # meaning to string fields. The following values are supported: # # * richText: The field must be interpreted as a rich text field. # * url: A fully qualified URL link. # * resource: A service qualified resource reference. # @!attribute [rw] string_values # @return [::Array<::String>] # Optional. Suggested hints for string fields. You can use them to # suggest values to users through console. class Annotations include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#type_id ⇒ ::String
Returns Optional. You can use type id if this definition of the field needs to be reused later. The type id must be unique across the entire template. You can only specify it if the field type is record.
152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 152 class MetadataTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Definition of Enumvalue, to be used for enum fields. # @!attribute [rw] index # @return [::Integer] # Required. Index for the enum value. It can't be modified. # @!attribute [rw] name # @return [::String] # Required. Name of the enumvalue. This is the actual value that the # aspect can contain. # @!attribute [rw] deprecated # @return [::String] # Optional. You can set this message if you need to deprecate an enum # value. class EnumValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Definition of the constraints of a field. # @!attribute [rw] required # @return [::Boolean] # Optional. Marks this field as optional or required. class Constraints include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Definition of the annotations of a field. # @!attribute [rw] deprecated # @return [::String] # Optional. Marks a field as deprecated. You can include a deprecation # message. # @!attribute [rw] display_name # @return [::String] # Optional. Display name for a field. # @!attribute [rw] description # @return [::String] # Optional. Description for a field. # @!attribute [rw] display_order # @return [::Integer] # Optional. Display order for a field. You can use this to reorder where # a field is rendered. # @!attribute [rw] string_type # @return [::String] # Optional. You can use String Type annotations to specify special # meaning to string fields. The following values are supported: # # * richText: The field must be interpreted as a rich text field. # * url: A fully qualified URL link. # * resource: A service qualified resource reference. # @!attribute [rw] string_values # @return [::Array<::String>] # Optional. Suggested hints for string fields. You can use them to # suggest values to users through console. class Annotations include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#type_ref ⇒ ::String
Returns Optional. A reference to another field definition (not an inline definition). The value must be equal to the value of an id field defined elsewhere in the MetadataTemplate. Only fields with record type can refer to other fields.
152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 152 class MetadataTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Definition of Enumvalue, to be used for enum fields. # @!attribute [rw] index # @return [::Integer] # Required. Index for the enum value. It can't be modified. # @!attribute [rw] name # @return [::String] # Required. Name of the enumvalue. This is the actual value that the # aspect can contain. # @!attribute [rw] deprecated # @return [::String] # Optional. You can set this message if you need to deprecate an enum # value. class EnumValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Definition of the constraints of a field. # @!attribute [rw] required # @return [::Boolean] # Optional. Marks this field as optional or required. class Constraints include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Definition of the annotations of a field. # @!attribute [rw] deprecated # @return [::String] # Optional. Marks a field as deprecated. You can include a deprecation # message. # @!attribute [rw] display_name # @return [::String] # Optional. Display name for a field. # @!attribute [rw] description # @return [::String] # Optional. Description for a field. # @!attribute [rw] display_order # @return [::Integer] # Optional. Display order for a field. You can use this to reorder where # a field is rendered. # @!attribute [rw] string_type # @return [::String] # Optional. You can use String Type annotations to specify special # meaning to string fields. The following values are supported: # # * richText: The field must be interpreted as a rich text field. # * url: A fully qualified URL link. # * resource: A service qualified resource reference. # @!attribute [rw] string_values # @return [::Array<::String>] # Optional. Suggested hints for string fields. You can use them to # suggest values to users through console. class Annotations include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |