Class: Google::Cloud::Dataplex::V1::CreateDataAssetRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Dataplex::V1::CreateDataAssetRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataplex/v1/data_products.rb
Overview
Request message for creating a data asset.
Instance Attribute Summary collapse
-
#data_asset ⇒ ::Google::Cloud::Dataplex::V1::DataAsset
Required.
-
#data_asset_id ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
-
#validate_only ⇒ ::Boolean
Optional.
Instance Attribute Details
#data_asset ⇒ ::Google::Cloud::Dataplex::V1::DataAsset
Returns Required. The data asset to create.
461 462 463 464 |
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 461 class CreateDataAssetRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#data_asset_id ⇒ ::String
Returns Optional. The ID of the data asset to create.
The ID must conform to RFC-1034 and contain only lower-case letters (a-z),
numbers (0-9), or hyphens, with the first character a letter, the last a
letter or a number, and a 63 character maximum. Characters outside of
ASCII are not permitted.
Valid format regex: ^[a-z]([a-z0-9-]{0,61}[a-z0-9])?$
If not provided, a system generated ID will be used.
461 462 463 464 |
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 461 class CreateDataAssetRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The parent resource where this data asset will be created. Format: projects/{project_id_or_number}/locations/{location_id}/dataProducts/{data_product_id}.
461 462 463 464 |
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 461 class CreateDataAssetRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#validate_only ⇒ ::Boolean
Returns Optional. Validates the request without actually creating the data asset. Defaults to false.
461 462 463 464 |
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 461 class CreateDataAssetRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |