Class: Google::Cloud::Dataplex::V1::DataAsset::AccessGroupConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Dataplex::V1::DataAsset::AccessGroupConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataplex/v1/data_products.rb
Overview
Configuration for access group inherited from the parent data product.
Instance Attribute Summary collapse
-
#iam_roles ⇒ ::Array<::String>
Optional.
Instance Attribute Details
#iam_roles ⇒ ::Array<::String>
Returns Optional. IAM roles granted on the resource to this access group. Role name follows https://cloud.google.com/iam/docs/reference/rest/v1/roles.
Example: [ "roles/bigquery.dataViewer" ].
246 247 248 249 |
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 246 class AccessGroupConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |