Class: Google::Cloud::Dataplex::V1::DataDocumentationResult
- Inherits:
-
Object
- Object
- Google::Cloud::Dataplex::V1::DataDocumentationResult
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataplex/v1/data_documentation.rb
Overview
The output of a DataDocumentation scan.
Defined Under Namespace
Classes: DatasetResult, Field, Query, Schema, SchemaRelationship, TableResult
Instance Attribute Summary collapse
-
#dataset_result ⇒ ::Google::Cloud::Dataplex::V1::DataDocumentationResult::DatasetResult
readonly
Output only.
-
#table_result ⇒ ::Google::Cloud::Dataplex::V1::DataDocumentationResult::TableResult
readonly
Output only.
Instance Attribute Details
#dataset_result ⇒ ::Google::Cloud::Dataplex::V1::DataDocumentationResult::DatasetResult (readonly)
Returns Output only. Insights for a Dataset resource.
Note: The following fields are mutually exclusive: dataset_result, table_result. If a field in that set is populated, all other fields in the set will automatically be cleared.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'proto_docs/google/cloud/dataplex/v1/data_documentation.rb', line 67 class DataDocumentationResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Insights for a dataset resource. # @!attribute [r] overview # @return [::String] # Output only. Generated Dataset description. # @!attribute [r] schema_relationships # @return [::Array<::Google::Cloud::Dataplex::V1::DataDocumentationResult::SchemaRelationship>] # Output only. Relationships suggesting how tables in the dataset are # related to each other, based on their schema. # @!attribute [r] queries # @return [::Array<::Google::Cloud::Dataplex::V1::DataDocumentationResult::Query>] # Output only. Sample SQL queries for the dataset. class DatasetResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Insights for a table resource. # @!attribute [r] name # @return [::String] # Output only. The service-qualified full resource name of the cloud # resource. Ex: # //bigquery.googleapis.com/projects/PROJECT_ID/datasets/DATASET_ID/tables/TABLE_ID # @!attribute [r] overview # @return [::String] # Output only. Generated description of the table. # @!attribute [r] schema # @return [::Google::Cloud::Dataplex::V1::DataDocumentationResult::Schema] # Output only. Schema of the table with generated metadata of the columns # in the schema. # @!attribute [r] queries # @return [::Array<::Google::Cloud::Dataplex::V1::DataDocumentationResult::Query>] # Output only. Sample SQL queries for the table. class TableResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Details of the relationship between the schema of two resources. # @!attribute [r] left_schema_paths # @return [::Google::Cloud::Dataplex::V1::DataDocumentationResult::SchemaRelationship::SchemaPaths] # Output only. An ordered list of fields for the join from the first table. # The size of this list must be the same as `right_schema_paths`. # Each field at index i in this list must correspond to a field at the same # index in the `right_schema_paths` list. # @!attribute [r] right_schema_paths # @return [::Google::Cloud::Dataplex::V1::DataDocumentationResult::SchemaRelationship::SchemaPaths] # Output only. An ordered list of fields for the join from the second # table. The size of this list must be the same as `left_schema_paths`. # Each field at index i in this list must correspond to a field at the same # index in the `left_schema_paths` list. # @!attribute [r] sources # @return [::Array<::Google::Cloud::Dataplex::V1::DataDocumentationResult::SchemaRelationship::Source>] # Output only. Sources which generated the schema relation edge. # @!attribute [r] type # @return [::Google::Cloud::Dataplex::V1::DataDocumentationResult::SchemaRelationship::Type] # Output only. The type of relationship between the schema paths. class SchemaRelationship include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents an ordered set of paths within a table's schema. # @!attribute [r] table_fqn # @return [::String] # Output only. The service-qualified full resource name of the table # Ex: # //bigquery.googleapis.com/projects/PROJECT_ID/datasets/DATASET_ID/tables/TABLE_ID # @!attribute [r] paths # @return [::Array<::String>] # Output only. An ordered set of Paths to fields within the schema of the # table. For fields nested within a top level field of type record, use # '.' to separate field names. Examples: Top level field - `top_level` # Nested field - `top_level.child.sub_field` class SchemaPaths include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Source which generated the schema relation edge. module Source # The source of the schema relationship is unspecified. SOURCE_UNSPECIFIED = 0 # The source of the schema relationship is agent. AGENT = 4 # The source of the schema relationship is query history from the source # system. QUERY_HISTORY = 5 # The source of the schema relationship is table constraints added in # the source system. TABLE_CONSTRAINTS = 6 end # The type of relationship. module Type # The type of the schema relationship is unspecified. TYPE_UNSPECIFIED = 0 # Indicates a join relationship between the schema fields. SCHEMA_JOIN = 1 end end # A sample SQL query in data documentation. # @!attribute [r] sql # @return [::String] # Output only. The SQL query string which can be executed. # @!attribute [r] description # @return [::String] # Output only. The description for the query. class Query include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Schema of the table with generated metadata of columns. # @!attribute [r] fields # @return [::Array<::Google::Cloud::Dataplex::V1::DataDocumentationResult::Field>] # Output only. The list of columns. class Schema include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Column of a table with generated metadata and nested fields. # @!attribute [r] name # @return [::String] # Output only. The name of the column. # @!attribute [r] description # @return [::String] # Output only. Generated description for columns and fields. # @!attribute [r] fields # @return [::Array<::Google::Cloud::Dataplex::V1::DataDocumentationResult::Field>] # Output only. Nested fields. class Field include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#table_result ⇒ ::Google::Cloud::Dataplex::V1::DataDocumentationResult::TableResult (readonly)
Returns Output only. Insights for a Table resource.
Note: The following fields are mutually exclusive: table_result, dataset_result. If a field in that set is populated, all other fields in the set will automatically be cleared.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'proto_docs/google/cloud/dataplex/v1/data_documentation.rb', line 67 class DataDocumentationResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Insights for a dataset resource. # @!attribute [r] overview # @return [::String] # Output only. Generated Dataset description. # @!attribute [r] schema_relationships # @return [::Array<::Google::Cloud::Dataplex::V1::DataDocumentationResult::SchemaRelationship>] # Output only. Relationships suggesting how tables in the dataset are # related to each other, based on their schema. # @!attribute [r] queries # @return [::Array<::Google::Cloud::Dataplex::V1::DataDocumentationResult::Query>] # Output only. Sample SQL queries for the dataset. class DatasetResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Insights for a table resource. # @!attribute [r] name # @return [::String] # Output only. The service-qualified full resource name of the cloud # resource. Ex: # //bigquery.googleapis.com/projects/PROJECT_ID/datasets/DATASET_ID/tables/TABLE_ID # @!attribute [r] overview # @return [::String] # Output only. Generated description of the table. # @!attribute [r] schema # @return [::Google::Cloud::Dataplex::V1::DataDocumentationResult::Schema] # Output only. Schema of the table with generated metadata of the columns # in the schema. # @!attribute [r] queries # @return [::Array<::Google::Cloud::Dataplex::V1::DataDocumentationResult::Query>] # Output only. Sample SQL queries for the table. class TableResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Details of the relationship between the schema of two resources. # @!attribute [r] left_schema_paths # @return [::Google::Cloud::Dataplex::V1::DataDocumentationResult::SchemaRelationship::SchemaPaths] # Output only. An ordered list of fields for the join from the first table. # The size of this list must be the same as `right_schema_paths`. # Each field at index i in this list must correspond to a field at the same # index in the `right_schema_paths` list. # @!attribute [r] right_schema_paths # @return [::Google::Cloud::Dataplex::V1::DataDocumentationResult::SchemaRelationship::SchemaPaths] # Output only. An ordered list of fields for the join from the second # table. The size of this list must be the same as `left_schema_paths`. # Each field at index i in this list must correspond to a field at the same # index in the `left_schema_paths` list. # @!attribute [r] sources # @return [::Array<::Google::Cloud::Dataplex::V1::DataDocumentationResult::SchemaRelationship::Source>] # Output only. Sources which generated the schema relation edge. # @!attribute [r] type # @return [::Google::Cloud::Dataplex::V1::DataDocumentationResult::SchemaRelationship::Type] # Output only. The type of relationship between the schema paths. class SchemaRelationship include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents an ordered set of paths within a table's schema. # @!attribute [r] table_fqn # @return [::String] # Output only. The service-qualified full resource name of the table # Ex: # //bigquery.googleapis.com/projects/PROJECT_ID/datasets/DATASET_ID/tables/TABLE_ID # @!attribute [r] paths # @return [::Array<::String>] # Output only. An ordered set of Paths to fields within the schema of the # table. For fields nested within a top level field of type record, use # '.' to separate field names. Examples: Top level field - `top_level` # Nested field - `top_level.child.sub_field` class SchemaPaths include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Source which generated the schema relation edge. module Source # The source of the schema relationship is unspecified. SOURCE_UNSPECIFIED = 0 # The source of the schema relationship is agent. AGENT = 4 # The source of the schema relationship is query history from the source # system. QUERY_HISTORY = 5 # The source of the schema relationship is table constraints added in # the source system. TABLE_CONSTRAINTS = 6 end # The type of relationship. module Type # The type of the schema relationship is unspecified. TYPE_UNSPECIFIED = 0 # Indicates a join relationship between the schema fields. SCHEMA_JOIN = 1 end end # A sample SQL query in data documentation. # @!attribute [r] sql # @return [::String] # Output only. The SQL query string which can be executed. # @!attribute [r] description # @return [::String] # Output only. The description for the query. class Query include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Schema of the table with generated metadata of columns. # @!attribute [r] fields # @return [::Array<::Google::Cloud::Dataplex::V1::DataDocumentationResult::Field>] # Output only. The list of columns. class Schema include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Column of a table with generated metadata and nested fields. # @!attribute [r] name # @return [::String] # Output only. The name of the column. # @!attribute [r] description # @return [::String] # Output only. Generated description for columns and fields. # @!attribute [r] fields # @return [::Array<::Google::Cloud::Dataplex::V1::DataDocumentationResult::Field>] # Output only. Nested fields. class Field include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |