Class: Google::Cloud::Dataplex::V1::DataDocumentationSpec
- Inherits:
-
Object
- Object
- Google::Cloud::Dataplex::V1::DataDocumentationSpec
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataplex/v1/data_documentation.rb
Overview
DataDocumentation scan related spec.
Defined Under Namespace
Modules: GenerationScope
Instance Attribute Summary collapse
-
#catalog_publishing_enabled ⇒ ::Boolean
Optional.
-
#generation_scopes ⇒ ::Array<::Google::Cloud::Dataplex::V1::DataDocumentationSpec::GenerationScope>
Optional.
Instance Attribute Details
#catalog_publishing_enabled ⇒ ::Boolean
Returns Optional. Whether to publish result to Dataplex Catalog.
34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'proto_docs/google/cloud/dataplex/v1/data_documentation.rb', line 34 class DataDocumentationSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The data documentation generation scope. This field contains the possible # components of a data documentation scan which can be selectively generated. module GenerationScope # Unspecified generation scope. If no generation scope is specified, all # available documentation components will be generated. GENERATION_SCOPE_UNSPECIFIED = 0 # All the possible results will be generated. ALL = 1 # Table and column descriptions will be generated. TABLE_AND_COLUMN_DESCRIPTIONS = 2 # SQL queries will be generated. SQL_QUERIES = 3 end end |
#generation_scopes ⇒ ::Array<::Google::Cloud::Dataplex::V1::DataDocumentationSpec::GenerationScope>
Returns Optional. Specifies which components of the data documentation to generate. Any component that is required to generate the specified components will also be generated. If no generation scope is specified, all available documentation components will be generated.
34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'proto_docs/google/cloud/dataplex/v1/data_documentation.rb', line 34 class DataDocumentationSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The data documentation generation scope. This field contains the possible # components of a data documentation scan which can be selectively generated. module GenerationScope # Unspecified generation scope. If no generation scope is specified, all # available documentation components will be generated. GENERATION_SCOPE_UNSPECIFIED = 0 # All the possible results will be generated. ALL = 1 # Table and column descriptions will be generated. TABLE_AND_COLUMN_DESCRIPTIONS = 2 # SQL queries will be generated. SQL_QUERIES = 3 end end |