Module: Google::Cloud::Dataplex::V1::DataDocumentationSpec::GenerationScope
- Defined in:
- proto_docs/google/cloud/dataplex/v1/data_documentation.rb
Overview
The data documentation generation scope. This field contains the possible components of a data documentation scan which can be selectively generated.
Constant Summary collapse
- GENERATION_SCOPE_UNSPECIFIED =
Unspecified generation scope. If no generation scope is specified, all available documentation components will be generated.
0- ALL =
All the possible results will be generated.
1- TABLE_AND_COLUMN_DESCRIPTIONS =
Table and column descriptions will be generated.
2- SQL_QUERIES =
SQL queries will be generated.
3