Class: Google::Cloud::Dataplex::V1::DataProduct::AccessApprovalConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Dataplex::V1::DataProduct::AccessApprovalConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataplex/v1/data_products.rb
Overview
Configuration for access approval for the data product.
Instance Attribute Summary collapse
-
#approver_emails ⇒ ::Array<::String>
Optional.
Instance Attribute Details
#approver_emails ⇒ ::Array<::String>
Returns Optional. Specifies the email addresses of users who are potential approvers and are notified when an access request is made for the data product. The maximum number of emails allowed is 10.
148 149 150 151 |
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 148 class AccessApprovalConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |