Class: Google::Cloud::Dataplex::V1::DataProduct::Principal
- Inherits:
-
Object
- Object
- Google::Cloud::Dataplex::V1::DataProduct::Principal
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataplex/v1/data_products.rb
Overview
Represents the principal entity associated with an access group, as per https://cloud.google.com/iam/docs/principals-overview.
Instance Attribute Summary collapse
-
#google_group ⇒ ::String
Optional.
-
#service_account ⇒ ::String
Optional.
Instance Attribute Details
#google_group ⇒ ::String
Returns Optional. Email of the Google Group, as per https://cloud.google.com/iam/docs/principals-overview#google-group.
115 116 117 118 |
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 115 class Principal include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#service_account ⇒ ::String
Returns Optional. Specifies the email of the producer service account, as per https://cloud.google.com/iam/docs/principals-overview#service-account.
115 116 117 118 |
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 115 class Principal include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |