Class: Google::Cloud::Dataplex::V1::DataProductAccessRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Dataplex::V1::DataProductAccessRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataplex/v1/approval_workflow.rb
Overview
Message for requesting access to a Data Product. This will be used to create a ChangeRequest of type REQUEST_DATA_PRODUCT_ACCESS.
Instance Attribute Summary collapse
-
#access_group_display_name ⇒ ::String
readonly
Output only.
-
#access_group_id ⇒ ::String
Required.
-
#parent ⇒ ::String
Required.
-
#requested_principal ⇒ ::String
Optional.
Instance Attribute Details
#access_group_display_name ⇒ ::String (readonly)
Returns Output only. The display name of the access group defined in the Data Product for which access is being requested.
256 257 258 259 |
# File 'proto_docs/google/cloud/dataplex/v1/approval_workflow.rb', line 256 class DataProductAccessRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#access_group_id ⇒ ::String
Returns Required. The ID of the access group for which access is being requested. This corresponds to the unique identifier of the AccessGroup defined in the Data Product.
256 257 258 259 |
# File 'proto_docs/google/cloud/dataplex/v1/approval_workflow.rb', line 256 class DataProductAccessRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The resource name of the data product. Format: projects/{project_number}/locations/{location_id}/dataProducts/{data_product_id}.
256 257 258 259 |
# File 'proto_docs/google/cloud/dataplex/v1/approval_workflow.rb', line 256 class DataProductAccessRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#requested_principal ⇒ ::String
Returns Optional. The principal for which access is being requested in IAM format.
If not specified, the requestor's principal will be used.
Example: serviceAccount:my-sa@my-project.iam.gserviceaccount.com.
Only service account principals are currently supported.
https://cloud.google.com/iam/docs/principal-identifiers.
256 257 258 259 |
# File 'proto_docs/google/cloud/dataplex/v1/approval_workflow.rb', line 256 class DataProductAccessRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |