Class: Google::Cloud::Dataplex::V1::DataProfileSpec
- Inherits:
-
Object
- Object
- Google::Cloud::Dataplex::V1::DataProfileSpec
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataplex/v1/data_profile.rb
Overview
DataProfileScan related setting.
Defined Under Namespace
Modules: Mode Classes: PostScanActions, SelectedFields
Instance Attribute Summary collapse
-
#catalog_publishing_enabled ⇒ ::Boolean
Optional.
-
#exclude_fields ⇒ ::Google::Cloud::Dataplex::V1::DataProfileSpec::SelectedFields
Optional.
-
#include_fields ⇒ ::Google::Cloud::Dataplex::V1::DataProfileSpec::SelectedFields
Optional.
-
#mode ⇒ ::Google::Cloud::Dataplex::V1::DataProfileSpec::Mode
Optional.
-
#post_scan_actions ⇒ ::Google::Cloud::Dataplex::V1::DataProfileSpec::PostScanActions
Optional.
-
#row_filter ⇒ ::String
Optional.
-
#sampling_percent ⇒ ::Float
Optional.
Instance Attribute Details
#catalog_publishing_enabled ⇒ ::Boolean
Returns Optional. If set, the latest DataScan job result will be published as Dataplex Universal Catalog metadata.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'proto_docs/google/cloud/dataplex/v1/data_profile.rb', line 62 class DataProfileSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The configuration of post scan actions of DataProfileScan job. # @!attribute [rw] bigquery_export # @return [::Google::Cloud::Dataplex::V1::DataProfileSpec::PostScanActions::BigQueryExport] # Optional. If set, results will be exported to the provided BigQuery # table. class PostScanActions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The configuration of BigQuery export post scan action. # @!attribute [rw] results_table # @return [::String] # Optional. The BigQuery table to export DataProfileScan results to. # Format: # //bigquery.googleapis.com/projects/PROJECT_ID/datasets/DATASET_ID/tables/TABLE_ID class BigQueryExport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # The specification for fields to include or exclude in data profile scan. # @!attribute [rw] field_names # @return [::Array<::String>] # Optional. Expected input is a list of fully qualified names of fields as # in the schema. # # Only top-level field names for nested fields are supported. # For instance, if 'x' is of nested field type, listing 'x' is supported # but 'x.y.z' is not supported. Here 'y' and 'y.z' are nested fields of # 'x'. class SelectedFields include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Defines the execution mode for the profile scan. module Mode # Default value. This value is unused. MODE_UNSPECIFIED = 0 # Performs standard profiling. The behavior is controlled by other fields # such as `sampling_percent`, `row_filter`, and column filters. # This mode allows for full scans or custom sampling. STANDARD = 1 # Specifies lightweight profiling mode. This mode is optimized for # low-latency, low-fidelity profiling. # # When this mode is selected, the following fields must not be set: # `sampling_percent`, `row_filter`, `include_fields`, and `exclude_fields`. LIGHTWEIGHT = 2 end end |
#exclude_fields ⇒ ::Google::Cloud::Dataplex::V1::DataProfileSpec::SelectedFields
Returns Optional. The fields to exclude from data profile.
If specified, the fields will be excluded from data profile, regardless of
include_fields value.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'proto_docs/google/cloud/dataplex/v1/data_profile.rb', line 62 class DataProfileSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The configuration of post scan actions of DataProfileScan job. # @!attribute [rw] bigquery_export # @return [::Google::Cloud::Dataplex::V1::DataProfileSpec::PostScanActions::BigQueryExport] # Optional. If set, results will be exported to the provided BigQuery # table. class PostScanActions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The configuration of BigQuery export post scan action. # @!attribute [rw] results_table # @return [::String] # Optional. The BigQuery table to export DataProfileScan results to. # Format: # //bigquery.googleapis.com/projects/PROJECT_ID/datasets/DATASET_ID/tables/TABLE_ID class BigQueryExport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # The specification for fields to include or exclude in data profile scan. # @!attribute [rw] field_names # @return [::Array<::String>] # Optional. Expected input is a list of fully qualified names of fields as # in the schema. # # Only top-level field names for nested fields are supported. # For instance, if 'x' is of nested field type, listing 'x' is supported # but 'x.y.z' is not supported. Here 'y' and 'y.z' are nested fields of # 'x'. class SelectedFields include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Defines the execution mode for the profile scan. module Mode # Default value. This value is unused. MODE_UNSPECIFIED = 0 # Performs standard profiling. The behavior is controlled by other fields # such as `sampling_percent`, `row_filter`, and column filters. # This mode allows for full scans or custom sampling. STANDARD = 1 # Specifies lightweight profiling mode. This mode is optimized for # low-latency, low-fidelity profiling. # # When this mode is selected, the following fields must not be set: # `sampling_percent`, `row_filter`, `include_fields`, and `exclude_fields`. LIGHTWEIGHT = 2 end end |
#include_fields ⇒ ::Google::Cloud::Dataplex::V1::DataProfileSpec::SelectedFields
Returns Optional. The fields to include in data profile.
If not specified, all fields at the time of profile scan job execution are
included, except for ones listed in exclude_fields.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'proto_docs/google/cloud/dataplex/v1/data_profile.rb', line 62 class DataProfileSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The configuration of post scan actions of DataProfileScan job. # @!attribute [rw] bigquery_export # @return [::Google::Cloud::Dataplex::V1::DataProfileSpec::PostScanActions::BigQueryExport] # Optional. If set, results will be exported to the provided BigQuery # table. class PostScanActions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The configuration of BigQuery export post scan action. # @!attribute [rw] results_table # @return [::String] # Optional. The BigQuery table to export DataProfileScan results to. # Format: # //bigquery.googleapis.com/projects/PROJECT_ID/datasets/DATASET_ID/tables/TABLE_ID class BigQueryExport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # The specification for fields to include or exclude in data profile scan. # @!attribute [rw] field_names # @return [::Array<::String>] # Optional. Expected input is a list of fully qualified names of fields as # in the schema. # # Only top-level field names for nested fields are supported. # For instance, if 'x' is of nested field type, listing 'x' is supported # but 'x.y.z' is not supported. Here 'y' and 'y.z' are nested fields of # 'x'. class SelectedFields include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Defines the execution mode for the profile scan. module Mode # Default value. This value is unused. MODE_UNSPECIFIED = 0 # Performs standard profiling. The behavior is controlled by other fields # such as `sampling_percent`, `row_filter`, and column filters. # This mode allows for full scans or custom sampling. STANDARD = 1 # Specifies lightweight profiling mode. This mode is optimized for # low-latency, low-fidelity profiling. # # When this mode is selected, the following fields must not be set: # `sampling_percent`, `row_filter`, `include_fields`, and `exclude_fields`. LIGHTWEIGHT = 2 end end |
#mode ⇒ ::Google::Cloud::Dataplex::V1::DataProfileSpec::Mode
Returns Optional. The execution mode for the profile scan.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'proto_docs/google/cloud/dataplex/v1/data_profile.rb', line 62 class DataProfileSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The configuration of post scan actions of DataProfileScan job. # @!attribute [rw] bigquery_export # @return [::Google::Cloud::Dataplex::V1::DataProfileSpec::PostScanActions::BigQueryExport] # Optional. If set, results will be exported to the provided BigQuery # table. class PostScanActions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The configuration of BigQuery export post scan action. # @!attribute [rw] results_table # @return [::String] # Optional. The BigQuery table to export DataProfileScan results to. # Format: # //bigquery.googleapis.com/projects/PROJECT_ID/datasets/DATASET_ID/tables/TABLE_ID class BigQueryExport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # The specification for fields to include or exclude in data profile scan. # @!attribute [rw] field_names # @return [::Array<::String>] # Optional. Expected input is a list of fully qualified names of fields as # in the schema. # # Only top-level field names for nested fields are supported. # For instance, if 'x' is of nested field type, listing 'x' is supported # but 'x.y.z' is not supported. Here 'y' and 'y.z' are nested fields of # 'x'. class SelectedFields include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Defines the execution mode for the profile scan. module Mode # Default value. This value is unused. MODE_UNSPECIFIED = 0 # Performs standard profiling. The behavior is controlled by other fields # such as `sampling_percent`, `row_filter`, and column filters. # This mode allows for full scans or custom sampling. STANDARD = 1 # Specifies lightweight profiling mode. This mode is optimized for # low-latency, low-fidelity profiling. # # When this mode is selected, the following fields must not be set: # `sampling_percent`, `row_filter`, `include_fields`, and `exclude_fields`. LIGHTWEIGHT = 2 end end |
#post_scan_actions ⇒ ::Google::Cloud::Dataplex::V1::DataProfileSpec::PostScanActions
Returns Optional. Actions to take upon job completion..
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'proto_docs/google/cloud/dataplex/v1/data_profile.rb', line 62 class DataProfileSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The configuration of post scan actions of DataProfileScan job. # @!attribute [rw] bigquery_export # @return [::Google::Cloud::Dataplex::V1::DataProfileSpec::PostScanActions::BigQueryExport] # Optional. If set, results will be exported to the provided BigQuery # table. class PostScanActions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The configuration of BigQuery export post scan action. # @!attribute [rw] results_table # @return [::String] # Optional. The BigQuery table to export DataProfileScan results to. # Format: # //bigquery.googleapis.com/projects/PROJECT_ID/datasets/DATASET_ID/tables/TABLE_ID class BigQueryExport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # The specification for fields to include or exclude in data profile scan. # @!attribute [rw] field_names # @return [::Array<::String>] # Optional. Expected input is a list of fully qualified names of fields as # in the schema. # # Only top-level field names for nested fields are supported. # For instance, if 'x' is of nested field type, listing 'x' is supported # but 'x.y.z' is not supported. Here 'y' and 'y.z' are nested fields of # 'x'. class SelectedFields include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Defines the execution mode for the profile scan. module Mode # Default value. This value is unused. MODE_UNSPECIFIED = 0 # Performs standard profiling. The behavior is controlled by other fields # such as `sampling_percent`, `row_filter`, and column filters. # This mode allows for full scans or custom sampling. STANDARD = 1 # Specifies lightweight profiling mode. This mode is optimized for # low-latency, low-fidelity profiling. # # When this mode is selected, the following fields must not be set: # `sampling_percent`, `row_filter`, `include_fields`, and `exclude_fields`. LIGHTWEIGHT = 2 end end |
#row_filter ⇒ ::String
Returns Optional. A filter applied to all rows in a single DataScan job. The filter needs to be a valid SQL expression for a WHERE clause in BigQuery standard SQL syntax. Example: col1 >= 0 AND col2 < 10.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'proto_docs/google/cloud/dataplex/v1/data_profile.rb', line 62 class DataProfileSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The configuration of post scan actions of DataProfileScan job. # @!attribute [rw] bigquery_export # @return [::Google::Cloud::Dataplex::V1::DataProfileSpec::PostScanActions::BigQueryExport] # Optional. If set, results will be exported to the provided BigQuery # table. class PostScanActions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The configuration of BigQuery export post scan action. # @!attribute [rw] results_table # @return [::String] # Optional. The BigQuery table to export DataProfileScan results to. # Format: # //bigquery.googleapis.com/projects/PROJECT_ID/datasets/DATASET_ID/tables/TABLE_ID class BigQueryExport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # The specification for fields to include or exclude in data profile scan. # @!attribute [rw] field_names # @return [::Array<::String>] # Optional. Expected input is a list of fully qualified names of fields as # in the schema. # # Only top-level field names for nested fields are supported. # For instance, if 'x' is of nested field type, listing 'x' is supported # but 'x.y.z' is not supported. Here 'y' and 'y.z' are nested fields of # 'x'. class SelectedFields include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Defines the execution mode for the profile scan. module Mode # Default value. This value is unused. MODE_UNSPECIFIED = 0 # Performs standard profiling. The behavior is controlled by other fields # such as `sampling_percent`, `row_filter`, and column filters. # This mode allows for full scans or custom sampling. STANDARD = 1 # Specifies lightweight profiling mode. This mode is optimized for # low-latency, low-fidelity profiling. # # When this mode is selected, the following fields must not be set: # `sampling_percent`, `row_filter`, `include_fields`, and `exclude_fields`. LIGHTWEIGHT = 2 end end |
#sampling_percent ⇒ ::Float
Returns Optional. The percentage of the records to be selected from the dataset for DataScan.
- Value can range between 0.0 and 100.0 with up to 3 significant decimal digits.
- Sampling is not applied if
sampling_percentis not specified, 0 or 100.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'proto_docs/google/cloud/dataplex/v1/data_profile.rb', line 62 class DataProfileSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The configuration of post scan actions of DataProfileScan job. # @!attribute [rw] bigquery_export # @return [::Google::Cloud::Dataplex::V1::DataProfileSpec::PostScanActions::BigQueryExport] # Optional. If set, results will be exported to the provided BigQuery # table. class PostScanActions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The configuration of BigQuery export post scan action. # @!attribute [rw] results_table # @return [::String] # Optional. The BigQuery table to export DataProfileScan results to. # Format: # //bigquery.googleapis.com/projects/PROJECT_ID/datasets/DATASET_ID/tables/TABLE_ID class BigQueryExport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # The specification for fields to include or exclude in data profile scan. # @!attribute [rw] field_names # @return [::Array<::String>] # Optional. Expected input is a list of fully qualified names of fields as # in the schema. # # Only top-level field names for nested fields are supported. # For instance, if 'x' is of nested field type, listing 'x' is supported # but 'x.y.z' is not supported. Here 'y' and 'y.z' are nested fields of # 'x'. class SelectedFields include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Defines the execution mode for the profile scan. module Mode # Default value. This value is unused. MODE_UNSPECIFIED = 0 # Performs standard profiling. The behavior is controlled by other fields # such as `sampling_percent`, `row_filter`, and column filters. # This mode allows for full scans or custom sampling. STANDARD = 1 # Specifies lightweight profiling mode. This mode is optimized for # low-latency, low-fidelity profiling. # # When this mode is selected, the following fields must not be set: # `sampling_percent`, `row_filter`, `include_fields`, and `exclude_fields`. LIGHTWEIGHT = 2 end end |