Class: Google::Cloud::Dataplex::V1::DataProfileSpec
- Inherits:
-
Object
- Object
- Google::Cloud::Dataplex::V1::DataProfileSpec
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataplex/v1/data_profile.rb
Overview
DataProfileScan related setting.
Defined Under Namespace
Classes: PostScanActions, SelectedFields
Instance Attribute Summary collapse
-
#catalog_publishing_enabled ⇒ ::Boolean
Optional.
-
#exclude_fields ⇒ ::Google::Cloud::Dataplex::V1::DataProfileSpec::SelectedFields
Optional.
-
#include_fields ⇒ ::Google::Cloud::Dataplex::V1::DataProfileSpec::SelectedFields
Optional.
-
#post_scan_actions ⇒ ::Google::Cloud::Dataplex::V1::DataProfileSpec::PostScanActions
Optional.
-
#row_filter ⇒ ::String
Optional.
-
#sampling_percent ⇒ ::Float
Optional.
Instance Attribute Details
#catalog_publishing_enabled ⇒ ::Boolean
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'proto_docs/google/cloud/dataplex/v1/data_profile.rb', line 59 class DataProfileSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The configuration of post scan actions of DataProfileScan job. # @!attribute [rw] bigquery_export # @return [::Google::Cloud::Dataplex::V1::DataProfileSpec::PostScanActions::BigQueryExport] # Optional. If set, results will be exported to the provided BigQuery # table. class PostScanActions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The configuration of BigQuery export post scan action. # @!attribute [rw] results_table # @return [::String] # Optional. The BigQuery table to export DataProfileScan results to. # Format: # //bigquery.googleapis.com/projects/PROJECT_ID/datasets/DATASET_ID/tables/TABLE_ID class BigQueryExport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # The specification for fields to include or exclude in data profile scan. # @!attribute [rw] field_names # @return [::Array<::String>] # Optional. Expected input is a list of fully qualified names of fields as # in the schema. # # Only top-level field names for nested fields are supported. # For instance, if 'x' is of nested field type, listing 'x' is supported # but 'x.y.z' is not supported. Here 'y' and 'y.z' are nested fields of # 'x'. class SelectedFields include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#exclude_fields ⇒ ::Google::Cloud::Dataplex::V1::DataProfileSpec::SelectedFields
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'proto_docs/google/cloud/dataplex/v1/data_profile.rb', line 59 class DataProfileSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The configuration of post scan actions of DataProfileScan job. # @!attribute [rw] bigquery_export # @return [::Google::Cloud::Dataplex::V1::DataProfileSpec::PostScanActions::BigQueryExport] # Optional. If set, results will be exported to the provided BigQuery # table. class PostScanActions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The configuration of BigQuery export post scan action. # @!attribute [rw] results_table # @return [::String] # Optional. The BigQuery table to export DataProfileScan results to. # Format: # //bigquery.googleapis.com/projects/PROJECT_ID/datasets/DATASET_ID/tables/TABLE_ID class BigQueryExport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # The specification for fields to include or exclude in data profile scan. # @!attribute [rw] field_names # @return [::Array<::String>] # Optional. Expected input is a list of fully qualified names of fields as # in the schema. # # Only top-level field names for nested fields are supported. # For instance, if 'x' is of nested field type, listing 'x' is supported # but 'x.y.z' is not supported. Here 'y' and 'y.z' are nested fields of # 'x'. class SelectedFields include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#include_fields ⇒ ::Google::Cloud::Dataplex::V1::DataProfileSpec::SelectedFields
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'proto_docs/google/cloud/dataplex/v1/data_profile.rb', line 59 class DataProfileSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The configuration of post scan actions of DataProfileScan job. # @!attribute [rw] bigquery_export # @return [::Google::Cloud::Dataplex::V1::DataProfileSpec::PostScanActions::BigQueryExport] # Optional. If set, results will be exported to the provided BigQuery # table. class PostScanActions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The configuration of BigQuery export post scan action. # @!attribute [rw] results_table # @return [::String] # Optional. The BigQuery table to export DataProfileScan results to. # Format: # //bigquery.googleapis.com/projects/PROJECT_ID/datasets/DATASET_ID/tables/TABLE_ID class BigQueryExport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # The specification for fields to include or exclude in data profile scan. # @!attribute [rw] field_names # @return [::Array<::String>] # Optional. Expected input is a list of fully qualified names of fields as # in the schema. # # Only top-level field names for nested fields are supported. # For instance, if 'x' is of nested field type, listing 'x' is supported # but 'x.y.z' is not supported. Here 'y' and 'y.z' are nested fields of # 'x'. class SelectedFields include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#post_scan_actions ⇒ ::Google::Cloud::Dataplex::V1::DataProfileSpec::PostScanActions
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'proto_docs/google/cloud/dataplex/v1/data_profile.rb', line 59 class DataProfileSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The configuration of post scan actions of DataProfileScan job. # @!attribute [rw] bigquery_export # @return [::Google::Cloud::Dataplex::V1::DataProfileSpec::PostScanActions::BigQueryExport] # Optional. If set, results will be exported to the provided BigQuery # table. class PostScanActions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The configuration of BigQuery export post scan action. # @!attribute [rw] results_table # @return [::String] # Optional. The BigQuery table to export DataProfileScan results to. # Format: # //bigquery.googleapis.com/projects/PROJECT_ID/datasets/DATASET_ID/tables/TABLE_ID class BigQueryExport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # The specification for fields to include or exclude in data profile scan. # @!attribute [rw] field_names # @return [::Array<::String>] # Optional. Expected input is a list of fully qualified names of fields as # in the schema. # # Only top-level field names for nested fields are supported. # For instance, if 'x' is of nested field type, listing 'x' is supported # but 'x.y.z' is not supported. Here 'y' and 'y.z' are nested fields of # 'x'. class SelectedFields include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#row_filter ⇒ ::String
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'proto_docs/google/cloud/dataplex/v1/data_profile.rb', line 59 class DataProfileSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The configuration of post scan actions of DataProfileScan job. # @!attribute [rw] bigquery_export # @return [::Google::Cloud::Dataplex::V1::DataProfileSpec::PostScanActions::BigQueryExport] # Optional. If set, results will be exported to the provided BigQuery # table. class PostScanActions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The configuration of BigQuery export post scan action. # @!attribute [rw] results_table # @return [::String] # Optional. The BigQuery table to export DataProfileScan results to. # Format: # //bigquery.googleapis.com/projects/PROJECT_ID/datasets/DATASET_ID/tables/TABLE_ID class BigQueryExport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # The specification for fields to include or exclude in data profile scan. # @!attribute [rw] field_names # @return [::Array<::String>] # Optional. Expected input is a list of fully qualified names of fields as # in the schema. # # Only top-level field names for nested fields are supported. # For instance, if 'x' is of nested field type, listing 'x' is supported # but 'x.y.z' is not supported. Here 'y' and 'y.z' are nested fields of # 'x'. class SelectedFields include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#sampling_percent ⇒ ::Float
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'proto_docs/google/cloud/dataplex/v1/data_profile.rb', line 59 class DataProfileSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The configuration of post scan actions of DataProfileScan job. # @!attribute [rw] bigquery_export # @return [::Google::Cloud::Dataplex::V1::DataProfileSpec::PostScanActions::BigQueryExport] # Optional. If set, results will be exported to the provided BigQuery # table. class PostScanActions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The configuration of BigQuery export post scan action. # @!attribute [rw] results_table # @return [::String] # Optional. The BigQuery table to export DataProfileScan results to. # Format: # //bigquery.googleapis.com/projects/PROJECT_ID/datasets/DATASET_ID/tables/TABLE_ID class BigQueryExport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # The specification for fields to include or exclude in data profile scan. # @!attribute [rw] field_names # @return [::Array<::String>] # Optional. Expected input is a list of fully qualified names of fields as # in the schema. # # Only top-level field names for nested fields are supported. # For instance, if 'x' is of nested field type, listing 'x' is supported # but 'x.y.z' is not supported. Here 'y' and 'y.z' are nested fields of # 'x'. class SelectedFields include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |