Module: Google::Cloud::Dataplex::V1::DataProfileSpec::Mode
- Defined in:
- proto_docs/google/cloud/dataplex/v1/data_profile.rb
Overview
Defines the execution mode for the profile scan.
Constant Summary collapse
- MODE_UNSPECIFIED =
Default value. This value is unused.
0- STANDARD =
Performs standard profiling. The behavior is controlled by other fields such as
sampling_percent,row_filter, and column filters. This mode allows for full scans or custom sampling. 1- LIGHTWEIGHT =
Specifies lightweight profiling mode. This mode is optimized for low-latency, low-fidelity profiling.
When this mode is selected, the following fields must not be set:
sampling_percent,row_filter,include_fields, andexclude_fields. 2