Class: Google::Cloud::Dataplex::V1::DataQualityRule::RuleSource::RulePathElement
- Inherits:
-
Object
- Object
- Google::Cloud::Dataplex::V1::DataQualityRule::RuleSource::RulePathElement
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataplex/v1/data_quality.rb
Overview
Path Element represents the direct relationship between the rule origin (aspects) to the BigQuery Entry. Ordering of the rule relationship will be maintained such that the first entry in the list is the closest ancestor (BigQuery table itself). A blank source denotes that the rule is derived directly from the DataScan itself.
Defined Under Namespace
Classes: EntryLinkSource, EntrySource
Instance Attribute Summary collapse
-
#entry_link_source ⇒ ::Google::Cloud::Dataplex::V1::DataQualityRule::RuleSource::RulePathElement::EntryLinkSource
readonly
Output only.
-
#entry_source ⇒ ::Google::Cloud::Dataplex::V1::DataQualityRule::RuleSource::RulePathElement::EntrySource
readonly
Output only.
Instance Attribute Details
#entry_link_source ⇒ ::Google::Cloud::Dataplex::V1::DataQualityRule::RuleSource::RulePathElement::EntryLinkSource (readonly)
Returns Output only. Entry link source represents information about the entry link.
Note: The following fields are mutually exclusive: entry_link_source, entry_source. If a field in that set is populated, all other fields in the set will automatically be cleared.
742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 |
# File 'proto_docs/google/cloud/dataplex/v1/data_quality.rb', line 742 class RulePathElement include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Entry source represents information about the related source entry. # @!attribute [r] entry_type # @return [::String] # Output only. The entry type to represent the current characteristics # of the entry in the form of: # `projects/{project_id_or_number}/locations/{location_id}/entryTypes/{entry-type-id}`. # @!attribute [r] entry # @return [::String] # Output only. The entry name in the form of: # `projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}/entries/{entry_id}` # @!attribute [r] display_name # @return [::String] # Output only. The display name of the entry. class EntrySource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Entry link source represents information about the entry link. # @!attribute [r] entry_link_type # @return [::String] # Output only. The entry link type to represent the current # relationship between the entry and the next entry in the path. # In the form of: # `projects/{project_id_or_number}/locations/{location_id}/entryLinkTypes/{entry_link_type_id}` # @!attribute [r] entry_link # @return [::String] # Output only. The entry link name in the form of: # `projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}/entryLinks/{entry_link_id}` class EntryLinkSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#entry_source ⇒ ::Google::Cloud::Dataplex::V1::DataQualityRule::RuleSource::RulePathElement::EntrySource (readonly)
Returns Output only. Entry source represents information about the related source entry.
Note: The following fields are mutually exclusive: entry_source, entry_link_source. If a field in that set is populated, all other fields in the set will automatically be cleared.
742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 |
# File 'proto_docs/google/cloud/dataplex/v1/data_quality.rb', line 742 class RulePathElement include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Entry source represents information about the related source entry. # @!attribute [r] entry_type # @return [::String] # Output only. The entry type to represent the current characteristics # of the entry in the form of: # `projects/{project_id_or_number}/locations/{location_id}/entryTypes/{entry-type-id}`. # @!attribute [r] entry # @return [::String] # Output only. The entry name in the form of: # `projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}/entries/{entry_id}` # @!attribute [r] display_name # @return [::String] # Output only. The display name of the entry. class EntrySource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Entry link source represents information about the entry link. # @!attribute [r] entry_link_type # @return [::String] # Output only. The entry link type to represent the current # relationship between the entry and the next entry in the path. # In the form of: # `projects/{project_id_or_number}/locations/{location_id}/entryLinkTypes/{entry_link_type_id}` # @!attribute [r] entry_link # @return [::String] # Output only. The entry link name in the form of: # `projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}/entryLinks/{entry_link_id}` class EntryLinkSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |