Class: Google::Cloud::Dataplex::V1::DataQualityRule::RuleSource::RulePathElement::EntryLinkSource
- Inherits:
-
Object
- Object
- Google::Cloud::Dataplex::V1::DataQualityRule::RuleSource::RulePathElement::EntryLinkSource
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataplex/v1/data_quality.rb
Overview
Entry link source represents information about the entry link.
Instance Attribute Summary collapse
-
#entry_link ⇒ ::String
readonly
Output only.
-
#entry_link_type ⇒ ::String
readonly
Output only.
Instance Attribute Details
#entry_link ⇒ ::String (readonly)
Returns Output only. The entry link name in the form of:
projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}/entryLinks/{entry_link_id}.
775 776 777 778 |
# File 'proto_docs/google/cloud/dataplex/v1/data_quality.rb', line 775 class EntryLinkSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#entry_link_type ⇒ ::String (readonly)
Returns Output only. The entry link type to represent the current
relationship between the entry and the next entry in the path.
In the form of:
projects/{project_id_or_number}/locations/{location_id}/entryLinkTypes/{entry_link_type_id}.
775 776 777 778 |
# File 'proto_docs/google/cloud/dataplex/v1/data_quality.rb', line 775 class EntryLinkSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |