Class: Google::Cloud::Dataplex::V1::DataQualityRule::StatisticRangeExpectation
- Inherits:
-
Object
- Object
- Google::Cloud::Dataplex::V1::DataQualityRule::StatisticRangeExpectation
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataplex/v1/data_quality.rb
Overview
Evaluates whether the column aggregate statistic lies between a specified range.
Defined Under Namespace
Modules: ColumnStatistic
Instance Attribute Summary collapse
-
#max_value ⇒ ::String
Optional.
-
#min_value ⇒ ::String
Optional.
-
#statistic ⇒ ::Google::Cloud::Dataplex::V1::DataQualityRule::StatisticRangeExpectation::ColumnStatistic
Optional.
-
#strict_max_enabled ⇒ ::Boolean
Optional.
-
#strict_min_enabled ⇒ ::Boolean
Optional.
Instance Attribute Details
#max_value ⇒ ::String
522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 |
# File 'proto_docs/google/cloud/dataplex/v1/data_quality.rb', line 522 class StatisticRangeExpectation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The list of aggregate metrics a rule can be evaluated against. module ColumnStatistic # Unspecified statistic type STATISTIC_UNDEFINED = 0 # Evaluate the column mean MEAN = 1 # Evaluate the column min MIN = 2 # Evaluate the column max MAX = 3 end end |
#min_value ⇒ ::String
522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 |
# File 'proto_docs/google/cloud/dataplex/v1/data_quality.rb', line 522 class StatisticRangeExpectation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The list of aggregate metrics a rule can be evaluated against. module ColumnStatistic # Unspecified statistic type STATISTIC_UNDEFINED = 0 # Evaluate the column mean MEAN = 1 # Evaluate the column min MIN = 2 # Evaluate the column max MAX = 3 end end |
#statistic ⇒ ::Google::Cloud::Dataplex::V1::DataQualityRule::StatisticRangeExpectation::ColumnStatistic
522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 |
# File 'proto_docs/google/cloud/dataplex/v1/data_quality.rb', line 522 class StatisticRangeExpectation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The list of aggregate metrics a rule can be evaluated against. module ColumnStatistic # Unspecified statistic type STATISTIC_UNDEFINED = 0 # Evaluate the column mean MEAN = 1 # Evaluate the column min MIN = 2 # Evaluate the column max MAX = 3 end end |
#strict_max_enabled ⇒ ::Boolean
522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 |
# File 'proto_docs/google/cloud/dataplex/v1/data_quality.rb', line 522 class StatisticRangeExpectation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The list of aggregate metrics a rule can be evaluated against. module ColumnStatistic # Unspecified statistic type STATISTIC_UNDEFINED = 0 # Evaluate the column mean MEAN = 1 # Evaluate the column min MIN = 2 # Evaluate the column max MAX = 3 end end |
#strict_min_enabled ⇒ ::Boolean
522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 |
# File 'proto_docs/google/cloud/dataplex/v1/data_quality.rb', line 522 class StatisticRangeExpectation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The list of aggregate metrics a rule can be evaluated against. module ColumnStatistic # Unspecified statistic type STATISTIC_UNDEFINED = 0 # Evaluate the column mean MEAN = 1 # Evaluate the column min MIN = 2 # Evaluate the column max MAX = 3 end end |