Class: Google::Cloud::Dataplex::V1::DataQualityRule::TemplateReference
- Inherits:
-
Object
- Object
- Google::Cloud::Dataplex::V1::DataQualityRule::TemplateReference
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataplex/v1/data_quality.rb
Overview
A rule that constructs a SQL statement to evaluate using a rule template and parameter values. If the constructed statement returns any rows, this rule fails
Defined Under Namespace
Classes: ParameterValue, ValuesEntry
Instance Attribute Summary collapse
-
#name ⇒ ::String
Required.
-
#resolved_sql ⇒ ::String
readonly
Output only.
-
#rule_template ⇒ ::Google::Cloud::Dataplex::V1::DataQualityRuleTemplate
readonly
Output only.
-
#values ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Dataplex::V1::DataQualityRule::TemplateReference::ParameterValue}
Optional.
Instance Attribute Details
#name ⇒ ::String
Returns Required. The template entry name. Entry must be of EntryType
projects/dataplex-types/locations/global/entryTypes/data-quality-rule-template
and contains top-level aspect of AspectType
projects/dataplex-types/locations/global/aspectTypes/data-quality-rule-template.
The format is:
projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}/entries/{entry_id}.
692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 |
# File 'proto_docs/google/cloud/dataplex/v1/data_quality.rb', line 692 class TemplateReference include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a parameter value. # @!attribute [rw] value # @return [::String] # Required. Represents the string value of the parameter. class ParameterValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Dataplex::V1::DataQualityRule::TemplateReference::ParameterValue] class ValuesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#resolved_sql ⇒ ::String (readonly)
Returns Output only. The resolved SQL statement generated from the template with parameters substituted. It is only populated in the result.
692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 |
# File 'proto_docs/google/cloud/dataplex/v1/data_quality.rb', line 692 class TemplateReference include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a parameter value. # @!attribute [rw] value # @return [::String] # Required. Represents the string value of the parameter. class ParameterValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Dataplex::V1::DataQualityRule::TemplateReference::ParameterValue] class ValuesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#rule_template ⇒ ::Google::Cloud::Dataplex::V1::DataQualityRuleTemplate (readonly)
Returns Output only. The rule template used to resolve the rule. It is only populated in the result.
692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 |
# File 'proto_docs/google/cloud/dataplex/v1/data_quality.rb', line 692 class TemplateReference include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a parameter value. # @!attribute [rw] value # @return [::String] # Required. Represents the string value of the parameter. class ParameterValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Dataplex::V1::DataQualityRule::TemplateReference::ParameterValue] class ValuesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#values ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Dataplex::V1::DataQualityRule::TemplateReference::ParameterValue}
Returns Optional. Provides the map of parameter name and value. The maximum size of the field is 120KB (encoded as UTF-8).
692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 |
# File 'proto_docs/google/cloud/dataplex/v1/data_quality.rb', line 692 class TemplateReference include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a parameter value. # @!attribute [rw] value # @return [::String] # Required. Represents the string value of the parameter. class ParameterValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Dataplex::V1::DataQualityRule::TemplateReference::ParameterValue] class ValuesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |