Class: Google::Cloud::Dataplex::V1::DataQualityRuleResult
- Inherits:
-
Object
- Object
- Google::Cloud::Dataplex::V1::DataQualityRuleResult
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataplex/v1/data_quality.rb
Overview
DataQualityRuleResult provides a more detailed, per-rule view of the results.
Defined Under Namespace
Classes: DebugQueryResult, DebugQueryResultSet
Instance Attribute Summary collapse
-
#assertion_row_count ⇒ ::Integer
readonly
Output only.
-
#debug_queries_result_sets ⇒ ::Array<::Google::Cloud::Dataplex::V1::DataQualityRuleResult::DebugQueryResultSet>
readonly
Output only.
-
#evaluated_count ⇒ ::Integer
readonly
Output only.
-
#failing_rows_query ⇒ ::String
readonly
Output only.
-
#null_count ⇒ ::Integer
readonly
Output only.
-
#pass_ratio ⇒ ::Float
readonly
Output only.
-
#passed ⇒ ::Boolean
readonly
Output only.
-
#passed_count ⇒ ::Integer
readonly
Output only.
-
#rule ⇒ ::Google::Cloud::Dataplex::V1::DataQualityRule
readonly
Output only.
Instance Attribute Details
#assertion_row_count ⇒ ::Integer (readonly)
Returns Output only. The number of rows returned by the SQL statement in a SQL assertion rule.
This field is only valid for SQL assertion rules.
323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 |
# File 'proto_docs/google/cloud/dataplex/v1/data_quality.rb', line 323 class DataQualityRuleResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains a single result from the debug query. # @!attribute [rw] name # @return [::String] # Specifies the name of the result. Available if provided with an explicit # alias using `[AS] alias`. # @!attribute [rw] type # @return [::String] # Indicates the data type of the result. For more information, see # [BigQuery data # types](https://cloud.google.com/bigquery/docs/reference/standard-sql/data-types). # @!attribute [rw] value # @return [::String] # Represents the value of the result as a string. class DebugQueryResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Contains all results from a debug query. # @!attribute [r] results # @return [::Array<::Google::Cloud::Dataplex::V1::DataQualityRuleResult::DebugQueryResult>] # Output only. Contains all results. Up to 10 results can be returned. class DebugQueryResultSet include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#debug_queries_result_sets ⇒ ::Array<::Google::Cloud::Dataplex::V1::DataQualityRuleResult::DebugQueryResultSet> (readonly)
Returns Output only. Contains the results of all debug queries for this rule. The number of result sets will correspond to the number of debug_queries.
323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 |
# File 'proto_docs/google/cloud/dataplex/v1/data_quality.rb', line 323 class DataQualityRuleResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains a single result from the debug query. # @!attribute [rw] name # @return [::String] # Specifies the name of the result. Available if provided with an explicit # alias using `[AS] alias`. # @!attribute [rw] type # @return [::String] # Indicates the data type of the result. For more information, see # [BigQuery data # types](https://cloud.google.com/bigquery/docs/reference/standard-sql/data-types). # @!attribute [rw] value # @return [::String] # Represents the value of the result as a string. class DebugQueryResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Contains all results from a debug query. # @!attribute [r] results # @return [::Array<::Google::Cloud::Dataplex::V1::DataQualityRuleResult::DebugQueryResult>] # Output only. Contains all results. Up to 10 results can be returned. class DebugQueryResultSet include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#evaluated_count ⇒ ::Integer (readonly)
Returns Output only. The number of rows a rule was evaluated against.
This field is only valid for row-level type rules.
Evaluated count can be configured to either
- include all rows (default) - with
nullrows automatically failing rule evaluation, or - exclude
nullrows from theevaluated_count, by settingignore_nulls = true.
This field is not set for rule SqlAssertion.
323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 |
# File 'proto_docs/google/cloud/dataplex/v1/data_quality.rb', line 323 class DataQualityRuleResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains a single result from the debug query. # @!attribute [rw] name # @return [::String] # Specifies the name of the result. Available if provided with an explicit # alias using `[AS] alias`. # @!attribute [rw] type # @return [::String] # Indicates the data type of the result. For more information, see # [BigQuery data # types](https://cloud.google.com/bigquery/docs/reference/standard-sql/data-types). # @!attribute [rw] value # @return [::String] # Represents the value of the result as a string. class DebugQueryResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Contains all results from a debug query. # @!attribute [r] results # @return [::Array<::Google::Cloud::Dataplex::V1::DataQualityRuleResult::DebugQueryResult>] # Output only. Contains all results. Up to 10 results can be returned. class DebugQueryResultSet include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#failing_rows_query ⇒ ::String (readonly)
Returns Output only. The query to find rows that did not pass this rule.
This field is only valid for row-level type rules.
323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 |
# File 'proto_docs/google/cloud/dataplex/v1/data_quality.rb', line 323 class DataQualityRuleResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains a single result from the debug query. # @!attribute [rw] name # @return [::String] # Specifies the name of the result. Available if provided with an explicit # alias using `[AS] alias`. # @!attribute [rw] type # @return [::String] # Indicates the data type of the result. For more information, see # [BigQuery data # types](https://cloud.google.com/bigquery/docs/reference/standard-sql/data-types). # @!attribute [rw] value # @return [::String] # Represents the value of the result as a string. class DebugQueryResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Contains all results from a debug query. # @!attribute [r] results # @return [::Array<::Google::Cloud::Dataplex::V1::DataQualityRuleResult::DebugQueryResult>] # Output only. Contains all results. Up to 10 results can be returned. class DebugQueryResultSet include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#null_count ⇒ ::Integer (readonly)
Returns Output only. The number of rows with null values in the specified column.
323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 |
# File 'proto_docs/google/cloud/dataplex/v1/data_quality.rb', line 323 class DataQualityRuleResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains a single result from the debug query. # @!attribute [rw] name # @return [::String] # Specifies the name of the result. Available if provided with an explicit # alias using `[AS] alias`. # @!attribute [rw] type # @return [::String] # Indicates the data type of the result. For more information, see # [BigQuery data # types](https://cloud.google.com/bigquery/docs/reference/standard-sql/data-types). # @!attribute [rw] value # @return [::String] # Represents the value of the result as a string. class DebugQueryResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Contains all results from a debug query. # @!attribute [r] results # @return [::Array<::Google::Cloud::Dataplex::V1::DataQualityRuleResult::DebugQueryResult>] # Output only. Contains all results. Up to 10 results can be returned. class DebugQueryResultSet include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#pass_ratio ⇒ ::Float (readonly)
Returns Output only. The ratio of passed_count / evaluated_count.
This field is only valid for row-level type rules.
323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 |
# File 'proto_docs/google/cloud/dataplex/v1/data_quality.rb', line 323 class DataQualityRuleResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains a single result from the debug query. # @!attribute [rw] name # @return [::String] # Specifies the name of the result. Available if provided with an explicit # alias using `[AS] alias`. # @!attribute [rw] type # @return [::String] # Indicates the data type of the result. For more information, see # [BigQuery data # types](https://cloud.google.com/bigquery/docs/reference/standard-sql/data-types). # @!attribute [rw] value # @return [::String] # Represents the value of the result as a string. class DebugQueryResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Contains all results from a debug query. # @!attribute [r] results # @return [::Array<::Google::Cloud::Dataplex::V1::DataQualityRuleResult::DebugQueryResult>] # Output only. Contains all results. Up to 10 results can be returned. class DebugQueryResultSet include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#passed ⇒ ::Boolean (readonly)
Returns Output only. Whether the rule passed or failed.
323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 |
# File 'proto_docs/google/cloud/dataplex/v1/data_quality.rb', line 323 class DataQualityRuleResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains a single result from the debug query. # @!attribute [rw] name # @return [::String] # Specifies the name of the result. Available if provided with an explicit # alias using `[AS] alias`. # @!attribute [rw] type # @return [::String] # Indicates the data type of the result. For more information, see # [BigQuery data # types](https://cloud.google.com/bigquery/docs/reference/standard-sql/data-types). # @!attribute [rw] value # @return [::String] # Represents the value of the result as a string. class DebugQueryResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Contains all results from a debug query. # @!attribute [r] results # @return [::Array<::Google::Cloud::Dataplex::V1::DataQualityRuleResult::DebugQueryResult>] # Output only. Contains all results. Up to 10 results can be returned. class DebugQueryResultSet include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#passed_count ⇒ ::Integer (readonly)
Returns Output only. The number of rows which passed a rule evaluation.
This field is only valid for row-level type rules.
This field is not set for rule SqlAssertion.
323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 |
# File 'proto_docs/google/cloud/dataplex/v1/data_quality.rb', line 323 class DataQualityRuleResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains a single result from the debug query. # @!attribute [rw] name # @return [::String] # Specifies the name of the result. Available if provided with an explicit # alias using `[AS] alias`. # @!attribute [rw] type # @return [::String] # Indicates the data type of the result. For more information, see # [BigQuery data # types](https://cloud.google.com/bigquery/docs/reference/standard-sql/data-types). # @!attribute [rw] value # @return [::String] # Represents the value of the result as a string. class DebugQueryResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Contains all results from a debug query. # @!attribute [r] results # @return [::Array<::Google::Cloud::Dataplex::V1::DataQualityRuleResult::DebugQueryResult>] # Output only. Contains all results. Up to 10 results can be returned. class DebugQueryResultSet include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#rule ⇒ ::Google::Cloud::Dataplex::V1::DataQualityRule (readonly)
Returns Output only. The rule specified in the DataQualitySpec, as is.
323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 |
# File 'proto_docs/google/cloud/dataplex/v1/data_quality.rb', line 323 class DataQualityRuleResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains a single result from the debug query. # @!attribute [rw] name # @return [::String] # Specifies the name of the result. Available if provided with an explicit # alias using `[AS] alias`. # @!attribute [rw] type # @return [::String] # Indicates the data type of the result. For more information, see # [BigQuery data # types](https://cloud.google.com/bigquery/docs/reference/standard-sql/data-types). # @!attribute [rw] value # @return [::String] # Represents the value of the result as a string. class DebugQueryResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Contains all results from a debug query. # @!attribute [r] results # @return [::Array<::Google::Cloud::Dataplex::V1::DataQualityRuleResult::DebugQueryResult>] # Output only. Contains all results. Up to 10 results can be returned. class DebugQueryResultSet include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |