Class: Google::Cloud::Dataplex::V1::DataQualitySpec
- Inherits:
-
Object
- Object
- Google::Cloud::Dataplex::V1::DataQualitySpec
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataplex/v1/data_quality.rb
Overview
DataQualityScan related setting.
Defined Under Namespace
Classes: PostScanActions
Instance Attribute Summary collapse
-
#catalog_publishing_enabled ⇒ ::Boolean
Optional.
-
#enable_catalog_based_rules ⇒ ::Boolean
Optional.
-
#filter ⇒ ::String
Optional.
-
#post_scan_actions ⇒ ::Google::Cloud::Dataplex::V1::DataQualitySpec::PostScanActions
Optional.
-
#row_filter ⇒ ::String
Optional.
-
#rules ⇒ ::Array<::Google::Cloud::Dataplex::V1::DataQualityRule>
Required.
-
#sampling_percent ⇒ ::Float
Optional.
Instance Attribute Details
#catalog_publishing_enabled ⇒ ::Boolean
Returns Optional. If set, the latest DataScan job result will be published as Dataplex Universal Catalog metadata.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'proto_docs/google/cloud/dataplex/v1/data_quality.rb', line 75 class DataQualitySpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The configuration of post scan actions of DataQualityScan. # @!attribute [rw] bigquery_export # @return [::Google::Cloud::Dataplex::V1::DataQualitySpec::PostScanActions::BigQueryExport] # Optional. If set, results will be exported to the provided BigQuery # table. # @!attribute [rw] notification_report # @return [::Google::Cloud::Dataplex::V1::DataQualitySpec::PostScanActions::NotificationReport] # Optional. If set, results will be sent to the provided notification # receipts upon triggers. class PostScanActions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The configuration of BigQuery export post scan action. # @!attribute [rw] results_table # @return [::String] # Optional. The BigQuery table to export DataQualityScan results to. # Format: # //bigquery.googleapis.com/projects/PROJECT_ID/datasets/DATASET_ID/tables/TABLE_ID # or # projects/PROJECT_ID/datasets/DATASET_ID/tables/TABLE_ID class BigQueryExport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The individuals or groups who are designated to receive notifications # upon triggers. # @!attribute [rw] emails # @return [::Array<::String>] # Optional. The email recipients who will receive the DataQualityScan # results report. class Recipients include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # This trigger is triggered when the DQ score in the job result is less # than a specified input score. # @!attribute [rw] score_threshold # @return [::Float] # Optional. The score range is in [0,100]. class ScoreThresholdTrigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # This trigger is triggered when the scan job itself fails, regardless of # the result. class JobFailureTrigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # This trigger is triggered whenever a scan job run ends, regardless # of the result. class JobEndTrigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The configuration of notification report post scan action. # @!attribute [rw] recipients # @return [::Google::Cloud::Dataplex::V1::DataQualitySpec::PostScanActions::Recipients] # Required. The recipients who will receive the notification report. # @!attribute [rw] score_threshold_trigger # @return [::Google::Cloud::Dataplex::V1::DataQualitySpec::PostScanActions::ScoreThresholdTrigger] # Optional. If set, report will be sent when score threshold is met. # @!attribute [rw] job_failure_trigger # @return [::Google::Cloud::Dataplex::V1::DataQualitySpec::PostScanActions::JobFailureTrigger] # Optional. If set, report will be sent when a scan job fails. # @!attribute [rw] job_end_trigger # @return [::Google::Cloud::Dataplex::V1::DataQualitySpec::PostScanActions::JobEndTrigger] # Optional. If set, report will be sent when a scan job ends. class NotificationReport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#enable_catalog_based_rules ⇒ ::Boolean
Returns Optional. If enabled, the data scan will retrieve rules defined in the dataplex-types.global.data-rules aspect on all paths of the catalog entry corresponding to the BigQuery table resource and all attached glossary terms. The path that data-rules aspect is attached on the table entry defines the column that the rule will be evaluated against. For glossary terms, the path that the terms are attached on the table entry defines the column that the rule will be evaluated against. At the start of scan execution, the rules reflect the latest state retrieved from the catalog entry and any updates on the rules thereafter are ignored for that execution. The updates will be reflected from the next execution. Rules defined in the datascan must be empty if this field is enabled.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'proto_docs/google/cloud/dataplex/v1/data_quality.rb', line 75 class DataQualitySpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The configuration of post scan actions of DataQualityScan. # @!attribute [rw] bigquery_export # @return [::Google::Cloud::Dataplex::V1::DataQualitySpec::PostScanActions::BigQueryExport] # Optional. If set, results will be exported to the provided BigQuery # table. # @!attribute [rw] notification_report # @return [::Google::Cloud::Dataplex::V1::DataQualitySpec::PostScanActions::NotificationReport] # Optional. If set, results will be sent to the provided notification # receipts upon triggers. class PostScanActions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The configuration of BigQuery export post scan action. # @!attribute [rw] results_table # @return [::String] # Optional. The BigQuery table to export DataQualityScan results to. # Format: # //bigquery.googleapis.com/projects/PROJECT_ID/datasets/DATASET_ID/tables/TABLE_ID # or # projects/PROJECT_ID/datasets/DATASET_ID/tables/TABLE_ID class BigQueryExport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The individuals or groups who are designated to receive notifications # upon triggers. # @!attribute [rw] emails # @return [::Array<::String>] # Optional. The email recipients who will receive the DataQualityScan # results report. class Recipients include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # This trigger is triggered when the DQ score in the job result is less # than a specified input score. # @!attribute [rw] score_threshold # @return [::Float] # Optional. The score range is in [0,100]. class ScoreThresholdTrigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # This trigger is triggered when the scan job itself fails, regardless of # the result. class JobFailureTrigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # This trigger is triggered whenever a scan job run ends, regardless # of the result. class JobEndTrigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The configuration of notification report post scan action. # @!attribute [rw] recipients # @return [::Google::Cloud::Dataplex::V1::DataQualitySpec::PostScanActions::Recipients] # Required. The recipients who will receive the notification report. # @!attribute [rw] score_threshold_trigger # @return [::Google::Cloud::Dataplex::V1::DataQualitySpec::PostScanActions::ScoreThresholdTrigger] # Optional. If set, report will be sent when score threshold is met. # @!attribute [rw] job_failure_trigger # @return [::Google::Cloud::Dataplex::V1::DataQualitySpec::PostScanActions::JobFailureTrigger] # Optional. If set, report will be sent when a scan job fails. # @!attribute [rw] job_end_trigger # @return [::Google::Cloud::Dataplex::V1::DataQualitySpec::PostScanActions::JobEndTrigger] # Optional. If set, report will be sent when a scan job ends. class NotificationReport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#filter ⇒ ::String
Returns Optional. Filter for selectively running a subset of rules. You can filter the request by the name or attribute key-value pairs defined on the rule. If not specified, all rules are run. The filter is applicable to both, the rules retrieved from catalog and explicitly defined rules in the scan. Please see filter syntax for more details.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'proto_docs/google/cloud/dataplex/v1/data_quality.rb', line 75 class DataQualitySpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The configuration of post scan actions of DataQualityScan. # @!attribute [rw] bigquery_export # @return [::Google::Cloud::Dataplex::V1::DataQualitySpec::PostScanActions::BigQueryExport] # Optional. If set, results will be exported to the provided BigQuery # table. # @!attribute [rw] notification_report # @return [::Google::Cloud::Dataplex::V1::DataQualitySpec::PostScanActions::NotificationReport] # Optional. If set, results will be sent to the provided notification # receipts upon triggers. class PostScanActions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The configuration of BigQuery export post scan action. # @!attribute [rw] results_table # @return [::String] # Optional. The BigQuery table to export DataQualityScan results to. # Format: # //bigquery.googleapis.com/projects/PROJECT_ID/datasets/DATASET_ID/tables/TABLE_ID # or # projects/PROJECT_ID/datasets/DATASET_ID/tables/TABLE_ID class BigQueryExport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The individuals or groups who are designated to receive notifications # upon triggers. # @!attribute [rw] emails # @return [::Array<::String>] # Optional. The email recipients who will receive the DataQualityScan # results report. class Recipients include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # This trigger is triggered when the DQ score in the job result is less # than a specified input score. # @!attribute [rw] score_threshold # @return [::Float] # Optional. The score range is in [0,100]. class ScoreThresholdTrigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # This trigger is triggered when the scan job itself fails, regardless of # the result. class JobFailureTrigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # This trigger is triggered whenever a scan job run ends, regardless # of the result. class JobEndTrigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The configuration of notification report post scan action. # @!attribute [rw] recipients # @return [::Google::Cloud::Dataplex::V1::DataQualitySpec::PostScanActions::Recipients] # Required. The recipients who will receive the notification report. # @!attribute [rw] score_threshold_trigger # @return [::Google::Cloud::Dataplex::V1::DataQualitySpec::PostScanActions::ScoreThresholdTrigger] # Optional. If set, report will be sent when score threshold is met. # @!attribute [rw] job_failure_trigger # @return [::Google::Cloud::Dataplex::V1::DataQualitySpec::PostScanActions::JobFailureTrigger] # Optional. If set, report will be sent when a scan job fails. # @!attribute [rw] job_end_trigger # @return [::Google::Cloud::Dataplex::V1::DataQualitySpec::PostScanActions::JobEndTrigger] # Optional. If set, report will be sent when a scan job ends. class NotificationReport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#post_scan_actions ⇒ ::Google::Cloud::Dataplex::V1::DataQualitySpec::PostScanActions
Returns Optional. Actions to take upon job completion.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'proto_docs/google/cloud/dataplex/v1/data_quality.rb', line 75 class DataQualitySpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The configuration of post scan actions of DataQualityScan. # @!attribute [rw] bigquery_export # @return [::Google::Cloud::Dataplex::V1::DataQualitySpec::PostScanActions::BigQueryExport] # Optional. If set, results will be exported to the provided BigQuery # table. # @!attribute [rw] notification_report # @return [::Google::Cloud::Dataplex::V1::DataQualitySpec::PostScanActions::NotificationReport] # Optional. If set, results will be sent to the provided notification # receipts upon triggers. class PostScanActions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The configuration of BigQuery export post scan action. # @!attribute [rw] results_table # @return [::String] # Optional. The BigQuery table to export DataQualityScan results to. # Format: # //bigquery.googleapis.com/projects/PROJECT_ID/datasets/DATASET_ID/tables/TABLE_ID # or # projects/PROJECT_ID/datasets/DATASET_ID/tables/TABLE_ID class BigQueryExport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The individuals or groups who are designated to receive notifications # upon triggers. # @!attribute [rw] emails # @return [::Array<::String>] # Optional. The email recipients who will receive the DataQualityScan # results report. class Recipients include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # This trigger is triggered when the DQ score in the job result is less # than a specified input score. # @!attribute [rw] score_threshold # @return [::Float] # Optional. The score range is in [0,100]. class ScoreThresholdTrigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # This trigger is triggered when the scan job itself fails, regardless of # the result. class JobFailureTrigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # This trigger is triggered whenever a scan job run ends, regardless # of the result. class JobEndTrigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The configuration of notification report post scan action. # @!attribute [rw] recipients # @return [::Google::Cloud::Dataplex::V1::DataQualitySpec::PostScanActions::Recipients] # Required. The recipients who will receive the notification report. # @!attribute [rw] score_threshold_trigger # @return [::Google::Cloud::Dataplex::V1::DataQualitySpec::PostScanActions::ScoreThresholdTrigger] # Optional. If set, report will be sent when score threshold is met. # @!attribute [rw] job_failure_trigger # @return [::Google::Cloud::Dataplex::V1::DataQualitySpec::PostScanActions::JobFailureTrigger] # Optional. If set, report will be sent when a scan job fails. # @!attribute [rw] job_end_trigger # @return [::Google::Cloud::Dataplex::V1::DataQualitySpec::PostScanActions::JobEndTrigger] # Optional. If set, report will be sent when a scan job ends. class NotificationReport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#row_filter ⇒ ::String
Returns Optional. A filter applied to all rows in a single DataScan job. The filter needs to be a valid SQL expression for a WHERE clause in GoogleSQL syntax.
Example: col1 >= 0 AND col2 < 10.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'proto_docs/google/cloud/dataplex/v1/data_quality.rb', line 75 class DataQualitySpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The configuration of post scan actions of DataQualityScan. # @!attribute [rw] bigquery_export # @return [::Google::Cloud::Dataplex::V1::DataQualitySpec::PostScanActions::BigQueryExport] # Optional. If set, results will be exported to the provided BigQuery # table. # @!attribute [rw] notification_report # @return [::Google::Cloud::Dataplex::V1::DataQualitySpec::PostScanActions::NotificationReport] # Optional. If set, results will be sent to the provided notification # receipts upon triggers. class PostScanActions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The configuration of BigQuery export post scan action. # @!attribute [rw] results_table # @return [::String] # Optional. The BigQuery table to export DataQualityScan results to. # Format: # //bigquery.googleapis.com/projects/PROJECT_ID/datasets/DATASET_ID/tables/TABLE_ID # or # projects/PROJECT_ID/datasets/DATASET_ID/tables/TABLE_ID class BigQueryExport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The individuals or groups who are designated to receive notifications # upon triggers. # @!attribute [rw] emails # @return [::Array<::String>] # Optional. The email recipients who will receive the DataQualityScan # results report. class Recipients include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # This trigger is triggered when the DQ score in the job result is less # than a specified input score. # @!attribute [rw] score_threshold # @return [::Float] # Optional. The score range is in [0,100]. class ScoreThresholdTrigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # This trigger is triggered when the scan job itself fails, regardless of # the result. class JobFailureTrigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # This trigger is triggered whenever a scan job run ends, regardless # of the result. class JobEndTrigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The configuration of notification report post scan action. # @!attribute [rw] recipients # @return [::Google::Cloud::Dataplex::V1::DataQualitySpec::PostScanActions::Recipients] # Required. The recipients who will receive the notification report. # @!attribute [rw] score_threshold_trigger # @return [::Google::Cloud::Dataplex::V1::DataQualitySpec::PostScanActions::ScoreThresholdTrigger] # Optional. If set, report will be sent when score threshold is met. # @!attribute [rw] job_failure_trigger # @return [::Google::Cloud::Dataplex::V1::DataQualitySpec::PostScanActions::JobFailureTrigger] # Optional. If set, report will be sent when a scan job fails. # @!attribute [rw] job_end_trigger # @return [::Google::Cloud::Dataplex::V1::DataQualitySpec::PostScanActions::JobEndTrigger] # Optional. If set, report will be sent when a scan job ends. class NotificationReport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#rules ⇒ ::Array<::Google::Cloud::Dataplex::V1::DataQualityRule>
Returns Required. The list of rules to evaluate against a data source. At least one rule is required.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'proto_docs/google/cloud/dataplex/v1/data_quality.rb', line 75 class DataQualitySpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The configuration of post scan actions of DataQualityScan. # @!attribute [rw] bigquery_export # @return [::Google::Cloud::Dataplex::V1::DataQualitySpec::PostScanActions::BigQueryExport] # Optional. If set, results will be exported to the provided BigQuery # table. # @!attribute [rw] notification_report # @return [::Google::Cloud::Dataplex::V1::DataQualitySpec::PostScanActions::NotificationReport] # Optional. If set, results will be sent to the provided notification # receipts upon triggers. class PostScanActions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The configuration of BigQuery export post scan action. # @!attribute [rw] results_table # @return [::String] # Optional. The BigQuery table to export DataQualityScan results to. # Format: # //bigquery.googleapis.com/projects/PROJECT_ID/datasets/DATASET_ID/tables/TABLE_ID # or # projects/PROJECT_ID/datasets/DATASET_ID/tables/TABLE_ID class BigQueryExport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The individuals or groups who are designated to receive notifications # upon triggers. # @!attribute [rw] emails # @return [::Array<::String>] # Optional. The email recipients who will receive the DataQualityScan # results report. class Recipients include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # This trigger is triggered when the DQ score in the job result is less # than a specified input score. # @!attribute [rw] score_threshold # @return [::Float] # Optional. The score range is in [0,100]. class ScoreThresholdTrigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # This trigger is triggered when the scan job itself fails, regardless of # the result. class JobFailureTrigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # This trigger is triggered whenever a scan job run ends, regardless # of the result. class JobEndTrigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The configuration of notification report post scan action. # @!attribute [rw] recipients # @return [::Google::Cloud::Dataplex::V1::DataQualitySpec::PostScanActions::Recipients] # Required. The recipients who will receive the notification report. # @!attribute [rw] score_threshold_trigger # @return [::Google::Cloud::Dataplex::V1::DataQualitySpec::PostScanActions::ScoreThresholdTrigger] # Optional. If set, report will be sent when score threshold is met. # @!attribute [rw] job_failure_trigger # @return [::Google::Cloud::Dataplex::V1::DataQualitySpec::PostScanActions::JobFailureTrigger] # Optional. If set, report will be sent when a scan job fails. # @!attribute [rw] job_end_trigger # @return [::Google::Cloud::Dataplex::V1::DataQualitySpec::PostScanActions::JobEndTrigger] # Optional. If set, report will be sent when a scan job ends. class NotificationReport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#sampling_percent ⇒ ::Float
Returns Optional. The percentage of the records to be selected from the dataset for DataScan.
- Value can range between 0.0 and 100.0 with up to 3 significant decimal digits.
- Sampling is not applied if
sampling_percentis not specified, 0 or 100.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'proto_docs/google/cloud/dataplex/v1/data_quality.rb', line 75 class DataQualitySpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The configuration of post scan actions of DataQualityScan. # @!attribute [rw] bigquery_export # @return [::Google::Cloud::Dataplex::V1::DataQualitySpec::PostScanActions::BigQueryExport] # Optional. If set, results will be exported to the provided BigQuery # table. # @!attribute [rw] notification_report # @return [::Google::Cloud::Dataplex::V1::DataQualitySpec::PostScanActions::NotificationReport] # Optional. If set, results will be sent to the provided notification # receipts upon triggers. class PostScanActions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The configuration of BigQuery export post scan action. # @!attribute [rw] results_table # @return [::String] # Optional. The BigQuery table to export DataQualityScan results to. # Format: # //bigquery.googleapis.com/projects/PROJECT_ID/datasets/DATASET_ID/tables/TABLE_ID # or # projects/PROJECT_ID/datasets/DATASET_ID/tables/TABLE_ID class BigQueryExport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The individuals or groups who are designated to receive notifications # upon triggers. # @!attribute [rw] emails # @return [::Array<::String>] # Optional. The email recipients who will receive the DataQualityScan # results report. class Recipients include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # This trigger is triggered when the DQ score in the job result is less # than a specified input score. # @!attribute [rw] score_threshold # @return [::Float] # Optional. The score range is in [0,100]. class ScoreThresholdTrigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # This trigger is triggered when the scan job itself fails, regardless of # the result. class JobFailureTrigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # This trigger is triggered whenever a scan job run ends, regardless # of the result. class JobEndTrigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The configuration of notification report post scan action. # @!attribute [rw] recipients # @return [::Google::Cloud::Dataplex::V1::DataQualitySpec::PostScanActions::Recipients] # Required. The recipients who will receive the notification report. # @!attribute [rw] score_threshold_trigger # @return [::Google::Cloud::Dataplex::V1::DataQualitySpec::PostScanActions::ScoreThresholdTrigger] # Optional. If set, report will be sent when score threshold is met. # @!attribute [rw] job_failure_trigger # @return [::Google::Cloud::Dataplex::V1::DataQualitySpec::PostScanActions::JobFailureTrigger] # Optional. If set, report will be sent when a scan job fails. # @!attribute [rw] job_end_trigger # @return [::Google::Cloud::Dataplex::V1::DataQualitySpec::PostScanActions::JobEndTrigger] # Optional. If set, report will be sent when a scan job ends. class NotificationReport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |