Class: Google::Cloud::Dataplex::V1::DataScanCatalogPublishingStatus
- Inherits:
-
Object
- Object
- Google::Cloud::Dataplex::V1::DataScanCatalogPublishingStatus
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataplex/v1/datascans_common.rb
Overview
The status of publishing the data scan result as Dataplex Universal Catalog metadata. Multiple DataScan log events may exist, each with different publishing information depending on the type of publishing triggered.
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#state ⇒ ::Google::Cloud::Dataplex::V1::DataScanCatalogPublishingStatus::State
readonly
Output only.
Instance Attribute Details
#state ⇒ ::Google::Cloud::Dataplex::V1::DataScanCatalogPublishingStatus::State (readonly)
Returns Output only. Execution state for publishing.
30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 |
# File 'proto_docs/google/cloud/dataplex/v1/datascans_common.rb', line 30 class DataScanCatalogPublishingStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Execution state for the publishing. module State # The publishing state is unspecified. STATE_UNSPECIFIED = 0 # Publishing to catalog completed successfully. SUCCEEDED = 1 # Publish to catalog failed. FAILED = 2 # Publishing to catalog was skipped. SKIPPED = 3 end end |