Class: Google::Cloud::Dataplex::V1::DataScanJob
- Inherits:
-
Object
- Object
- Google::Cloud::Dataplex::V1::DataScanJob
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataplex/v1/datascans.rb
Overview
A DataScanJob represents an instance of DataScan execution.
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#data_discovery_result ⇒ ::Google::Cloud::Dataplex::V1::DataDiscoveryResult
readonly
Output only.
-
#data_discovery_spec ⇒ ::Google::Cloud::Dataplex::V1::DataDiscoverySpec
readonly
Output only.
-
#data_documentation_result ⇒ ::Google::Cloud::Dataplex::V1::DataDocumentationResult
readonly
Output only.
-
#data_documentation_spec ⇒ ::Google::Cloud::Dataplex::V1::DataDocumentationSpec
readonly
Output only.
-
#data_profile_result ⇒ ::Google::Cloud::Dataplex::V1::DataProfileResult
readonly
Output only.
-
#data_profile_spec ⇒ ::Google::Cloud::Dataplex::V1::DataProfileSpec
readonly
Output only.
-
#data_quality_result ⇒ ::Google::Cloud::Dataplex::V1::DataQualityResult
readonly
Output only.
-
#data_quality_spec ⇒ ::Google::Cloud::Dataplex::V1::DataQualitySpec
readonly
Output only.
-
#end_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#message ⇒ ::String
readonly
Output only.
-
#name ⇒ ::String
readonly
Output only.
-
#partial_failure_message ⇒ ::String
readonly
Output only.
-
#start_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#state ⇒ ::Google::Cloud::Dataplex::V1::DataScanJob::State
readonly
Output only.
-
#type ⇒ ::Google::Cloud::Dataplex::V1::DataScanType
readonly
Output only.
-
#uid ⇒ ::String
readonly
Output only.
Instance Attribute Details
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time when the DataScanJob was created.
586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 |
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 586 class DataScanJob include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Execution state for the DataScanJob. module State # The DataScanJob state is unspecified. STATE_UNSPECIFIED = 0 # The DataScanJob is running. RUNNING = 1 # The DataScanJob is canceling. CANCELING = 2 # The DataScanJob cancellation was successful. CANCELLED = 3 # The DataScanJob completed successfully. SUCCEEDED = 4 # The DataScanJob is no longer running due to an error. FAILED = 5 # The DataScanJob has been created but not started to run yet. PENDING = 7 # The DataScanJob succeeded with errors. SUCCEEDED_WITH_ERRORS = 8 end end |
#data_discovery_result ⇒ ::Google::Cloud::Dataplex::V1::DataDiscoveryResult (readonly)
Returns Output only. The result of a data discovery scan.
Note: The following fields are mutually exclusive: data_discovery_result, data_quality_result, data_profile_result, data_documentation_result. If a field in that set is populated, all other fields in the set will automatically be cleared.
586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 |
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 586 class DataScanJob include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Execution state for the DataScanJob. module State # The DataScanJob state is unspecified. STATE_UNSPECIFIED = 0 # The DataScanJob is running. RUNNING = 1 # The DataScanJob is canceling. CANCELING = 2 # The DataScanJob cancellation was successful. CANCELLED = 3 # The DataScanJob completed successfully. SUCCEEDED = 4 # The DataScanJob is no longer running due to an error. FAILED = 5 # The DataScanJob has been created but not started to run yet. PENDING = 7 # The DataScanJob succeeded with errors. SUCCEEDED_WITH_ERRORS = 8 end end |
#data_discovery_spec ⇒ ::Google::Cloud::Dataplex::V1::DataDiscoverySpec (readonly)
Returns Output only. Settings for a data discovery scan.
Note: The following fields are mutually exclusive: data_discovery_spec, data_quality_spec, data_profile_spec, data_documentation_spec. If a field in that set is populated, all other fields in the set will automatically be cleared.
586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 |
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 586 class DataScanJob include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Execution state for the DataScanJob. module State # The DataScanJob state is unspecified. STATE_UNSPECIFIED = 0 # The DataScanJob is running. RUNNING = 1 # The DataScanJob is canceling. CANCELING = 2 # The DataScanJob cancellation was successful. CANCELLED = 3 # The DataScanJob completed successfully. SUCCEEDED = 4 # The DataScanJob is no longer running due to an error. FAILED = 5 # The DataScanJob has been created but not started to run yet. PENDING = 7 # The DataScanJob succeeded with errors. SUCCEEDED_WITH_ERRORS = 8 end end |
#data_documentation_result ⇒ ::Google::Cloud::Dataplex::V1::DataDocumentationResult (readonly)
Returns Output only. The result of a data documentation scan.
Note: The following fields are mutually exclusive: data_documentation_result, data_quality_result, data_profile_result, data_discovery_result. If a field in that set is populated, all other fields in the set will automatically be cleared.
586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 |
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 586 class DataScanJob include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Execution state for the DataScanJob. module State # The DataScanJob state is unspecified. STATE_UNSPECIFIED = 0 # The DataScanJob is running. RUNNING = 1 # The DataScanJob is canceling. CANCELING = 2 # The DataScanJob cancellation was successful. CANCELLED = 3 # The DataScanJob completed successfully. SUCCEEDED = 4 # The DataScanJob is no longer running due to an error. FAILED = 5 # The DataScanJob has been created but not started to run yet. PENDING = 7 # The DataScanJob succeeded with errors. SUCCEEDED_WITH_ERRORS = 8 end end |
#data_documentation_spec ⇒ ::Google::Cloud::Dataplex::V1::DataDocumentationSpec (readonly)
Returns Output only. Settings for a data documentation scan.
Note: The following fields are mutually exclusive: data_documentation_spec, data_quality_spec, data_profile_spec, data_discovery_spec. If a field in that set is populated, all other fields in the set will automatically be cleared.
586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 |
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 586 class DataScanJob include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Execution state for the DataScanJob. module State # The DataScanJob state is unspecified. STATE_UNSPECIFIED = 0 # The DataScanJob is running. RUNNING = 1 # The DataScanJob is canceling. CANCELING = 2 # The DataScanJob cancellation was successful. CANCELLED = 3 # The DataScanJob completed successfully. SUCCEEDED = 4 # The DataScanJob is no longer running due to an error. FAILED = 5 # The DataScanJob has been created but not started to run yet. PENDING = 7 # The DataScanJob succeeded with errors. SUCCEEDED_WITH_ERRORS = 8 end end |
#data_profile_result ⇒ ::Google::Cloud::Dataplex::V1::DataProfileResult (readonly)
Returns Output only. The result of a data profile scan.
Note: The following fields are mutually exclusive: data_profile_result, data_quality_result, data_discovery_result, data_documentation_result. If a field in that set is populated, all other fields in the set will automatically be cleared.
586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 |
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 586 class DataScanJob include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Execution state for the DataScanJob. module State # The DataScanJob state is unspecified. STATE_UNSPECIFIED = 0 # The DataScanJob is running. RUNNING = 1 # The DataScanJob is canceling. CANCELING = 2 # The DataScanJob cancellation was successful. CANCELLED = 3 # The DataScanJob completed successfully. SUCCEEDED = 4 # The DataScanJob is no longer running due to an error. FAILED = 5 # The DataScanJob has been created but not started to run yet. PENDING = 7 # The DataScanJob succeeded with errors. SUCCEEDED_WITH_ERRORS = 8 end end |
#data_profile_spec ⇒ ::Google::Cloud::Dataplex::V1::DataProfileSpec (readonly)
Returns Output only. Settings for a data profile scan.
Note: The following fields are mutually exclusive: data_profile_spec, data_quality_spec, data_discovery_spec, data_documentation_spec. If a field in that set is populated, all other fields in the set will automatically be cleared.
586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 |
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 586 class DataScanJob include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Execution state for the DataScanJob. module State # The DataScanJob state is unspecified. STATE_UNSPECIFIED = 0 # The DataScanJob is running. RUNNING = 1 # The DataScanJob is canceling. CANCELING = 2 # The DataScanJob cancellation was successful. CANCELLED = 3 # The DataScanJob completed successfully. SUCCEEDED = 4 # The DataScanJob is no longer running due to an error. FAILED = 5 # The DataScanJob has been created but not started to run yet. PENDING = 7 # The DataScanJob succeeded with errors. SUCCEEDED_WITH_ERRORS = 8 end end |
#data_quality_result ⇒ ::Google::Cloud::Dataplex::V1::DataQualityResult (readonly)
Returns Output only. The result of a data quality scan.
Note: The following fields are mutually exclusive: data_quality_result, data_profile_result, data_discovery_result, data_documentation_result. If a field in that set is populated, all other fields in the set will automatically be cleared.
586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 |
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 586 class DataScanJob include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Execution state for the DataScanJob. module State # The DataScanJob state is unspecified. STATE_UNSPECIFIED = 0 # The DataScanJob is running. RUNNING = 1 # The DataScanJob is canceling. CANCELING = 2 # The DataScanJob cancellation was successful. CANCELLED = 3 # The DataScanJob completed successfully. SUCCEEDED = 4 # The DataScanJob is no longer running due to an error. FAILED = 5 # The DataScanJob has been created but not started to run yet. PENDING = 7 # The DataScanJob succeeded with errors. SUCCEEDED_WITH_ERRORS = 8 end end |
#data_quality_spec ⇒ ::Google::Cloud::Dataplex::V1::DataQualitySpec (readonly)
Returns Output only. Settings for a data quality scan.
Note: The following fields are mutually exclusive: data_quality_spec, data_profile_spec, data_discovery_spec, data_documentation_spec. If a field in that set is populated, all other fields in the set will automatically be cleared.
586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 |
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 586 class DataScanJob include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Execution state for the DataScanJob. module State # The DataScanJob state is unspecified. STATE_UNSPECIFIED = 0 # The DataScanJob is running. RUNNING = 1 # The DataScanJob is canceling. CANCELING = 2 # The DataScanJob cancellation was successful. CANCELLED = 3 # The DataScanJob completed successfully. SUCCEEDED = 4 # The DataScanJob is no longer running due to an error. FAILED = 5 # The DataScanJob has been created but not started to run yet. PENDING = 7 # The DataScanJob succeeded with errors. SUCCEEDED_WITH_ERRORS = 8 end end |
#end_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time when the DataScanJob ended.
586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 |
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 586 class DataScanJob include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Execution state for the DataScanJob. module State # The DataScanJob state is unspecified. STATE_UNSPECIFIED = 0 # The DataScanJob is running. RUNNING = 1 # The DataScanJob is canceling. CANCELING = 2 # The DataScanJob cancellation was successful. CANCELLED = 3 # The DataScanJob completed successfully. SUCCEEDED = 4 # The DataScanJob is no longer running due to an error. FAILED = 5 # The DataScanJob has been created but not started to run yet. PENDING = 7 # The DataScanJob succeeded with errors. SUCCEEDED_WITH_ERRORS = 8 end end |
#message ⇒ ::String (readonly)
Returns Output only. Additional information about the current state.
586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 |
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 586 class DataScanJob include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Execution state for the DataScanJob. module State # The DataScanJob state is unspecified. STATE_UNSPECIFIED = 0 # The DataScanJob is running. RUNNING = 1 # The DataScanJob is canceling. CANCELING = 2 # The DataScanJob cancellation was successful. CANCELLED = 3 # The DataScanJob completed successfully. SUCCEEDED = 4 # The DataScanJob is no longer running due to an error. FAILED = 5 # The DataScanJob has been created but not started to run yet. PENDING = 7 # The DataScanJob succeeded with errors. SUCCEEDED_WITH_ERRORS = 8 end end |
#name ⇒ ::String (readonly)
Returns Output only. Identifier. The relative resource name of the DataScanJob, of
the form:
projects/{project}/locations/{location_id}/dataScans/{datascan_id}/jobs/{job_id},
where project refers to a project_id or project_number and
location_id refers to a Google Cloud region.
586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 |
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 586 class DataScanJob include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Execution state for the DataScanJob. module State # The DataScanJob state is unspecified. STATE_UNSPECIFIED = 0 # The DataScanJob is running. RUNNING = 1 # The DataScanJob is canceling. CANCELING = 2 # The DataScanJob cancellation was successful. CANCELLED = 3 # The DataScanJob completed successfully. SUCCEEDED = 4 # The DataScanJob is no longer running due to an error. FAILED = 5 # The DataScanJob has been created but not started to run yet. PENDING = 7 # The DataScanJob succeeded with errors. SUCCEEDED_WITH_ERRORS = 8 end end |
#partial_failure_message ⇒ ::String (readonly)
Returns Output only. A message indicating partial failure details.
586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 |
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 586 class DataScanJob include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Execution state for the DataScanJob. module State # The DataScanJob state is unspecified. STATE_UNSPECIFIED = 0 # The DataScanJob is running. RUNNING = 1 # The DataScanJob is canceling. CANCELING = 2 # The DataScanJob cancellation was successful. CANCELLED = 3 # The DataScanJob completed successfully. SUCCEEDED = 4 # The DataScanJob is no longer running due to an error. FAILED = 5 # The DataScanJob has been created but not started to run yet. PENDING = 7 # The DataScanJob succeeded with errors. SUCCEEDED_WITH_ERRORS = 8 end end |
#start_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time when the DataScanJob was started.
586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 |
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 586 class DataScanJob include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Execution state for the DataScanJob. module State # The DataScanJob state is unspecified. STATE_UNSPECIFIED = 0 # The DataScanJob is running. RUNNING = 1 # The DataScanJob is canceling. CANCELING = 2 # The DataScanJob cancellation was successful. CANCELLED = 3 # The DataScanJob completed successfully. SUCCEEDED = 4 # The DataScanJob is no longer running due to an error. FAILED = 5 # The DataScanJob has been created but not started to run yet. PENDING = 7 # The DataScanJob succeeded with errors. SUCCEEDED_WITH_ERRORS = 8 end end |
#state ⇒ ::Google::Cloud::Dataplex::V1::DataScanJob::State (readonly)
Returns Output only. Execution state for the DataScanJob.
586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 |
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 586 class DataScanJob include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Execution state for the DataScanJob. module State # The DataScanJob state is unspecified. STATE_UNSPECIFIED = 0 # The DataScanJob is running. RUNNING = 1 # The DataScanJob is canceling. CANCELING = 2 # The DataScanJob cancellation was successful. CANCELLED = 3 # The DataScanJob completed successfully. SUCCEEDED = 4 # The DataScanJob is no longer running due to an error. FAILED = 5 # The DataScanJob has been created but not started to run yet. PENDING = 7 # The DataScanJob succeeded with errors. SUCCEEDED_WITH_ERRORS = 8 end end |
#type ⇒ ::Google::Cloud::Dataplex::V1::DataScanType (readonly)
Returns Output only. The type of the parent DataScan.
586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 |
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 586 class DataScanJob include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Execution state for the DataScanJob. module State # The DataScanJob state is unspecified. STATE_UNSPECIFIED = 0 # The DataScanJob is running. RUNNING = 1 # The DataScanJob is canceling. CANCELING = 2 # The DataScanJob cancellation was successful. CANCELLED = 3 # The DataScanJob completed successfully. SUCCEEDED = 4 # The DataScanJob is no longer running due to an error. FAILED = 5 # The DataScanJob has been created but not started to run yet. PENDING = 7 # The DataScanJob succeeded with errors. SUCCEEDED_WITH_ERRORS = 8 end end |
#uid ⇒ ::String (readonly)
Returns Output only. System generated globally unique ID for the DataScanJob.
586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 |
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 586 class DataScanJob include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Execution state for the DataScanJob. module State # The DataScanJob state is unspecified. STATE_UNSPECIFIED = 0 # The DataScanJob is running. RUNNING = 1 # The DataScanJob is canceling. CANCELING = 2 # The DataScanJob cancellation was successful. CANCELLED = 3 # The DataScanJob completed successfully. SUCCEEDED = 4 # The DataScanJob is no longer running due to an error. FAILED = 5 # The DataScanJob has been created but not started to run yet. PENDING = 7 # The DataScanJob succeeded with errors. SUCCEEDED_WITH_ERRORS = 8 end end |