Class: Google::Cloud::Dataplex::V1::DeleteDataProductRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Dataplex::V1::DeleteDataProductRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataplex/v1/data_products.rb
Overview
Request message for deleting a data product.
Instance Attribute Summary collapse
-
#etag ⇒ ::String
Optional.
-
#name ⇒ ::String
Required.
-
#validate_only ⇒ ::Boolean
Optional.
Instance Attribute Details
#etag ⇒ ::String
Optional. The etag of the data product.
If an etag is provided and does not match the current etag of the data product, then the deletion will be blocked and an ABORTED error will be returned.
314 315 316 317 |
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 314 class DeleteDataProductRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Required. The name of the data product to delete. Format: projects/{project_id_or_number}/locations/{location_id}/dataProducts/{data_product_id}.
314 315 316 317 |
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 314 class DeleteDataProductRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#validate_only ⇒ ::Boolean
Returns Optional. Validates the request without actually deleting the data product. Default: false.
314 315 316 317 |
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 314 class DeleteDataProductRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |