Class: Google::Cloud::Dataplex::V1::ExecutionIdentity
- Inherits:
-
Object
- Object
- Google::Cloud::Dataplex::V1::ExecutionIdentity
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataplex/v1/datascans.rb
Overview
The identity to run the datascan.
Defined Under Namespace
Classes: DataplexServiceAgent, ServiceAccount, UserCredential
Instance Attribute Summary collapse
-
#dataplex_service_agent ⇒ ::Google::Cloud::Dataplex::V1::ExecutionIdentity::DataplexServiceAgent
Optional.
-
#service_account ⇒ ::Google::Cloud::Dataplex::V1::ExecutionIdentity::ServiceAccount
Optional.
-
#user_credential ⇒ ::Google::Cloud::Dataplex::V1::ExecutionIdentity::UserCredential
Optional.
Instance Attribute Details
#dataplex_service_agent ⇒ ::Google::Cloud::Dataplex::V1::ExecutionIdentity::DataplexServiceAgent
Returns Optional. The Dataplex service agent associated with the user's project.
Note: The following fields are mutually exclusive: dataplex_service_agent, user_credential, service_account. If a field in that set is populated, all other fields in the set will automatically be cleared.
484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 |
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 484 class ExecutionIdentity include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The Dataplex service agent associated with the user's project. class DataplexServiceAgent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The credential of the calling user. class UserCredential include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The service account # @!attribute [rw] email # @return [::String] # Required. Service account email. The datascan will execute with this # service account's credentials. The user calling this API must have # permissions to act as this service account. Dataplex service agent must # be granted iam.serviceAccounts.getAccessToken permission on this service # account, for example, through the iam.serviceAccountTokenCreator role . class ServiceAccount include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#service_account ⇒ ::Google::Cloud::Dataplex::V1::ExecutionIdentity::ServiceAccount
Returns Optional. The provided service account.
Note: The following fields are mutually exclusive: service_account, dataplex_service_agent, user_credential. If a field in that set is populated, all other fields in the set will automatically be cleared.
484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 |
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 484 class ExecutionIdentity include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The Dataplex service agent associated with the user's project. class DataplexServiceAgent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The credential of the calling user. class UserCredential include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The service account # @!attribute [rw] email # @return [::String] # Required. Service account email. The datascan will execute with this # service account's credentials. The user calling this API must have # permissions to act as this service account. Dataplex service agent must # be granted iam.serviceAccounts.getAccessToken permission on this service # account, for example, through the iam.serviceAccountTokenCreator role . class ServiceAccount include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#user_credential ⇒ ::Google::Cloud::Dataplex::V1::ExecutionIdentity::UserCredential
Returns Optional. The credential of the calling user. Supports only ONE_TIME trigger type.
Note: The following fields are mutually exclusive: user_credential, dataplex_service_agent, service_account. If a field in that set is populated, all other fields in the set will automatically be cleared.
484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 |
# File 'proto_docs/google/cloud/dataplex/v1/datascans.rb', line 484 class ExecutionIdentity include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The Dataplex service agent associated with the user's project. class DataplexServiceAgent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The credential of the calling user. class UserCredential include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The service account # @!attribute [rw] email # @return [::String] # Required. Service account email. The datascan will execute with this # service account's credentials. The user calling this API must have # permissions to act as this service account. Dataplex service agent must # be granted iam.serviceAccounts.getAccessToken permission on this service # account, for example, through the iam.serviceAccountTokenCreator role . class ServiceAccount include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |