Class: Google::Cloud::Dataplex::V1::ListDataAssetsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Dataplex::V1::ListDataAssetsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataplex/v1/data_products.rb
Overview
Response message for listing data assets.
Instance Attribute Summary collapse
-
#data_assets ⇒ ::Array<::Google::Cloud::Dataplex::V1::DataAsset>
The data assets for the requested filter criteria.
-
#next_page_token ⇒ ::String
A token, which can be sent as
page_tokento retrieve the next page.
Instance Attribute Details
#data_assets ⇒ ::Array<::Google::Cloud::Dataplex::V1::DataAsset>
Returns The data assets for the requested filter criteria.
560 561 562 563 |
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 560 class ListDataAssetsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns A token, which can be sent as page_token to retrieve the next page.
If this field is empty, then there are no subsequent pages.
560 561 562 563 |
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 560 class ListDataAssetsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |