Class: Google::Cloud::Dataplex::V1::ListDataProductsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Dataplex::V1::ListDataProductsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataplex/v1/data_products.rb
Overview
Response message for listing data products.
Instance Attribute Summary collapse
-
#data_products ⇒ ::Array<::Google::Cloud::Dataplex::V1::DataProduct>
The data products for the requested filter criteria.
-
#next_page_token ⇒ ::String
A token, which can be sent as
page_tokento retrieve the next page. -
#unreachable ⇒ ::Array<::String>
Unordered list.
Instance Attribute Details
#data_products ⇒ ::Array<::Google::Cloud::Dataplex::V1::DataProduct>
Returns The data products for the requested filter criteria.
385 386 387 388 |
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 385 class ListDataProductsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns A token, which can be sent as page_token to retrieve the next page.
If this field is empty, then there are no subsequent pages.
385 386 387 388 |
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 385 class ListDataProductsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#unreachable ⇒ ::Array<::String>
Returns Unordered list. Locations that the service couldn't reach.
385 386 387 388 |
# File 'proto_docs/google/cloud/dataplex/v1/data_products.rb', line 385 class ListDataProductsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |