Class: Google::Cloud::Dataplex::V1::LookupContextRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Dataplex::V1::LookupContextRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataplex/v1/catalog.rb
Overview
Lookup Context using permissions in the source system.
Defined Under Namespace
Classes: OptionsEntry
Instance Attribute Summary collapse
-
#context ⇒ ::String
Optional.
-
#name ⇒ ::String
Required.
-
#options ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#resources ⇒ ::Array<::String>
Required.
Instance Attribute Details
#context ⇒ ::String
Returns Optional. The text representing contextual information for which metadata context is being requested.
1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 |
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 1101 class LookupContextRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class OptionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#name ⇒ ::String
Returns Required. The project to which the request should be attributed in the
following form: projects/{project}/locations/{location}.
1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 |
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 1101 class LookupContextRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class OptionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#options ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. Allows to configure the context.
Supported options:
format- The format of the context (one ofyaml,xml,json, default isyaml).context_budget- If provided, the output will be intelligently truncated on a best-effort basis to contain approximately the desired amount of characters. There is no guarantee to achieve the specific amount.
1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 |
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 1101 class LookupContextRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class OptionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#resources ⇒ ::Array<::String>
Returns Required. The entry names to look up the context for. The maximum number of resources for a request is limited to 10.
Examples:
projects/{project}/locations/{location}/entryGroups/{entry_group}/entries/{entry}.
1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 |
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 1101 class LookupContextRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class OptionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |