Class: Google::Cloud::Dataplex::V1::LookupContextResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Dataplex::V1::LookupContextResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataplex/v1/catalog.rb
Overview
Lookup Context response.
Instance Attribute Summary collapse
-
#context ⇒ ::String
Pre-formatted block of text containing the context for the requested resources.
Instance Attribute Details
#context ⇒ ::String
Returns Pre-formatted block of text containing the context for the requested resources.
1164 1165 1166 1167 |
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 1164 class LookupContextResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |