Class: Google::Cloud::Dataplex::V1::LookupEntryLinksResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Dataplex::V1::LookupEntryLinksResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataplex/v1/catalog.rb
Overview
Response message for LookupEntryLinks.
Instance Attribute Summary collapse
-
#entry_links ⇒ ::Array<::Google::Cloud::Dataplex::V1::EntryLink>
List of entry links that reference the specified entry.
-
#next_page_token ⇒ ::String
Token to retrieve the next page of results, or empty if there are no more results in the list.
Instance Attribute Details
#entry_links ⇒ ::Array<::Google::Cloud::Dataplex::V1::EntryLink>
Returns List of entry links that reference the specified entry.
2037 2038 2039 2040 |
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 2037 class LookupEntryLinksResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns Token to retrieve the next page of results, or empty if there are no more results in the list.
2037 2038 2039 2040 |
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 2037 class LookupEntryLinksResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |