Class: Google::Cloud::Dataplex::V1::LookupEntryRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Dataplex::V1::LookupEntryRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataplex/v1/catalog.rb
Overview
Lookup Entry request using permissions in the source system.
Instance Attribute Summary collapse
-
#aspect_types ⇒ ::Array<::String>
Optional.
-
#entry ⇒ ::String
Required.
-
#name ⇒ ::String
Required.
-
#paths ⇒ ::Array<::String>
Optional.
-
#view ⇒ ::Google::Cloud::Dataplex::V1::EntryView
Optional.
Instance Attribute Details
#aspect_types ⇒ ::Array<::String>
Returns Optional. Limits the aspects returned to the provided aspect types. It only works for CUSTOM view.
1068 1069 1070 1071 |
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 1068 class LookupEntryRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#entry ⇒ ::String
Returns Required. The resource name of the Entry:
projects/{project}/locations/{location}/entryGroups/{entry_group}/entries/{entry}.
1068 1069 1070 1071 |
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 1068 class LookupEntryRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Required. The project to which the request should be attributed in the
following form: projects/{project}/locations/{location}.
1068 1069 1070 1071 |
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 1068 class LookupEntryRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#paths ⇒ ::Array<::String>
Returns Optional. Limits the aspects returned to those associated with the provided paths within the Entry. It only works for CUSTOM view.
1068 1069 1070 1071 |
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 1068 class LookupEntryRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#view ⇒ ::Google::Cloud::Dataplex::V1::EntryView
Optional. View to control which parts of an entry the service should return. Please check the limitations on returned aspects in the Entry view documentation. Amount of returned aspects depends on the selected Entry View.
1068 1069 1070 1071 |
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 1068 class LookupEntryRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |