Class: Google::Cloud::Dataplex::V1::MetadataFeed
- Inherits:
-
Object
- Object
- Google::Cloud::Dataplex::V1::MetadataFeed
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataplex/v1/catalog.rb
Overview
MetadataFeed contains information related to the metadata feed.
Defined Under Namespace
Classes: Filters, LabelsEntry, Scope
Instance Attribute Summary collapse
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#filters ⇒ ::Google::Cloud::Dataplex::V1::MetadataFeed::Filters
Optional.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#name ⇒ ::String
Identifier.
-
#pubsub_topic ⇒ ::String
Optional.
-
#scope ⇒ ::Google::Cloud::Dataplex::V1::MetadataFeed::Scope
Required.
-
#uid ⇒ ::String
readonly
Output only.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time when the feed was created.
2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 |
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 2085 class MetadataFeed include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Scope defines the scope of the metadata feed. # Scopes are exclusive. Only one of the scopes can be specified. # @!attribute [rw] organization_level # @return [::Boolean] # Optional. Whether the metadata feed is at the organization-level. # # - If `true`, all changes happened to the entries in the same # organization as the feed are published. # - If `false`, you must specify a list of projects or a list of entry # groups whose entries you want to listen to. # # The default is `false`. # @!attribute [rw] projects # @return [::Array<::String>] # Optional. The projects whose entries you want to listen to. # Must be in the same organization as the feed. # Must be in the format: `projects/{project_id_or_number}`. # @!attribute [rw] entry_groups # @return [::Array<::String>] # Optional. The entry groups whose entries you want to listen to. # Must be in the format: # `projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}`. class Scope include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Filters defines the type of changes that you want to listen to. # You can have multiple entry type filters and multiple aspect type filters. # All of the entry type filters are OR'ed together. # All of the aspect type filters are OR'ed together. # All of the entry type filters and aspect type filters are AND'ed together. # @!attribute [rw] entry_types # @return [::Array<::String>] # Optional. The entry types that you want to listen to, specified as # relative resource names in the format # `projects/{project_id_or_number}/locations/{location}/entryTypes/{entry_type_id}`. # Only entries that belong to the specified entry types are published. # @!attribute [rw] aspect_types # @return [::Array<::String>] # Optional. The aspect types that you want to listen to. Depending on how # the aspect is attached to the entry, in the format: # `projects/{project_id_or_number}/locations/{location}/aspectTypes/{aspect_type_id}`. # @!attribute [rw] change_types # @return [::Array<::Google::Cloud::Dataplex::V1::MetadataFeed::Filters::ChangeType>] # Optional. The type of change that you want to listen to. # If not specified, all changes are published. class Filters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of change that you want to listen to. module ChangeType # Unspecified change type. Defaults to UNSPECIFIED. CHANGE_TYPE_UNSPECIFIED = 0 # The change is a create event. CREATE = 1 # The change is an update event. UPDATE = 2 # The change is a delete event. DELETE = 3 end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#filters ⇒ ::Google::Cloud::Dataplex::V1::MetadataFeed::Filters
Returns Optional. The filters of the metadata feed. Only the changes that match the filters are published.
2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 |
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 2085 class MetadataFeed include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Scope defines the scope of the metadata feed. # Scopes are exclusive. Only one of the scopes can be specified. # @!attribute [rw] organization_level # @return [::Boolean] # Optional. Whether the metadata feed is at the organization-level. # # - If `true`, all changes happened to the entries in the same # organization as the feed are published. # - If `false`, you must specify a list of projects or a list of entry # groups whose entries you want to listen to. # # The default is `false`. # @!attribute [rw] projects # @return [::Array<::String>] # Optional. The projects whose entries you want to listen to. # Must be in the same organization as the feed. # Must be in the format: `projects/{project_id_or_number}`. # @!attribute [rw] entry_groups # @return [::Array<::String>] # Optional. The entry groups whose entries you want to listen to. # Must be in the format: # `projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}`. class Scope include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Filters defines the type of changes that you want to listen to. # You can have multiple entry type filters and multiple aspect type filters. # All of the entry type filters are OR'ed together. # All of the aspect type filters are OR'ed together. # All of the entry type filters and aspect type filters are AND'ed together. # @!attribute [rw] entry_types # @return [::Array<::String>] # Optional. The entry types that you want to listen to, specified as # relative resource names in the format # `projects/{project_id_or_number}/locations/{location}/entryTypes/{entry_type_id}`. # Only entries that belong to the specified entry types are published. # @!attribute [rw] aspect_types # @return [::Array<::String>] # Optional. The aspect types that you want to listen to. Depending on how # the aspect is attached to the entry, in the format: # `projects/{project_id_or_number}/locations/{location}/aspectTypes/{aspect_type_id}`. # @!attribute [rw] change_types # @return [::Array<::Google::Cloud::Dataplex::V1::MetadataFeed::Filters::ChangeType>] # Optional. The type of change that you want to listen to. # If not specified, all changes are published. class Filters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of change that you want to listen to. module ChangeType # Unspecified change type. Defaults to UNSPECIFIED. CHANGE_TYPE_UNSPECIFIED = 0 # The change is a create event. CREATE = 1 # The change is an update event. UPDATE = 2 # The change is a delete event. DELETE = 3 end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. User-defined labels.
2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 |
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 2085 class MetadataFeed include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Scope defines the scope of the metadata feed. # Scopes are exclusive. Only one of the scopes can be specified. # @!attribute [rw] organization_level # @return [::Boolean] # Optional. Whether the metadata feed is at the organization-level. # # - If `true`, all changes happened to the entries in the same # organization as the feed are published. # - If `false`, you must specify a list of projects or a list of entry # groups whose entries you want to listen to. # # The default is `false`. # @!attribute [rw] projects # @return [::Array<::String>] # Optional. The projects whose entries you want to listen to. # Must be in the same organization as the feed. # Must be in the format: `projects/{project_id_or_number}`. # @!attribute [rw] entry_groups # @return [::Array<::String>] # Optional. The entry groups whose entries you want to listen to. # Must be in the format: # `projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}`. class Scope include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Filters defines the type of changes that you want to listen to. # You can have multiple entry type filters and multiple aspect type filters. # All of the entry type filters are OR'ed together. # All of the aspect type filters are OR'ed together. # All of the entry type filters and aspect type filters are AND'ed together. # @!attribute [rw] entry_types # @return [::Array<::String>] # Optional. The entry types that you want to listen to, specified as # relative resource names in the format # `projects/{project_id_or_number}/locations/{location}/entryTypes/{entry_type_id}`. # Only entries that belong to the specified entry types are published. # @!attribute [rw] aspect_types # @return [::Array<::String>] # Optional. The aspect types that you want to listen to. Depending on how # the aspect is attached to the entry, in the format: # `projects/{project_id_or_number}/locations/{location}/aspectTypes/{aspect_type_id}`. # @!attribute [rw] change_types # @return [::Array<::Google::Cloud::Dataplex::V1::MetadataFeed::Filters::ChangeType>] # Optional. The type of change that you want to listen to. # If not specified, all changes are published. class Filters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of change that you want to listen to. module ChangeType # Unspecified change type. Defaults to UNSPECIFIED. CHANGE_TYPE_UNSPECIFIED = 0 # The change is a create event. CREATE = 1 # The change is an update event. UPDATE = 2 # The change is a delete event. DELETE = 3 end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#name ⇒ ::String
Returns Identifier. The resource name of the metadata feed, in the format
projects/{project_id_or_number}/locations/{location_id}/metadataFeeds/{metadata_feed_id}.
2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 |
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 2085 class MetadataFeed include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Scope defines the scope of the metadata feed. # Scopes are exclusive. Only one of the scopes can be specified. # @!attribute [rw] organization_level # @return [::Boolean] # Optional. Whether the metadata feed is at the organization-level. # # - If `true`, all changes happened to the entries in the same # organization as the feed are published. # - If `false`, you must specify a list of projects or a list of entry # groups whose entries you want to listen to. # # The default is `false`. # @!attribute [rw] projects # @return [::Array<::String>] # Optional. The projects whose entries you want to listen to. # Must be in the same organization as the feed. # Must be in the format: `projects/{project_id_or_number}`. # @!attribute [rw] entry_groups # @return [::Array<::String>] # Optional. The entry groups whose entries you want to listen to. # Must be in the format: # `projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}`. class Scope include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Filters defines the type of changes that you want to listen to. # You can have multiple entry type filters and multiple aspect type filters. # All of the entry type filters are OR'ed together. # All of the aspect type filters are OR'ed together. # All of the entry type filters and aspect type filters are AND'ed together. # @!attribute [rw] entry_types # @return [::Array<::String>] # Optional. The entry types that you want to listen to, specified as # relative resource names in the format # `projects/{project_id_or_number}/locations/{location}/entryTypes/{entry_type_id}`. # Only entries that belong to the specified entry types are published. # @!attribute [rw] aspect_types # @return [::Array<::String>] # Optional. The aspect types that you want to listen to. Depending on how # the aspect is attached to the entry, in the format: # `projects/{project_id_or_number}/locations/{location}/aspectTypes/{aspect_type_id}`. # @!attribute [rw] change_types # @return [::Array<::Google::Cloud::Dataplex::V1::MetadataFeed::Filters::ChangeType>] # Optional. The type of change that you want to listen to. # If not specified, all changes are published. class Filters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of change that you want to listen to. module ChangeType # Unspecified change type. Defaults to UNSPECIFIED. CHANGE_TYPE_UNSPECIFIED = 0 # The change is a create event. CREATE = 1 # The change is an update event. UPDATE = 2 # The change is a delete event. DELETE = 3 end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#pubsub_topic ⇒ ::String
Returns Optional. The pubsub topic that you want the metadata feed messages to publish to. Please grant Dataplex service account the permission to publish messages to the topic. The service account is: service-{PROJECT_NUMBER}@gcp-sa-dataplex.iam.gserviceaccount.com.
2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 |
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 2085 class MetadataFeed include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Scope defines the scope of the metadata feed. # Scopes are exclusive. Only one of the scopes can be specified. # @!attribute [rw] organization_level # @return [::Boolean] # Optional. Whether the metadata feed is at the organization-level. # # - If `true`, all changes happened to the entries in the same # organization as the feed are published. # - If `false`, you must specify a list of projects or a list of entry # groups whose entries you want to listen to. # # The default is `false`. # @!attribute [rw] projects # @return [::Array<::String>] # Optional. The projects whose entries you want to listen to. # Must be in the same organization as the feed. # Must be in the format: `projects/{project_id_or_number}`. # @!attribute [rw] entry_groups # @return [::Array<::String>] # Optional. The entry groups whose entries you want to listen to. # Must be in the format: # `projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}`. class Scope include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Filters defines the type of changes that you want to listen to. # You can have multiple entry type filters and multiple aspect type filters. # All of the entry type filters are OR'ed together. # All of the aspect type filters are OR'ed together. # All of the entry type filters and aspect type filters are AND'ed together. # @!attribute [rw] entry_types # @return [::Array<::String>] # Optional. The entry types that you want to listen to, specified as # relative resource names in the format # `projects/{project_id_or_number}/locations/{location}/entryTypes/{entry_type_id}`. # Only entries that belong to the specified entry types are published. # @!attribute [rw] aspect_types # @return [::Array<::String>] # Optional. The aspect types that you want to listen to. Depending on how # the aspect is attached to the entry, in the format: # `projects/{project_id_or_number}/locations/{location}/aspectTypes/{aspect_type_id}`. # @!attribute [rw] change_types # @return [::Array<::Google::Cloud::Dataplex::V1::MetadataFeed::Filters::ChangeType>] # Optional. The type of change that you want to listen to. # If not specified, all changes are published. class Filters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of change that you want to listen to. module ChangeType # Unspecified change type. Defaults to UNSPECIFIED. CHANGE_TYPE_UNSPECIFIED = 0 # The change is a create event. CREATE = 1 # The change is an update event. UPDATE = 2 # The change is a delete event. DELETE = 3 end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#scope ⇒ ::Google::Cloud::Dataplex::V1::MetadataFeed::Scope
Returns Required. The scope of the metadata feed. Only the in scope changes are published.
2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 |
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 2085 class MetadataFeed include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Scope defines the scope of the metadata feed. # Scopes are exclusive. Only one of the scopes can be specified. # @!attribute [rw] organization_level # @return [::Boolean] # Optional. Whether the metadata feed is at the organization-level. # # - If `true`, all changes happened to the entries in the same # organization as the feed are published. # - If `false`, you must specify a list of projects or a list of entry # groups whose entries you want to listen to. # # The default is `false`. # @!attribute [rw] projects # @return [::Array<::String>] # Optional. The projects whose entries you want to listen to. # Must be in the same organization as the feed. # Must be in the format: `projects/{project_id_or_number}`. # @!attribute [rw] entry_groups # @return [::Array<::String>] # Optional. The entry groups whose entries you want to listen to. # Must be in the format: # `projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}`. class Scope include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Filters defines the type of changes that you want to listen to. # You can have multiple entry type filters and multiple aspect type filters. # All of the entry type filters are OR'ed together. # All of the aspect type filters are OR'ed together. # All of the entry type filters and aspect type filters are AND'ed together. # @!attribute [rw] entry_types # @return [::Array<::String>] # Optional. The entry types that you want to listen to, specified as # relative resource names in the format # `projects/{project_id_or_number}/locations/{location}/entryTypes/{entry_type_id}`. # Only entries that belong to the specified entry types are published. # @!attribute [rw] aspect_types # @return [::Array<::String>] # Optional. The aspect types that you want to listen to. Depending on how # the aspect is attached to the entry, in the format: # `projects/{project_id_or_number}/locations/{location}/aspectTypes/{aspect_type_id}`. # @!attribute [rw] change_types # @return [::Array<::Google::Cloud::Dataplex::V1::MetadataFeed::Filters::ChangeType>] # Optional. The type of change that you want to listen to. # If not specified, all changes are published. class Filters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of change that you want to listen to. module ChangeType # Unspecified change type. Defaults to UNSPECIFIED. CHANGE_TYPE_UNSPECIFIED = 0 # The change is a create event. CREATE = 1 # The change is an update event. UPDATE = 2 # The change is a delete event. DELETE = 3 end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#uid ⇒ ::String (readonly)
Returns Output only. A system-generated, globally unique ID for the metadata job. If the metadata job is deleted and then re-created with the same name, this ID is different.
2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 |
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 2085 class MetadataFeed include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Scope defines the scope of the metadata feed. # Scopes are exclusive. Only one of the scopes can be specified. # @!attribute [rw] organization_level # @return [::Boolean] # Optional. Whether the metadata feed is at the organization-level. # # - If `true`, all changes happened to the entries in the same # organization as the feed are published. # - If `false`, you must specify a list of projects or a list of entry # groups whose entries you want to listen to. # # The default is `false`. # @!attribute [rw] projects # @return [::Array<::String>] # Optional. The projects whose entries you want to listen to. # Must be in the same organization as the feed. # Must be in the format: `projects/{project_id_or_number}`. # @!attribute [rw] entry_groups # @return [::Array<::String>] # Optional. The entry groups whose entries you want to listen to. # Must be in the format: # `projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}`. class Scope include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Filters defines the type of changes that you want to listen to. # You can have multiple entry type filters and multiple aspect type filters. # All of the entry type filters are OR'ed together. # All of the aspect type filters are OR'ed together. # All of the entry type filters and aspect type filters are AND'ed together. # @!attribute [rw] entry_types # @return [::Array<::String>] # Optional. The entry types that you want to listen to, specified as # relative resource names in the format # `projects/{project_id_or_number}/locations/{location}/entryTypes/{entry_type_id}`. # Only entries that belong to the specified entry types are published. # @!attribute [rw] aspect_types # @return [::Array<::String>] # Optional. The aspect types that you want to listen to. Depending on how # the aspect is attached to the entry, in the format: # `projects/{project_id_or_number}/locations/{location}/aspectTypes/{aspect_type_id}`. # @!attribute [rw] change_types # @return [::Array<::Google::Cloud::Dataplex::V1::MetadataFeed::Filters::ChangeType>] # Optional. The type of change that you want to listen to. # If not specified, all changes are published. class Filters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of change that you want to listen to. module ChangeType # Unspecified change type. Defaults to UNSPECIFIED. CHANGE_TYPE_UNSPECIFIED = 0 # The change is a create event. CREATE = 1 # The change is an update event. UPDATE = 2 # The change is a delete event. DELETE = 3 end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time when the feed was updated.
2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 |
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 2085 class MetadataFeed include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Scope defines the scope of the metadata feed. # Scopes are exclusive. Only one of the scopes can be specified. # @!attribute [rw] organization_level # @return [::Boolean] # Optional. Whether the metadata feed is at the organization-level. # # - If `true`, all changes happened to the entries in the same # organization as the feed are published. # - If `false`, you must specify a list of projects or a list of entry # groups whose entries you want to listen to. # # The default is `false`. # @!attribute [rw] projects # @return [::Array<::String>] # Optional. The projects whose entries you want to listen to. # Must be in the same organization as the feed. # Must be in the format: `projects/{project_id_or_number}`. # @!attribute [rw] entry_groups # @return [::Array<::String>] # Optional. The entry groups whose entries you want to listen to. # Must be in the format: # `projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}`. class Scope include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Filters defines the type of changes that you want to listen to. # You can have multiple entry type filters and multiple aspect type filters. # All of the entry type filters are OR'ed together. # All of the aspect type filters are OR'ed together. # All of the entry type filters and aspect type filters are AND'ed together. # @!attribute [rw] entry_types # @return [::Array<::String>] # Optional. The entry types that you want to listen to, specified as # relative resource names in the format # `projects/{project_id_or_number}/locations/{location}/entryTypes/{entry_type_id}`. # Only entries that belong to the specified entry types are published. # @!attribute [rw] aspect_types # @return [::Array<::String>] # Optional. The aspect types that you want to listen to. Depending on how # the aspect is attached to the entry, in the format: # `projects/{project_id_or_number}/locations/{location}/aspectTypes/{aspect_type_id}`. # @!attribute [rw] change_types # @return [::Array<::Google::Cloud::Dataplex::V1::MetadataFeed::Filters::ChangeType>] # Optional. The type of change that you want to listen to. # If not specified, all changes are published. class Filters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of change that you want to listen to. module ChangeType # Unspecified change type. Defaults to UNSPECIFIED. CHANGE_TYPE_UNSPECIFIED = 0 # The change is a create event. CREATE = 1 # The change is an update event. UPDATE = 2 # The change is a delete event. DELETE = 3 end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |