Class: Google::Cloud::Dataplex::V1::MetadataFeed::Scope
- Inherits:
-
Object
- Object
- Google::Cloud::Dataplex::V1::MetadataFeed::Scope
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataplex/v1/catalog.rb
Overview
Scope defines the scope of the metadata feed. Scopes are exclusive. Only one of the scopes can be specified.
Instance Attribute Summary collapse
-
#entry_groups ⇒ ::Array<::String>
Optional.
-
#organization_level ⇒ ::Boolean
Optional.
-
#projects ⇒ ::Array<::String>
Optional.
Instance Attribute Details
#entry_groups ⇒ ::Array<::String>
Returns Optional. The entry groups whose entries you want to listen to.
Must be in the format:
projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}.
2111 2112 2113 2114 |
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 2111 class Scope include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#organization_level ⇒ ::Boolean
Returns Optional. Whether the metadata feed is at the organization-level.
- If
true, all changes happened to the entries in the same organization as the feed are published. - If
false, you must specify a list of projects or a list of entry groups whose entries you want to listen to.
The default is false.
2111 2112 2113 2114 |
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 2111 class Scope include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#projects ⇒ ::Array<::String>
Returns Optional. The projects whose entries you want to listen to.
Must be in the same organization as the feed.
Must be in the format: projects/{project_id_or_number}.
2111 2112 2113 2114 |
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 2111 class Scope include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |