Class: Google::Cloud::Dataplex::V1::MetadataJob::Status

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataplex/v1/catalog.rb

Overview

Metadata job status.

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

#completion_percent::Integer (readonly)

Returns Output only. Progress tracking.

Returns:

  • (::Integer)

    Output only. Progress tracking.



1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 1797

class Status
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # State of a metadata job.
  module State
    # State unspecified.
    STATE_UNSPECIFIED = 0

    # The job is queued.
    QUEUED = 1

    # The job is running.
    RUNNING = 2

    # The job is being canceled.
    CANCELING = 3

    # The job is canceled.
    CANCELED = 4

    # The job succeeded.
    SUCCEEDED = 5

    # The job failed.
    FAILED = 6

    # The job completed with some errors.
    SUCCEEDED_WITH_ERRORS = 7
  end
end

#message::String (readonly)

Returns Output only. Message relating to the progression of a metadata job.

Returns:

  • (::String)

    Output only. Message relating to the progression of a metadata job.



1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 1797

class Status
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # State of a metadata job.
  module State
    # State unspecified.
    STATE_UNSPECIFIED = 0

    # The job is queued.
    QUEUED = 1

    # The job is running.
    RUNNING = 2

    # The job is being canceled.
    CANCELING = 3

    # The job is canceled.
    CANCELED = 4

    # The job succeeded.
    SUCCEEDED = 5

    # The job failed.
    FAILED = 6

    # The job completed with some errors.
    SUCCEEDED_WITH_ERRORS = 7
  end
end

#state::Google::Cloud::Dataplex::V1::MetadataJob::Status::State (readonly)

Returns Output only. State of the metadata job.

Returns:



1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 1797

class Status
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # State of a metadata job.
  module State
    # State unspecified.
    STATE_UNSPECIFIED = 0

    # The job is queued.
    QUEUED = 1

    # The job is running.
    RUNNING = 2

    # The job is being canceled.
    CANCELING = 3

    # The job is canceled.
    CANCELED = 4

    # The job succeeded.
    SUCCEEDED = 5

    # The job failed.
    FAILED = 6

    # The job completed with some errors.
    SUCCEEDED_WITH_ERRORS = 7
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time when the status was updated.

Returns:



1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 1797

class Status
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # State of a metadata job.
  module State
    # State unspecified.
    STATE_UNSPECIFIED = 0

    # The job is queued.
    QUEUED = 1

    # The job is running.
    RUNNING = 2

    # The job is being canceled.
    CANCELING = 3

    # The job is canceled.
    CANCELED = 4

    # The job succeeded.
    SUCCEEDED = 5

    # The job failed.
    FAILED = 6

    # The job completed with some errors.
    SUCCEEDED_WITH_ERRORS = 7
  end
end