Class: Google::Cloud::Dataplex::V1::ModifyEntryRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Dataplex::V1::ModifyEntryRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataplex/v1/catalog.rb
Overview
Modify Entry request using permissions in the source system.
Instance Attribute Summary collapse
-
#aspect_keys ⇒ ::Array<::String>
Optional.
-
#delete_missing_aspects ⇒ ::Boolean
Optional.
-
#entry ⇒ ::Google::Cloud::Dataplex::V1::Entry
Required.
-
#name ⇒ ::String
Required.
-
#update_mask ⇒ ::Google::Protobuf::FieldMask
Optional.
Instance Attribute Details
#aspect_keys ⇒ ::Array<::String>
Returns Optional. The aspect keys which the service should modify. It supports the following syntaxes:
<aspect_type_reference>- matches an aspect of the given type and empty path.<aspect_type_reference>@path- matches an aspect of the given type and specified path. For example, to attach an aspect to a field that is specified by theschemaaspect, the path should have the formatSchema.<field_name>.<aspect_type_reference>@*- matches aspects of the given type for all paths.*@path- matches aspects of all types on the given path.
The service will not remove existing aspects matching the syntax unless
delete_missing_aspects is set to true.
If this field is left empty, the service treats it as specifying exactly those Aspects present in the request.
1154 1155 1156 1157 |
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 1154 class ModifyEntryRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#delete_missing_aspects ⇒ ::Boolean
Returns Optional. If set to true, any aspects not specified in the request will be deleted. The default is false.
1154 1155 1156 1157 |
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 1154 class ModifyEntryRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#entry ⇒ ::Google::Cloud::Dataplex::V1::Entry
Returns Required. The entry to modify.
1154 1155 1156 1157 |
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 1154 class ModifyEntryRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Required. The project to which the request should be attributed in the
following form: projects/{project}/locations/{location}.
1154 1155 1156 1157 |
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 1154 class ModifyEntryRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_mask ⇒ ::Google::Protobuf::FieldMask
Returns Optional. Mask of fields to update. To update Aspects, the update_mask must contain the value "aspects".
If the update_mask is empty, the service will update all modifiable fields present in the request.
1154 1155 1156 1157 |
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 1154 class ModifyEntryRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |