Class: Google::Cloud::Dataplex::V1::SearchEntriesResult
- Inherits:
-
Object
- Object
- Google::Cloud::Dataplex::V1::SearchEntriesResult
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataplex/v1/catalog.rb
Overview
A single result of a SearchEntries request.
Defined Under Namespace
Classes: Snippets
Instance Attribute Summary collapse
- #dataplex_entry ⇒ ::Google::Cloud::Dataplex::V1::Entry
-
#linked_resource ⇒ ::String
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#snippets ⇒ ::Google::Cloud::Dataplex::V1::SearchEntriesResult::Snippets
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
Instance Attribute Details
#dataplex_entry ⇒ ::Google::Cloud::Dataplex::V1::Entry
1221 1222 1223 1224 1225 1226 1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 |
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 1221 class SearchEntriesResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Snippets for the entry, contains HTML-style highlighting for # matched tokens, will be used in UI. # @deprecated This message is deprecated and may be removed in the next major version update. # @!attribute [rw] dataplex_entry # @deprecated This field is deprecated and may be removed in the next major version update. # @return [::Google::Cloud::Dataplex::V1::Entry] # Entry class Snippets include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#linked_resource ⇒ ::String
Deprecated.
This field is deprecated and may be removed in the next major version update.
Returns Linked resource name.
1221 1222 1223 1224 1225 1226 1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 |
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 1221 class SearchEntriesResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Snippets for the entry, contains HTML-style highlighting for # matched tokens, will be used in UI. # @deprecated This message is deprecated and may be removed in the next major version update. # @!attribute [rw] dataplex_entry # @deprecated This field is deprecated and may be removed in the next major version update. # @return [::Google::Cloud::Dataplex::V1::Entry] # Entry class Snippets include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#snippets ⇒ ::Google::Cloud::Dataplex::V1::SearchEntriesResult::Snippets
Deprecated.
This field is deprecated and may be removed in the next major version update.
Returns Snippets.
1221 1222 1223 1224 1225 1226 1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 |
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 1221 class SearchEntriesResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Snippets for the entry, contains HTML-style highlighting for # matched tokens, will be used in UI. # @deprecated This message is deprecated and may be removed in the next major version update. # @!attribute [rw] dataplex_entry # @deprecated This field is deprecated and may be removed in the next major version update. # @return [::Google::Cloud::Dataplex::V1::Entry] # Entry class Snippets include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |