Class: Google::Cloud::Dataplex::V1::Trigger
- Inherits:
-
Object
- Object
- Google::Cloud::Dataplex::V1::Trigger
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataplex/v1/processing.rb
Overview
DataScan scheduling and trigger settings.
Defined Under Namespace
Classes: OnDemand, OneTime, Schedule
Instance Attribute Summary collapse
-
#on_demand ⇒ ::Google::Cloud::Dataplex::V1::Trigger::OnDemand
The scan runs once via
RunDataScanAPI. -
#one_time ⇒ ::Google::Cloud::Dataplex::V1::Trigger::OneTime
The scan runs once, and does not create an associated ScanJob child resource.
-
#schedule ⇒ ::Google::Cloud::Dataplex::V1::Trigger::Schedule
The scan is scheduled to run periodically.
Instance Attribute Details
#on_demand ⇒ ::Google::Cloud::Dataplex::V1::Trigger::OnDemand
Returns The scan runs once via RunDataScan API.
Note: The following fields are mutually exclusive: on_demand, schedule, one_time. If a field in that set is populated, all other fields in the set will automatically be cleared.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'proto_docs/google/cloud/dataplex/v1/processing.rb', line 41 class Trigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The scan runs once via `RunDataScan` API. class OnDemand include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The scan is scheduled to run periodically. # @!attribute [rw] cron # @return [::String] # Required. [Cron](https://en.wikipedia.org/wiki/Cron) schedule for running # scans periodically. # # To explicitly set a timezone in the cron tab, apply a prefix in the # cron tab: **"CRON_TZ=$\\{IANA_TIME_ZONE}"** or **"TZ=$\\{IANA_TIME_ZONE}"**. # The **$\\{IANA_TIME_ZONE}** may only be a valid string from IANA time zone # database # ([wikipedia](https://en.wikipedia.org/wiki/List_of_tz_database_time_zones#List)). # For example, `CRON_TZ=America/New_York 1 * * * *`, or # `TZ=America/New_York 1 * * * *`. # # This field is required for Schedule scans. class Schedule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The scan runs once using create API. # @!attribute [rw] ttl_after_scan_completion # @return [::Google::Protobuf::Duration] # Optional. Time to live for OneTime scans. # default value is 24 hours, minimum value is 0 seconds, and maximum value # is 365 days. The time is calculated from the data scan job completion # time. If value is set as 0 seconds, the scan will be immediately deleted # upon job completion, regardless of whether the job succeeded or failed. class OneTime include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#one_time ⇒ ::Google::Cloud::Dataplex::V1::Trigger::OneTime
Returns The scan runs once, and does not create an associated ScanJob child resource.
Note: The following fields are mutually exclusive: one_time, on_demand, schedule. If a field in that set is populated, all other fields in the set will automatically be cleared.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'proto_docs/google/cloud/dataplex/v1/processing.rb', line 41 class Trigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The scan runs once via `RunDataScan` API. class OnDemand include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The scan is scheduled to run periodically. # @!attribute [rw] cron # @return [::String] # Required. [Cron](https://en.wikipedia.org/wiki/Cron) schedule for running # scans periodically. # # To explicitly set a timezone in the cron tab, apply a prefix in the # cron tab: **"CRON_TZ=$\\{IANA_TIME_ZONE}"** or **"TZ=$\\{IANA_TIME_ZONE}"**. # The **$\\{IANA_TIME_ZONE}** may only be a valid string from IANA time zone # database # ([wikipedia](https://en.wikipedia.org/wiki/List_of_tz_database_time_zones#List)). # For example, `CRON_TZ=America/New_York 1 * * * *`, or # `TZ=America/New_York 1 * * * *`. # # This field is required for Schedule scans. class Schedule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The scan runs once using create API. # @!attribute [rw] ttl_after_scan_completion # @return [::Google::Protobuf::Duration] # Optional. Time to live for OneTime scans. # default value is 24 hours, minimum value is 0 seconds, and maximum value # is 365 days. The time is calculated from the data scan job completion # time. If value is set as 0 seconds, the scan will be immediately deleted # upon job completion, regardless of whether the job succeeded or failed. class OneTime include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#schedule ⇒ ::Google::Cloud::Dataplex::V1::Trigger::Schedule
Returns The scan is scheduled to run periodically.
Note: The following fields are mutually exclusive: schedule, on_demand, one_time. If a field in that set is populated, all other fields in the set will automatically be cleared.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'proto_docs/google/cloud/dataplex/v1/processing.rb', line 41 class Trigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The scan runs once via `RunDataScan` API. class OnDemand include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The scan is scheduled to run periodically. # @!attribute [rw] cron # @return [::String] # Required. [Cron](https://en.wikipedia.org/wiki/Cron) schedule for running # scans periodically. # # To explicitly set a timezone in the cron tab, apply a prefix in the # cron tab: **"CRON_TZ=$\\{IANA_TIME_ZONE}"** or **"TZ=$\\{IANA_TIME_ZONE}"**. # The **$\\{IANA_TIME_ZONE}** may only be a valid string from IANA time zone # database # ([wikipedia](https://en.wikipedia.org/wiki/List_of_tz_database_time_zones#List)). # For example, `CRON_TZ=America/New_York 1 * * * *`, or # `TZ=America/New_York 1 * * * *`. # # This field is required for Schedule scans. class Schedule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The scan runs once using create API. # @!attribute [rw] ttl_after_scan_completion # @return [::Google::Protobuf::Duration] # Optional. Time to live for OneTime scans. # default value is 24 hours, minimum value is 0 seconds, and maximum value # is 365 days. The time is calculated from the data scan job completion # time. If value is set as 0 seconds, the scan will be immediately deleted # upon job completion, regardless of whether the job succeeded or failed. class OneTime include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |