Class: Google::Cloud::Dataplex::V1::UpdateEntryLinkRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Dataplex::V1::UpdateEntryLinkRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataplex/v1/catalog.rb
Overview
Request message for UpdateEntryLink method.
Instance Attribute Summary collapse
-
#allow_missing ⇒ ::Boolean
Optional.
-
#aspect_keys ⇒ ::Array<::String>
Optional.
-
#entry_link ⇒ ::Google::Cloud::Dataplex::V1::EntryLink
Required.
Instance Attribute Details
#allow_missing ⇒ ::Boolean
Returns Optional. If set to true and the entry link doesn't exist, the service will create it.
1967 1968 1969 1970 |
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 1967 class UpdateEntryLinkRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#aspect_keys ⇒ ::Array<::String>
Returns Optional. The map keys of the Aspects which the service should modify.
It should be the aspect type reference in the format
{project_id_or_number}.{location_id}.{aspect_type_id}.
If this field is left empty, the service treats it as specifying exactly those Aspects present in the request.
1967 1968 1969 1970 |
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 1967 class UpdateEntryLinkRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#entry_link ⇒ ::Google::Cloud::Dataplex::V1::EntryLink
Returns Required. Entry Link resource.
1967 1968 1969 1970 |
# File 'proto_docs/google/cloud/dataplex/v1/catalog.rb', line 1967 class UpdateEntryLinkRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |